@@ -280,6 +280,11 @@ return [
 			'url' => '/api/messages/{id}/mdn',
 			'verb' => 'POST'
 		],
+		[
+			'name' => 'messages#smartReply',
+			'url' => '/api/messages/{messageId}/smartreply',
+			'verb' => 'GET'
+		],
 		[
 			'name' => 'avatars#url',
 			'url' => '/api/avatars/url/{email}',
@@ -341,8 +346,8 @@ return [
 			'verb' => 'POST'
 		],
 		[
-			'name' => 'settings#setEnabledThreadSummary',
-			'url' => '/api/settings/threadsummary',
+			'name' => 'settings#setEnabledLlmProcessing',
+			'url' => '/api/settings/llm',
 			'verb' => 'PUT'
 		],
 		[
@@ -400,6 +405,11 @@ return [
 			'url' => '/api/thread/{id}/summary',
 			'verb' => 'GET'
 		],
+		[
+			'name' => 'thread#generateEventData',
+			'url' => '/api/thread/{id}/eventdata',
+			'verb' => 'GET'
+		],
 		[
 			'name' => 'outbox#send',
 			'url' => '/api/outbox/{id}',
