@@ -42,6 +42,12 @@ OC.L10N.register(
     "Email address" : "E-posadres",
     "Cancel" : "Kanselleer",
     "Add mail account" : "Voeg posrekening toe",
+    "Register" : "Registreer",
+    "Archive" : "Argief",
+    "Delete" : "Skrap",
+    "Search" : "Soek",
+    "Send" : "Stuur",
+    "Refresh" : "Verfris",
     "Update Certificate" : "Werk sertifikaat by",
     "No certificate" : "Geen sertifikaat",
     "Certificate updated" : "Sertifikaat bygewerk",
@@ -60,7 +66,7 @@ OC.L10N.register(
     "Monday morning" : "Maandagoggend",
     "Custom date and time" : "Pasgemaakte datum en tyd",
     "Enter a date" : "Voer ’n datum in",
-    "Send" : "Stuur",
+    "Choose" : "Kies",
     "Confirm" : "Bevestig",
     "Plain text" : "Skoonteks",
     "Favorite" : "Gunsteling",
@@ -69,10 +75,10 @@ OC.L10N.register(
     "No subject" : "Geen onderwerp",
     "Forward" : "Stuur aan",
     "All day" : "Heeldag",
+    "Description" : "Beskrywing",
     "Create" : "Skep",
     "Comment" : "Kommentaar",
     "Accept" : "Aanvaar",
-    "Choose" : "Kies",
     "Other" : "Ander",
     "Reply" : "Antwoord",
     "View source" : "Bekyk bron",
@@ -86,13 +92,10 @@ OC.L10N.register(
     "Remove account" : "Verwyder rekening",
     "Loading …" : "Laai …",
     "New message" : "Nuwe boodskap",
-    "Refresh" : "Verfris",
     "Retry" : "Herprobeer",
     "Sending …" : "Stuur…",
-    "Delete" : "Skrap",
     "Add" : "Voeg by",
     "Tags" : "Etikette",
-    "Search" : "Soek",
     "Date" : "Datum",
     "Custom" : "Eie",
     "Message source" : "Boodskapbron",
@@ -106,9 +109,6 @@ OC.L10N.register(
     "Valid until" : "Geldig tot",
     "Certificate" : "Sertifikaat",
     "Submit" : "Dien in",
-    "Keyboard shortcut" : "Snelsleutel",
-    "Keyboard shortcuts" : "Sneltoetse",
-    "Archive" : "Argief",
     "Connect your mail account" : "Koppel u posrekening",
     "All" : "Alle",
     "Drafts" : "Konsepte",
