@@ -13,34 +13,43 @@ OC.L10N.register(
     "SMTP Password" : "SMTP Şifrəsi",
     "Save" : "Saxla",
     "Connect" : "Qoşul",
+    "Signature" : "İmza",
     "Cancel" : "Dayandır",
-    "Enter a date" : "Tarixi əlavə edin",
+    "Archive" : "Arxiv",
+    "Delete" : "Sil",
+    "Search" : "Axtarış",
     "Send" : "Göndər",
+    "Refresh" : "Yenilə",
+    "Subject" : "Mövzu",
+    "Enter a date" : "Tarixi əlavə edin",
     "Choose a file to add as attachment" : "Əlavə ediləcək faylı seçin",
+    "Choose" : "Seç",
+    "Confirm" : "Təsdiq edin",
     "Favorite" : "İstəkli",
     "Read" : "Oxu",
     "Select" : "Select",
+    "Back" : "Geri",
+    "Description" : "Açıqlanma",
     "Create" : "Yarat",
     "Comment" : "Komentariya",
     "Accept" : "Qəbul et",
-    "Choose" : "Seç",
+    "Decline" : "İmtina",
     "Other" : "Digər",
     "Reply" : "Cavab",
     "Choose a folder to store the attachment in" : "Əlavələrin saxlanılması üçün qovluğu seçin",
     "Move" : "Move",
     "Quota" : "Norma",
+    "Saving" : "Saxlanılır",
     "Mark all as read" : "Hamısını oxunulmuş kimi qeydə al",
     "Clear cache" : "Keşi təmizlə",
-    "Refresh" : "Yenilə",
     "Sending …" : "Göndərilir...",
-    "Delete" : "Sil",
     "Add" : "Əlavə etmək",
     "Close" : "Bağla",
     "Tags" : "Işarələr",
-    "Search" : "Axtarış",
     "Date" : "Date",
     "Disabled" : "Dayandırılıb",
     "Enabled" : "İşə salınıb",
+    "Not found" : "Tapılmadı",
     "Remove" : "Sil",
     "Reset" : "Sıfırla",
     "Client ID" : "Müştəri İD-s",
@@ -50,7 +59,7 @@ OC.L10N.register(
     "Host" : "Şəbəkədə ünvan",
     "Port" : "Port",
     "Valid until" : "Vaxtadək keçərlidir",
-    "Archive" : "Arxiv",
+    "Certificate" : "Sertifikat",
     "All" : "Hamısı",
     "Drafts" : "Qaralamalar",
     "Favorites" : "Sevimlilər",
