@@ -75,7 +75,6 @@ OC.L10N.register(
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Автоматичен отговор на входящите съобщения. Ако някой ви изпрати няколко съобщения, този автоматичен отговор ще бъде изпращан най-много веднъж на всеки 4 дни.",
     "Please connect to a sieve server first." : "Моля да се свържете първо със сървъра на ситото",
     "Sieve filter rules" : "Правила за филтриране чрез сито",
-    "Trusted senders" : "Доверени податели",
     "Mail server" : "Имейл сървър",
     "Sieve filter server" : "Сървър за сито филтър",
     "Update alias" : "Актуализиране на псевдоним",
@@ -88,16 +87,29 @@ OC.L10N.register(
     "Add alias" : "Добавяне на псевдоним",
     "Create alias" : "Създаване на псевдоним",
     "Cancel" : "Отказ",
+    "Mail settings" : "Настройки на пощата",
+    "List" : "Списък",
     "Add mail account" : "Добавяне на профил",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Разрешаване на приложението да събира данни за вашите взаимодействия. Въз основа на тези данни приложението ще се адаптира към вашите предпочитания. Данните ще се съхраняват само локално.",
+    "Trusted senders" : "Доверени податели",
     "Use Gravatar and favicon avatars" : "Използване на аватари тип Gravatar и favicon",
     "Register as application for mail links" : "Регистрирайте се като приложение за пощенски връзки",
-    "Show keyboard shortcuts" : "Показване на клавишни комбинации",
+    "Register" : "Регистрация",
     "Manage S/MIME certificates" : "Управление на S/MIME сертификати",
     "Newest" : "Най-новият",
     "Oldest" : "Най-старият",
     "Looking for a way to encrypt your emails?" : "Търсите ли начин да шифровате имейлите си?",
-    "Install Mailvelope browser extension here" : "Инсталирайте тук разширението за браузър Mailvelope",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Разрешаване на приложението да събира данни за вашите взаимодействия. Въз основа на тези данни приложението ще се адаптира към вашите предпочитания. Данните ще се съхраняват само локално.",
+    "Keyboard" : "Клавиатура",
+    "Compose new message" : "Създай ново съобщение",
+    "Newer message" : "Следващо съобщение",
+    "Older message" : "Предишно съобщение",
+    "Toggle star" : "Означи със/Премахни звезда",
+    "Toggle unread" : "Означи като (не)/прочетено",
+    "Archive" : "Архивиране",
+    "Delete" : "Изтриване",
+    "Search" : "Търси",
+    "Send" : "Изпрати",
+    "Refresh" : "Опресняване",
     "Put my text to the bottom of a reply instead of on top of it." : "Поставяне на моя текст в долната част на отговора, вместо над него.",
     "Automatically classify importance of new email" : "Автоматично класифициране на важността на новия имейл",
     "Could not update preference" : "Предпочитанието не можа да се актуализира",
@@ -110,11 +122,11 @@ OC.L10N.register(
     "From" : "От",
     "Select account" : "Избери профил",
     "To" : "До",
+    "Select recipient" : "Избор на получател",
     "Contact or email address …" : "Контакт или имейл адрес...",
     "Toggle recipients list mode" : "Превключете в режима на списък с получатели",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
-    "No contacts found." : "Няма намерени контакти.",
     "Subject" : "Тема",
     "Subject …" : "Тема...",
     "This message came from a noreply address so your reply will probably not be read." : "Това съобщение дойде от адрес с настройка без отговор, така че отговорът ви вероятно няма да бъде прочетен.",
@@ -126,12 +138,12 @@ OC.L10N.register(
     "Draft saved" : "Черновата записана",
     "Save draft" : "Запиши чернова",
     "Discard & close draft" : "Отхвърляне и затворяне на черновата",
+    "Enable formatting" : "Форматиран текст",
+    "Disable formatting" : "Деактивиране на форматирането",
     "Upload attachment" : "Качи прикачен файл/ове",
     "Add attachment from Files" : "Прикачи от \"Файлове\"",
     "Smart picker" : "Смарт /интелигентен/ инструмент за избор",
     "Send later" : "Изпратете по-късно",
-    "Enable formatting" : "Форматиран текст",
-    "Disable formatting" : "Деактивиране на форматирането",
     "Request a read receipt" : "Заявка на разписка за четене",
     "Sign message with S/MIME" : "Подписване на съобщение със S/MIME/сертификат/",
     "Encrypt message with S/MIME" : "Криптиране на съобщение със S/MIME",
@@ -147,7 +159,6 @@ OC.L10N.register(
     "Encrypt with S/MIME and send" : "Криптиране със S/MIME и изпращане",
     "Encrypt with Mailvelope and send later" : "Криптиране с Mailvelope и изпращане по-късно",
     "Encrypt with Mailvelope and send" : "Криптиране с Mailvelope и изпращане",
-    "Send" : "Изпрати",
     "Message {id} could not be found" : "Съобщението {id} не можа да бъде намерено",
     "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Избрано е подписване или криптиране със S/MIME, но нямаме сертификат за избрания псевдоним. Съобщението няма да бъде подписано или криптирано.",
     "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Всяко съществуващо форматиране (например удебеляване, курсив, подчертани или вградени изображения) ще бъде премахнато.",
@@ -156,6 +167,7 @@ OC.L10N.register(
     "Keep formatting" : " Запазване /продължаване/ на форматирането",
     "Choose a file to add as attachment" : "Избери файл за прикачване",
     "Choose a file to share as a link" : "Изберете файл, който да споделите като връзка",
+    "Choose" : "Изберете",
     "_{count} attachment_::_{count} attachments_" : ["{count} прикачени файлове","{count} прикачени файлове"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Прикачените файлове надвишават разрешения размер на прикачени файлове от {size}. Моля, вместо това да споделите файловете чрез връзка.","Прикачените файлове надвишават разрешения размер на прикачени файлове от {size}. Моля, вместо това да споделите файловете чрез връзка."],
     "Confirm" : "Потвърдете",
@@ -233,7 +245,6 @@ OC.L10N.register(
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Нямате право да преместите това съобщение в архивната папка и/или да изтриете това съобщение от текущата папка",
     "Choose target mailbox" : "Избор на целева пощенска кутия ",
     "No more submailboxes in here" : "Тук няма повече допълнителни пощенски кутии",
-    "Choose" : "Изберете",
     "Important info" : "Важна информация",
     "Other" : "Друг",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Съобщенията автоматично ще бъдат маркирани като важни въз основа на съобщенията, с които сте взаимодействали или маркирани като важни. В началото може да се наложи ръчно да промените важността, за да обучите системата, но тя ще се подобри с течение на времето.",
@@ -273,7 +284,6 @@ OC.L10N.register(
     "Moving" : "Преместване ",
     "Moving thread" : "Нишката се премества",
     "Moving message" : "Съобщението се премества",
-    "Mail settings" : "Настройки на пощата",
     "Provisioned account is disabled" : "Осигуреният профил е деактивиран",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Моля, да се впишете с парола, за да активирате този профил. Текущата сесия използва удостоверяване без парола, напр. SSO или WebAuthn.",
     "Quota" : "Квота",
@@ -312,7 +322,6 @@ OC.L10N.register(
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочетени от {total}","{unread} непрочетени от {total}"],
     "Outbox" : "Изходящи",
     "New message" : "Ново съобщение",
-    "Refresh" : "Опресняване",
     "Error sending your message" : "Грешка при изпращне на вашето съобщение.",
     "Retry" : "Опитай отново",
     "Uploading attachments …" : "Качване на прикачените файлове ...",
@@ -335,7 +344,6 @@ OC.L10N.register(
     "Save autoresponder" : "Записване на автоматичен отговор",
     "Could not open outbox" : "Не можаха да се отворят изходящите",
     "Pending or not sent messages will show up here" : "Чакащи или неизпратени съобщения ще се показват тук",
-    "Delete" : "Изтриване",
     "Message could not be sent" : "Съобщението не можа да бъде изпратено",
     "Message deleted" : "Съобщението е изтрито ",
     "Contacts with this address" : "Контакти с този адрес",
@@ -361,7 +369,6 @@ OC.L10N.register(
     "Marked as" : "Маркиран/о като",
     "Has attachments" : "Има прикачени файлове",
     "Clear" : "Изчистване",
-    "Search" : "Търси",
     "Date" : "Дата",
     "Disabled" : "Изключено",
     "Enabled" : "Включено",
@@ -379,8 +386,8 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Подписът ви е по-голям от 2 MB. Това може да се отрази на работата на  вашия редактор.",
     "Save signature" : "Запис на подпис",
     "Place signature above quoted text" : "Поставяне на подпис над цитирания текст",
-    "Delete tag" : "Изтрий таг",
     "Saving new tag name …" : "Запазва се името на нов етикет …",
+    "Delete tag" : "Изтрий таг",
     "Set tag" : "Задаване на етикет",
     "Unset tag" : "Отмяна на етикет",
     "An error occurred, unable to rename the tag." : "Възникна грешка, не може да се преименува етикет.",
@@ -525,15 +532,6 @@ OC.L10N.register(
     "Certificate imported successfully" : "Успешно импортиране на сертификата",
     "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Неуспешно импортиране на сертификата. Моля, уверете се, че частният ключ съответства на сертификата и не е защитен с парола.",
     "Failed to import the certificate" : "Неуспешно импортиране на сертификата",
-    "Keyboard shortcut" : "Клавишни комбинации",
-    "Keyboard shortcuts" : "Бързи клавиши",
-    "Speed up your Mail experience with these quick shortcuts." : "Ускорете работата си с пощата с тези бързи преки пътища.",
-    "Compose new message" : "Създай ново съобщение",
-    "Newer message" : "Следващо съобщение",
-    "Older message" : "Предишно съобщение",
-    "Toggle star" : "Означи със/Премахни звезда",
-    "Toggle unread" : "Означи като (не)/прочетено",
-    "Archive" : "Архивиране",
     "Account connected" : "Профилът е свързан",
     "You can close this window" : "Можете да затворите този прозорец",
     "Connect your mail account" : "Свързване към ваш имейл профил",
