@@ -12,16 +12,20 @@ OC.L10N.register(
     "Connect" : "সংযুক্ত হও",
     "Go back" : "ফিরে যাও",
     "Cancel" : "বাতির",
+    "Delete" : "মুছে",
+    "Search" : "Search",
     "Send" : "পাঠাও",
+    "Refresh" : "নবোদ্যম",
     "Choose a file to add as attachment" : "সংযুক্তি দেয়ার জন্য একটি ফাইল নির্বাচন করুন",
+    "Choose" : "বেছে নিন",
     "Favorite" : "প্রিয়জন",
     "Read" : "পড়",
     "Select" : "সিলেক্ট",
     "Edit tags" : "ট্যাগ সম্পাদনা",
     "Back" : "পেছনে যাও",
+    "Description" : "বিবরণ",
     "Create" : "তৈরী কর",
     "Comment" : "মন্তব্য",
-    "Choose" : "বেছে নিন",
     "Other" : "অন্যান্য",
     "Reply" : "জবাব",
     "Choose a folder to store the attachment in" : "সংযুক্তি সংরক্ষনের জন্য একটি ফোল্ডার নির্বাচন করুন",
@@ -29,13 +33,10 @@ OC.L10N.register(
     "Quota" : "কোটা",
     "Mark all as read" : "সব পঠিত হিসেবে চিহ্নিত কর",
     "Clear cache" : "ক্যাশে পরিষ্কার কর",
-    "Refresh" : "নবোদ্যম",
     "Sending …" : "পাঠানো হচ্ছে......",
-    "Delete" : "মুছে",
     "Add" : "যোগ করুন",
     "Close" : "বন্ধ",
     "Tags" : "ট্যাগ",
-    "Search" : "Search",
     "Date" : "Date",
     "Disabled" : "অকার্যকর",
     "Enabled" : "কার্যকর",
@@ -46,7 +47,6 @@ OC.L10N.register(
     "User" : "User",
     "Host" : "হোস্ট",
     "Port" : "পোর্ট",
-    "Keyboard shortcuts" : "কী-বোর্ড শর্টকাট",
     "All" : "সবাই",
     "Favorites" : "প্রিয়জন"
 },
