@@ -17,7 +17,12 @@ OC.L10N.register(
     "Password required" : "Ger-tremen ret",
     "Change name" : "Cheñch env",
     "Cancel" : "Arrest",
+    "List" : "Roll",
+    "Delete" : "Dilemel",
+    "Search" : "Klask",
     "Send" : "Kas",
+    "Refresh" : "Freskaat",
+    "Choose" : "Dibab",
     "Confirm" : "Kadarnañ",
     "Unfavorite" : "Digaretañ",
     "Favorite" : "Pennrollañ",
@@ -25,10 +30,10 @@ OC.L10N.register(
     "Select" : "Dibab",
     "Back" : "Distro",
     "Forward" : "War-raok",
+    "Description" : "Deskrivadur",
     "Create" : "Krouiñ",
     "Comment" : "Displegadenn",
     "Accept" : "Asantiñ",
-    "Choose" : "Dibab",
     "Important info" : "Titouroù pouezus",
     "Other" : "All",
     "Reply" : "Respont",
@@ -40,14 +45,11 @@ OC.L10N.register(
     "Loading …" : "O Kargañ ...",
     "Edit name" : "Ebmann anv",
     "Clear cache" : "Gwalc'hiñ ar c'hache",
-    "Refresh" : "Freskaat",
     "Retry" : "Klaskit en dro",
-    "Delete" : "Dilemel",
     "Add" : "Ouzhpennañ",
     "Close" : "Serriñ",
     "Tags" : "Klavioù",
     "Clear" : "Netaat",
-    "Search" : "Klask",
     "Date" : "Deiz",
     "Disabled" : "Disaotreañ",
     "Enabled" : "Aotreet",
