@@ -85,7 +85,6 @@ OC.L10N.register(
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automatická odpověď na příchozí zprávy. Pokud vám někdo pošle vícero zpráv, tato automatická odpověď bude odeslána nanejvýš co 4 dny.",
     "Please connect to a sieve server first." : "Nejprve se prosím připojte k sieve serveru.",
     "Sieve filter rules" : "Pravidla sieve filtru",
-    "Trusted senders" : "Důvěryhodní odesílatelé",
     "Mail server" : "E-mailový server",
     "Sieve filter server" : "Filtrovací server sieve",
     "Mailbox search" : "Hledání ve schránce",
@@ -99,17 +98,43 @@ OC.L10N.register(
     "Add alias" : "Přidat alternativní název",
     "Create alias" : "Vytvořit alternativní název",
     "Cancel" : "Storno",
+    "Mail settings" : "Nastavení pro E-mail",
+    "Layout" : "Rozvržení",
+    "List" : "Seznam",
+    "Account creation" : "Vytváření účtů",
     "Add mail account" : "Přidat e-mailový účet",
+    "Activate body search" : "Zapnout hledání v těle",
+    "Data collection consent" : "Souhlas se shromažďováním dat",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Povolit aplikaci shromažďovat data o vaší interakci s ní. Na základě těchto dat se aplikace přizpůsobí vašim preferencím. Data budou ukládána pouze lokálně.",
+    "Auto tagging text" : "Text automatického opatřování štítkem",
+    "Trusted senders" : "Důvěryhodní odesílatelé",
+    "Gravatar settings" : "Nastavení pro gravatar",
     "Use Gravatar and favicon avatars" : "Použít Gravatar a favicon avatary",
+    "Reply text position" : "Pozice textu odpovědi",
+    "Mailto" : "Příjemce",
     "Register as application for mail links" : "Zaregistrovat jako aplikaci pro obsluhu e-mailových odkazů",
-    "Show keyboard shortcuts" : "Zobrazit klávesové zkratky",
+    "Register" : "Registrovat",
+    "S/MIME" : "S/MIME",
     "Manage S/MIME certificates" : "Spravovat S/MIME certifikáty",
+    "Sorting" : "Řazení",
     "Newest" : "Nejnovější",
     "Oldest" : "Nejstarší",
+    "Mailvelope" : "Mailvelope",
     "Looking for a way to encrypt your emails?" : "Hledáte způsob jak šifrovat své e-maily?",
-    "Install Mailvelope browser extension here" : "Nainstalujte si rozšíření pro webový prohlížeč Mailvelope zde",
+    "Install Mailvelope browser extension by clicking here" : "Kliknutím sem si nainstalujte rozšíření pro webový prohlížeč Mailvelope",
+    "Keyboard" : "Klávesnice",
+    "Compose new message" : "Napsat novou zprávu",
+    "Newer message" : "Novější zpráva",
+    "Older message" : "Starší zpráva",
+    "Toggle star" : "Přidat/odebrat hvězdičku",
+    "Toggle unread" : "Označit jako přečtené/nepřečtené",
+    "Archive" : "Archiv",
+    "Delete" : "Smazat",
+    "Search" : "Hledat",
+    "Send" : "Odeslat",
+    "Refresh" : "Načíst znovu",
     "Search in the body of messages in priority Inbox" : "Hledat v těle zpráv v prioritní schránce",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Povolit aplikaci shromažďovat data o vaší interakci s ní. Na základě těchto dat se aplikace přizpůsobí vašim preferencím. Data budou ukládána pouze lokálně.",
+    "Activate" : "Aktivovat",
     "Put my text to the bottom of a reply instead of on top of it." : "Můj text umístit na konec odpovědi namísto na její začátek.",
     "Automatically classify importance of new email" : "Automaticky klasifikovat důležitost nového e-mailu",
     "Could not update preference" : "Prioritu se nedaří aktualizovat",
@@ -122,11 +147,11 @@ OC.L10N.register(
     "From" : "Od",
     "Select account" : "Vybrat účet",
     "To" : "Pro",
+    "Select recipient" : "Vybrat příjemce",
     "Contact or email address …" : "Kontakt nebo e-mailová adresa…",
     "Toggle recipients list mode" : "Přepnout režim seznamu příjemců",
     "Cc" : "Kopie",
     "Bcc" : "Skrytá kopie",
-    "No contacts found." : "Nenalezeny žádné kontakty.",
     "Subject" : "Předmět",
     "Subject …" : "Předmět…",
     "This message came from a noreply address so your reply will probably not be read." : "Tato zpráva pochází z adresy noreply (neodpovídat), takže vaše odpověď pravděpodobně nebude přečtena.",
@@ -138,12 +163,12 @@ OC.L10N.register(
     "Draft saved" : "Koncept uložen",
     "Save draft" : "Uložit koncept",
     "Discard & close draft" : "Zahodit a zavřít koncept",
+    "Enable formatting" : "Povolit formátování",
+    "Disable formatting" : "Odebrat formátování",
     "Upload attachment" : "Nahrát přílohu",
     "Add attachment from Files" : "Přidat přílohu ze Souborů",
     "Smart picker" : "Inteligentní výběr",
     "Send later" : "Odeslat později",
-    "Enable formatting" : "Povolit formátování",
-    "Disable formatting" : "Odebrat formátování",
     "Request a read receipt" : "Vyžádat potvrzení o přečtení",
     "Sign message with S/MIME" : "Podepsat zprávu pomocí S/MIME",
     "Encrypt message with S/MIME" : "Zašifrovat zprávu pomocí S/MIME",
@@ -159,7 +184,6 @@ OC.L10N.register(
     "Encrypt with S/MIME and send" : "Zašifrovat pomocí S/MIME a odeslat",
     "Encrypt with Mailvelope and send later" : "Zašifrovat pomocí Mailvelope a odeslat později",
     "Encrypt with Mailvelope and send" : "Zašifrovat pomocí Mailvelope a odeslat",
-    "Send" : "Odeslat",
     "Message {id} could not be found" : "Zprávu {id} nelze najít",
     "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Bylo vybráno podepsání či šifrování pomocí S/MIME, ale pro zvolený alternativní název není k dispozici certifikát. Tato zpráva nebude podepsána či šifrována.",
     "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Jakékoli existující formátování (např. tučné, skloněné, podtržené nebo obrázky v textu) bude odebráno.",
@@ -168,6 +192,7 @@ OC.L10N.register(
     "Keep formatting" : "Ponechat formátování",
     "Choose a file to add as attachment" : "Vyberte soubor k přiložení",
     "Choose a file to share as a link" : "Zvolte soubor, který sdílet jako odkaz",
+    "Choose" : "Vybrat",
     "_{count} attachment_::_{count} attachments_" : ["{count} příloha","{count} přílohy","{count} příloh","{count} přílohy"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Přílohy překračují povolenou velikost příloh {size}. Místo toho prosím sdílejte soubor prostřednictvím odkazu.","Přílohy překračují povolenou velikost příloh {size}. Místo toho prosím sdílejte soubory prostřednictvím odkazu.","Přílohy překračují povolenou velikost příloh {size}. Místo toho prosím sdílejte souborů prostřednictvím odkazu.","Přílohy překračují povolenou velikost příloh {size}. Místo toho prosím sdílejte soubory prostřednictvím odkazu."],
     "Expand composer" : "Rozbalit dialog psaní",
@@ -236,6 +261,8 @@ OC.L10N.register(
     "_Delete {number} thread_::_Delete {number} threads_" : ["Smazat {number} vlákno","Smazat {number} vlákna","Smazat {number} vláken","Smazat {number} vlákna"],
     "Report this bug" : "Nahlásit tuto chybu",
     "All day" : "Celý den",
+    "Select calendar" : "Vybrat kalendář",
+    "Description" : "Popis",
     "Create" : "Vytvořit",
     "Event created" : "Událost vytvořena",
     "Could not create event" : "Událost se nedaří vytvořit",
@@ -265,7 +292,6 @@ OC.L10N.register(
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Nejste oprávněni přesunout tuto zprávu do archivní složky a/nebo tuto zprávu smazat ze stávající složky",
     "Choose target mailbox" : "Zvolte cílovou schránku",
     "No more submailboxes in here" : "Nejsou zde žádné další dílčí schránky",
-    "Choose" : "Vybrat",
     "Important info" : "Důležité informace",
     "Other" : "Ostatní",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Správy budou automaticky označené jako důležité v závislosti na tom, jakými správami jste se zabývali nebo označili jako důležité. Na začátku bude třeba měnit důležitost ručně a systém tak naučit, ale po čase se to zlepší.",
@@ -311,7 +337,6 @@ OC.L10N.register(
     "Moving" : "Přesouvání",
     "Moving thread" : "Přesouvá se vlákno",
     "Moving message" : "Přesouvá se zpráva",
-    "Mail settings" : "Nastavení pro E-mail",
     "Provisioned account is disabled" : "Předem připravený účet je deaktivován",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Prosíme aktivujte tento účet přihlášením se pomocí hesla. Stávající relace používá bezheslové ověření, např. sjednocené (SSO) nebo WebAuthn.",
     "Quota" : "Kvóta",
@@ -351,7 +376,6 @@ OC.L10N.register(
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} nepřečtený z {total}","{unread} nepřečtené z {total}","{unread} nepřečtených z {total}","{unread} nepřečtené z {total}"],
     "Outbox" : "Odchozí pošta",
     "New message" : "Nová zpráva",
-    "Refresh" : "Načíst znovu",
     "Error sending your message" : "Chyba při odesílání vaší zprávy",
     "Retry" : "Zkusit znovu",
     "Uploading attachments …" : "Nahrávání příloh…",
@@ -374,6 +398,9 @@ OC.L10N.register(
     "Welcome to {cloudName} Mail" : "Vítejte v {cloudName} Poště",
     "Autoresponder off" : "Automatické odpovědi vypnuty",
     "Autoresponder on" : "Automatické odpovědi zapnuty",
+    "Autoresponder follows system settings" : "Automatický odpovídač následuje nastavení systému",
+    "The autoresponder follows your personal absence period settings." : "Automatický odpovídač následuje vaše osobní nastavení období nepřítomnosti",
+    "Edit absence settings" : "Upravit nastavení nepřítomnosti",
     "First day" : "První den",
     "Last day (optional)" : "Poslední den (nepovinné)",
     "${subject} will be replaced with the subject of the message you are responding to" : "${subject} bude nahrazeno předmětem správy na kterou odpovídáte",
@@ -382,7 +409,6 @@ OC.L10N.register(
     "Save autoresponder" : "Uložit automatickou odpověď",
     "Could not open outbox" : "Nepodaří se otevřít odchozí poštu",
     "Pending or not sent messages will show up here" : "Zprávy čekájící na odeslání a ty neodeslané se zobrazí zde",
-    "Delete" : "Smazat",
     "Message could not be sent" : "Zprávu se nepodařilo odeslat",
     "Message deleted" : "Zpráva smazána",
     "Contacts with this address" : "Kontakty s touto adresou",
@@ -410,7 +436,6 @@ OC.L10N.register(
     "Marked as" : "Označeno jako",
     "Has attachments" : "Má přílohy",
     "Clear" : "Vyčistit",
-    "Search" : "Hledat",
     "Date" : "Datum",
     "Enable mail body search" : "Zapnout hledání v těle zprávy",
     "Disabled" : "Vypnuto",
@@ -432,8 +457,8 @@ OC.L10N.register(
     "Save signature" : "Uložit podpis",
     "Place signature above quoted text" : "Vložit podpis nad citovaný text",
     "Edit name or color" : "Upravit název nebo barvu",
-    "Delete tag" : "Smazat štítek",
     "Saving new tag name …" : "Ukládání nového názvu štítku…",
+    "Delete tag" : "Smazat štítek",
     "Set tag" : "Nastavit štítek",
     "Unset tag" : "Zrušit nastavení štítku",
     "An error occurred, unable to rename the tag." : "Došlo k chybě, štítek se nedaří přejmenovat.",
@@ -442,8 +467,8 @@ OC.L10N.register(
     "Saving tag …" : "Ukládání štítku…",
     "Tag name is a hidden system tag" : "Takto nazvaný štítek už existuje v podobě skrytého systémového štítku",
     "Tag already exists" : "Štítek už existuje",
+    "Tag name cannot be empty" : "Štítek je třeba nějak nazvat",
     "An error occurred, unable to create the tag." : "Došlo k chybě, štíte se nepodařilo vytvořit.",
-    "Select calendar" : "Vybrat kalendář",
     "No calendars with task list support" : "Nejsou zde žádné kalendáře, které by podporovaly seznam úkolů",
     "Task created" : "Úkol vytvořen",
     "Could not create task" : "Úkol se nezdařilo vytvořit",
@@ -509,8 +534,6 @@ OC.L10N.register(
     "Provision all accounts" : "Zprovoznit službu pro všechny účty",
     "Allow additional mail accounts" : "Umožnit ještě další e-mailové účty",
     "Allow additional Mail accounts from User Settings" : "Umožnit v nastaveních pro uživatele zadávat ještě další e-mailové účty",
-    "Enable thread summary" : "Zapnout vytváření souhrnu vlákna",
-    "Enable thread summaries" : "Zapnout vytváření souhrnů vláken",
     "Anti Spam Service" : "Služba ochrany před nevyžádanou poštou",
     "You can set up an anti spam service email address here." : "Adresu e-mailu služby proti spam zprávám je možné nastavit zde.",
     "Any email that is marked as spam will be sent to the anti spam service." : "Jakýkoli e-mail, označený jako spam bude odeslán na službu proti nevyžádaným zprávám.",
@@ -597,15 +620,6 @@ OC.L10N.register(
     "Certificate imported successfully" : "Certifikát úspěšně naimportován",
     "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Certifikát se nepodařilo naimportovat. Ověřte, že se soukromý klíč shoduje s certifikátem a že není chráněn heslovou frází.",
     "Failed to import the certificate" : "Certifikát se nepodařilo naimportovat",
-    "Keyboard shortcut" : "Klávesová zkratka",
-    "Keyboard shortcuts" : "Klávesové zkratky",
-    "Speed up your Mail experience with these quick shortcuts." : "Zrychlete své používání aplikace E-mail pomocí těchto pohotových zkratek.",
-    "Compose new message" : "Napsat novou zprávu",
-    "Newer message" : "Novější zpráva",
-    "Older message" : "Starší zpráva",
-    "Toggle star" : "Přidat/odebrat hvězdičku",
-    "Toggle unread" : "Označit jako přečtené/nepřečtené",
-    "Archive" : "Archiv",
     "Account connected" : "Účet připojen",
     "You can close this window" : "Toto okno je možné zavřít",
     "Connect your mail account" : "Připojit e-mailový účet",
