@@ -31,16 +31,27 @@ OC.L10N.register(
     "Go back" : "Nôl",
     "Email address" : "Cyfeiriad e-bost",
     "Cancel" : "Diddymu",
+    "List" : "Rhestr",
     "Add mail account" : "Ychwanegu cyfrif post",
     "Use Gravatar and favicon avatars" : "Defnyddiwch Gravatar ac afatarau favicon",
-    "Show keyboard shortcuts" : "Dangos llwybrau byr bysellfwrdd",
+    "Register" : "Cofrestru",
+    "Compose new message" : "Ysgrifennu Neges _Newydd",
+    "Newer message" : "Neges diweddarach",
+    "Older message" : "Neges hyn",
+    "Toggle star" : "Toglo seren",
+    "Toggle unread" : "Toglo heb ei darllen",
+    "Archive" : "Archif",
+    "Delete" : "Dileu",
+    "Search" : "Chwilio",
+    "Send" : "Anfon",
+    "Refresh" : "Ail-lwytho",
     "Subject" : "Pwnc",
     "Saving draft …" : "Yn cadw drafft …",
     "Draft saved" : "Cadwyd y drafft",
     "Upload attachment" : "Llwytho atodiad",
     "Add attachment from Files" : "Ychwanegwch atodiad o'r Ffeiliau",
-    "Send" : "Anfon",
     "Choose a file to add as attachment" : "Dewiswch ffeil i'w hychwanegu fel atodiad",
+    "Choose" : "Dewisa",
     "Confirm" : "Cadarnhau",
     "Draft: " : "Drafft:",
     "Favorite" : "Ffefryn",
@@ -49,11 +60,11 @@ OC.L10N.register(
     "Create event" : "Creu digwyddiad",
     "Report this bug" : "Cofnodi'r gwall",
     "All day" : "Drwy'r dydd",
+    "Description" : "Disgrifiad",
     "Create" : "Creu",
     "Comment" : "Sylw",
     "Accept" : "Derbyn",
     "Decline" : "Gwrthod",
-    "Choose" : "Dewisa",
     "Other" : "Arall",
     "Import into calendar" : "Mewnforio i'r calendr",
     "Download attachment" : "Llwytho'r atodiad i lawr",
@@ -68,16 +79,13 @@ OC.L10N.register(
     "Mark all as read" : "Marcio'r cyfan wedi'u darllen",
     "Edit name" : "Golygu enw",
     "New message" : "Neges newydd",
-    "Refresh" : "Ail-lwytho",
     "Error sending your message" : "Gwall wrth anfon eich neges",
     "Retry" : "Ceisio eto",
     "Uploading attachments …" : "Llwytho atodiadau ...",
     "Sending …" : "Anfon",
-    "Delete" : "Dileu",
     "Add" : "Ychwanegu",
     "Close" : "Cau",
     "Tags" : "Tagiau",
-    "Search" : "Chwilio",
     "Date" : "Date",
     "Disabled" : "Analluogwyd",
     "Enabled" : "Galluogwyd",
@@ -89,14 +97,6 @@ OC.L10N.register(
     "General" : "Cyffredinol",
     "User" : "User",
     "Certificate" : "Tystysgrif",
-    "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
-    "Speed up your Mail experience with these quick shortcuts." : "Cyflymwch eich profiad E-bost gyda'r llwybrau byr cyflym hyn.",
-    "Compose new message" : "Ysgrifennu Neges _Newydd",
-    "Newer message" : "Neges diweddarach",
-    "Older message" : "Neges hyn",
-    "Toggle star" : "Toglo seren",
-    "Toggle unread" : "Toglo heb ei darllen",
-    "Archive" : "Archif",
     "Connect your mail account" : "Cysylltu â'r cyfrif e-bost",
     "All" : "Popeth",
     "Drafts" : "Drafftiau",
