@@ -12,6 +12,7 @@ OC.L10N.register(
     "To Do" : "to do -liste",
     "Later" : "Senere",
     "Mail" : "Mail",
+    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Du bruger i øjeblikket {percentage} af din postkasseplads. Frigør plads ved at slette unødvendige e-mails.",
     "Mails" : "Mails",
     "💌 A mail app for Nextcloud" : "💌 En mail app til Nextcloud",
     "Your session has expired. The page will be reloaded." : "Din session er udløbet. Siden vil blive genindlæst.",
@@ -43,6 +44,7 @@ OC.L10N.register(
     "SMTP Password" : "SMTP kodeord",
     "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "For at din Google-konto skal kunne fungere med denne app, skal du aktivere to-faktor-godkendelse for Gmail samt generere en App-specifik adgangskode.",
     "Connecting" : "Tilslutter",
+    "Sign in with Google" : "Log ind med Google",
     "Save" : "Gem",
     "Connect" : "Tilslut",
     "Looking up configuration" : "Søger konfiguration",
@@ -50,6 +52,9 @@ OC.L10N.register(
     "Configuration discovery failed. Please use the manual settings" : "Opdagelse af konfiguration mislykkedes. Brug venligst de manuelle indstillinger",
     "Password required" : "Password påkrævet",
     "Testing authentication" : "Test af autentificering",
+    "Awaiting user consent" : "Afventer brugerens samtykke",
+    "Account created. Please follow the pop-up instructions to link your Google account" : "Konto oprettet. Følg venligst pop-up-instruktionerne for at linke din Google-konto.",
+    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Konto opdateret. Følg venligst pop-up-instruktionerne for at genoprette forbindelsen til din Google-konto.",
     "Account updated" : "Konto opdateret",
     "IMAP server is not reachable" : "IMAP server er ikke tilgængelig",
     "SMTP server is not reachable" : "SMTP server er ikke tilgængelig",
@@ -69,7 +74,6 @@ OC.L10N.register(
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automatisk svar på indgående beskeder. Hvis nogen sender dig flere beskeder, sendes dette automatiske svar højst én gang hver 4. dag.",
     "Please connect to a sieve server first." : "Opret forbindelse til en sieve server først.",
     "Sieve filter rules" : "Sieve filter regler",
-    "Trusted senders" : "Betroede afsendere",
     "Mail server" : "Mail server",
     "Sieve filter server" : "Sigt filter server",
     "Update alias" : "Opdater alias",
@@ -81,25 +85,38 @@ OC.L10N.register(
     "Add alias" : "Tilføj alias",
     "Create alias" : "Opret alias",
     "Cancel" : "Annullér",
+    "Mail settings" : "Mail indstillinger",
+    "List" : "Liste",
     "Add mail account" : "Tilføj mail konto",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Tillad, at appen indsamler data om dine interaktioner. Baseret på disse data vil appen tilpasse sig dine præferencer. Dataene gemmes kun lokalt.",
+    "Trusted senders" : "Betroede afsendere",
     "Use Gravatar and favicon avatars" : "Brug Gravatar og favicon avatarer",
     "Register as application for mail links" : "Registrer som program til at åbne mail links",
-    "Show keyboard shortcuts" : "Vis tastaturgenveje",
+    "Register" : "Registér",
     "Manage S/MIME certificates" : "Administrer S/MIME-certifikater",
+    "Sorting" : "Sortering",
     "Looking for a way to encrypt your emails?" : "Leder du efter en måde at kryptere dine e-mails på?",
-    "Install Mailvelope browser extension here" : "Installer Mailvelope browserudvidelse her",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Tillad, at appen indsamler data om dine interaktioner. Baseret på disse data vil appen tilpasse sig dine præferencer. Dataene gemmes kun lokalt.",
+    "Compose new message" : "Skriv en ny meddelelse",
+    "Newer message" : "Nyere besked",
+    "Older message" : "Ældre besked",
+    "Toggle star" : "Toggle stjerne",
+    "Toggle unread" : "Toggle læst",
+    "Archive" : "Arkivér",
+    "Delete" : "Slet",
+    "Search" : "Søg",
+    "Send" : "Send",
+    "Refresh" : "Opdatér",
     "Put my text to the bottom of a reply instead of on top of it." : "Sæt min tekst til bunden af et svar i stedet for oven på den.",
     "Automatically classify importance of new email" : "Klassificer automatisk vigtigheden af ny e -mail",
     "Could not update preference" : "Præference kunne ikke opdateres",
     "From" : "Fra",
     "Select account" : "Vælg konto",
     "To" : "Til",
+    "Select recipient" : "Vælg modtager",
     "Contact or email address …" : "Kontakt eller email…",
     "Toggle recipients list mode" : "Skift modtagerlistetilstand",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
-    "No contacts found." : "Ingen kontakter.",
     "Subject" : "Emne",
     "Subject …" : "Emne…",
     "This message came from a noreply address so your reply will probably not be read." : "Denne meddelelse kom fra en svar-ikke adresse. Dit svar vil sansynligvis ikke blive læst. ",
@@ -111,12 +128,12 @@ OC.L10N.register(
     "Draft saved" : "Kladde gemt",
     "Save draft" : "Gem kladde",
     "Discard & close draft" : "Kassér og luk kladde",
+    "Enable formatting" : "Aktiver formatering",
+    "Disable formatting" : "Deaktiver formatering",
     "Upload attachment" : "Upload vedhæftning",
     "Add attachment from Files" : "Vedhæft fra filer",
     "Smart picker" : "Smart Vælger",
     "Send later" : "Send senere",
-    "Enable formatting" : "Aktiver formatering",
-    "Disable formatting" : "Deaktiver formatering",
     "Request a read receipt" : "Anmod om en læsekvittering",
     "Sign message with S/MIME" : "Underskriv besked med S/MIME",
     "Encrypt message with S/MIME" : "Krypter besked med S/MIME",
@@ -130,7 +147,6 @@ OC.L10N.register(
     "Add share link from {productName} Files" : "Tilføj delingslink fra {productName} filer",
     "Encrypt with S/MIME and send later" : "Krypter med S/MIME og send senere",
     "Encrypt with S/MIME and send" : "Krypter med S/MIME og send",
-    "Send" : "Send",
     "Message {id} could not be found" : "Beskeden {id} kunne ikke findes",
     "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Signer eller krypter med S/MIME blev valgt, men vi har ikke et certifikat for det valgte alias. Beskeden bliver ikke underskrevet eller krypteret.",
     "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Enhver eksisterende formatering (f.eks. fed, kursiv, understregning eller indlejrede billeder) vil blive fjernet.",
@@ -139,6 +155,7 @@ OC.L10N.register(
     "Keep formatting" : "Behold formattering",
     "Choose a file to add as attachment" : "Vælg en fil, der skal tilføjes som vedhæftning",
     "Choose a file to share as a link" : "Vælg en fil der skal deles som link",
+    "Choose" : "Vælg",
     "_{count} attachment_::_{count} attachments_" : ["{count} vedhæftet fil","{count} vedhæftede filer"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Den vedhæftede fil overskrider den tilladte størrelse på vedhæftede filer på {size}. Del venligst filen via link i stedet.","De vedhæftede filer overskrider den tilladte størrelse på vedhæftede filer på {size}. Del venligst filerne via link i stedet."],
     "Confirm" : "Bekræft",
@@ -184,6 +201,7 @@ OC.L10N.register(
     "_Delete {number} thread_::_Delete {number} threads_" : ["Slet {number} tråd","Slet {number} tråde"],
     "Report this bug" : "Rapporter denne fejl",
     "All day" : "Hele dagen",
+    "Description" : "Beskrivelse",
     "Create" : "Opret",
     "Event created" : "Begivenhed oprettet",
     "Could not create event" : "Begivenheden kunne ikke oprettes",
@@ -210,7 +228,6 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksering af dine beskeder. Dette kan tage lidt længere tid for større postkasser.",
     "Choose target mailbox" : "Vælg målpostkasse",
     "No more submailboxes in here" : "Ikke flere underpostkasser herinde",
-    "Choose" : "Vælg",
     "Important info" : "Vigtig information",
     "Other" : "Andet",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Beskeder vil automatisk blive markeret som vigtige baseret på, hvilke meddelelser du har interageret med eller markeret som vigtige. I begyndelsen skal du muligvis manuelt ændre vigtigheden for at lære systemet, men det vil forbedres med tiden.",
@@ -232,7 +249,6 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Dette billede er blevet blokeret for at beskytte din privat liv",
     "Show images" : "Vis billeder",
     "Move" : "Flyt",
-    "Mail settings" : "Mail indstillinger",
     "Quota" : "Kvote",
     "Show only subscribed mailboxes" : "Vis kun postkasser der abonneres på",
     "Add mailbox" : "Tilføj postkasse",
@@ -258,7 +274,6 @@ OC.L10N.register(
     "_{total} message_::_{total} messages_" : ["{total} besked","{total} beskeder"],
     "Outbox" : "Udbakke",
     "New message" : "Ny besked",
-    "Refresh" : "Opdatér",
     "Error sending your message" : "Fejl ved afsendelse af din besked",
     "Retry" : "Prøv igen",
     "Uploading attachments …" : "Uploader vedhæftninger",
@@ -267,9 +282,9 @@ OC.L10N.register(
     "Send anyway" : "Send alligevel",
     "No sent mailbox configured. Please pick one in the account settings." : "Ingen sendt postkasse konfigureret. Vælg en i kontoindstillingerne.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Du prøver at sende til mange modtagere i Til og/eller Cc. Overvej at bruge Bcc til at skjule modtageradresser.",
+    "First day" : "Første dag",
     "Message" : "Besked",
     "Could not open outbox" : "Kunne ikke åbne udbakken",
-    "Delete" : "Slet",
     "Copy to clipboard" : "Kopier til udklipsholder",
     "Add" : "Tilføj",
     "Search in mailbox" : "Søg i postkasse",
@@ -278,12 +293,11 @@ OC.L10N.register(
     "Body" : "Krop",
     "Pick a start date" : "Vælg en startdato",
     "Pick an end date" : "Vælg en slutdato",
-    "Tags" : "Mærker",
+    "Tags" : "Tags",
     "Select tags" : "Vælg tags",
     "Marked as" : "Markeret som",
     "Has attachments" : "Har vedhæftede filer",
     "Clear" : "Ryd",
-    "Search" : "Søg",
     "Date" : "Dato",
     "Disabled" : "Deaktiveret",
     "Enabled" : "Aktiveret",
@@ -335,15 +349,6 @@ OC.L10N.register(
     "Certificate imported successfully" : "Certifikatet blev importeret",
     "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Kunne ikke importere certifikatet. Sørg for, at den private nøgle matcher certifikatet og ikke er beskyttet af en kode.",
     "Failed to import the certificate" : "Kunne ikke importere certifikatet",
-    "Keyboard shortcut" : "Tastaturgenvej",
-    "Keyboard shortcuts" : "Tastaturgenveje",
-    "Speed up your Mail experience with these quick shortcuts." : "Gør brugen af Mail hurtige med disse genveje.",
-    "Compose new message" : "Skriv en ny meddelelse",
-    "Newer message" : "Nyere besked",
-    "Older message" : "Ældre besked",
-    "Toggle star" : "Toggle stjerne",
-    "Toggle unread" : "Toggle læst",
-    "Archive" : "Arkivér",
     "Account connected" : "Kontoen er tilknyttet",
     "Connect your mail account" : "Forbind din mail konto",
     "All" : "Alle",
