@@ -58,7 +58,6 @@ OC.L10N.register(
     "Preferred writing mode for new messages and replies." : "Προτιμώμενη λειτουργία σύνταξης για νέα μηνύματα και απαντήσεις.",
     "Default folders" : "Προεπιλεγμένοι φάκελοι",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Αυτοματοποιημένη απάντηση σε εισερχόμενα μηνύματα. Εάν κάποιος σας στείλει πολλά μηνύματα, αυτή η αυτοματοποιημένη απάντηση θα αποστέλλεται το πολύ μία φορά κάθε 4 ημέρες.",
-    "Trusted senders" : "Έμπιστοι αποστολείς",
     "Mail server" : "Διακομιστής αλληλογραφίας",
     "Update alias" : "Ενημέρωση ψευδώνυμου",
     "Show update alias form" : "Εμφάνιση φόρμας ενημέρωσης ψευδώνυμου",
@@ -69,13 +68,27 @@ OC.L10N.register(
     "Add alias" : "Προσθήκη alias",
     "Create alias" : "Δημιουργία ψευδωνύμου",
     "Cancel" : "Ακύρωση",
+    "Mail settings" : "Ρυθμίσεις αλληλογραφίας",
+    "List" : "Λίστα",
     "Add mail account" : "Προσθήκη λογαριασμού αλληλογραφίας",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Να επιτρέπεται στην εφαρμογή να συλλέγει δεδομένα σχετικά με την δραστηριότητά σας. Με βάση αυτά τα δεδομένα, η εφαρμογή θα προσαρμοστεί στις προτιμήσεις σας. Τα δεδομένα θα αποθηκευτούν μόνο τοπικά.",
+    "Trusted senders" : "Έμπιστοι αποστολείς",
     "Use Gravatar and favicon avatars" : "Χρησιμοποιήστε Gravatar και favicon avatars",
     "Register as application for mail links" : "Εγγραφή ως εφαρμογή για συνδέσμους αλληλογραφίας",
-    "Show keyboard shortcuts" : "Εμφάνιση συντομεύσεων πληκτρολογίου",
+    "Register" : "Εγγραφή",
+    "Sorting" : "Ταξινόμηση",
     "Newest" : "Νεότερο",
     "Oldest" : "Παλαιότερο",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Να επιτρέπεται στην εφαρμογή να συλλέγει δεδομένα σχετικά με την δραστηριότητά σας. Με βάση αυτά τα δεδομένα, η εφαρμογή θα προσαρμοστεί στις προτιμήσεις σας. Τα δεδομένα θα αποθηκευτούν μόνο τοπικά.",
+    "Compose new message" : "Σύνταξη νέου μηνύματος",
+    "Newer message" : "Νεότερο μήνυμα",
+    "Older message" : "Παλαιότερο μήνυμα",
+    "Toggle star" : "Εναλλαγή αστεριού",
+    "Toggle unread" : "Εναλλαγή αδιάβαστων",
+    "Archive" : "Αρχειοθετημένα",
+    "Delete" : "Διαγραφή",
+    "Search" : "Αναζήτηση",
+    "Send" : "Αποστολή",
+    "Refresh" : "Ανανέωση",
     "Put my text to the bottom of a reply instead of on top of it." : "Το κείμενό μου στο κάτω μέρος μιας απάντησης αντί στο επάνω μέρος της.",
     "Automatically classify importance of new email" : "Αυτόματη ταξινόμηση σπουδαιότητας νέων email",
     "Could not update preference" : "Δεν ήταν δυνατή η ενημέρωση της προτίμησης",
@@ -85,7 +98,6 @@ OC.L10N.register(
     "Contact or email address …" : "Επαφή ή διεύθυνση ηλ.ταχυδρομείου ...",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
-    "No contacts found." : "Δε βρέθηκαν επαφές.",
     "Subject" : "Θέμα",
     "Subject …" : "Θέμα...",
     "This message came from a noreply address so your reply will probably not be read." : "Η αλληλογραφία προέρχεται από διεύθυνση η οποία δεν δέχεται απαντήσεις, οπότε η απάντησή σας πιθανότατα δεν θα διαβαστεί.",
@@ -96,10 +108,10 @@ OC.L10N.register(
     "Draft saved" : "Το πρόχειρο αποθηκεύτηκε",
     "Save draft" : "Αποθήκευση ως πρόχειρο",
     "Discard & close draft" : "Απόρριψη & κλείσιμο πρόχειρου",
+    "Enable formatting" : "Ενεργοποίηση μορφοποίησης",
     "Upload attachment" : "Μεταφόρτωση συνημμένων",
     "Add attachment from Files" : "Προσθήκη συνημμένου από Αρχεία",
     "Send later" : "Αποστολή αργότερα",
-    "Enable formatting" : "Ενεργοποίηση μορφοποίησης",
     "Request a read receipt" : "Ζητήστε βεβαίωση ανάγνωσης",
     "Encrypt message with Mailvelope" : "Κρυπτογράφηση μηνύματος με το Mailvelope",
     "Send now" : "Αποστολή τωρα",
@@ -109,10 +121,10 @@ OC.L10N.register(
     "Custom date and time" : "Επιλέξτε ημερομηνία και ώρα",
     "Enter a date" : "Προσθέστε ημερομηνία",
     "Add share link from {productName} Files" : "Προσθήκη συνδέσμου κοινής χρήσης από αρχεία {productName}",
-    "Send" : "Αποστολή",
     "Message {id} could not be found" : "Δεν ήταν δυνατή η εύρεση του μηνύματος {id}",
     "Choose a file to add as attachment" : "Επιλέξτε ένα αρχείο για να προσθέσετε ως συνημμένο",
     "Choose a file to share as a link" : "Επιλέξτε ένα αρχείο για κοινή χρήση ως σύνδεσμο",
+    "Choose" : "Επιλογή",
     "_{count} attachment_::_{count} attachments_" : ["{count} συνημμένo","{count} συνημμένα"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Το συνημμένο υπερβαίνει το επιτρεπόμενο μέγεθος συνημμένων {size}. Παρακαλούμε διαμοιράστε το αρχείο μέσω συνδέσμου.","Τα συνημμένα υπερβαίνουν το επιτρεπόμενο μέγεθος συνημμένων {size}. Παρακαλούμε διαμοιράστε τα αρχεία μέσω συνδέσμου."],
     "Confirm" : "Επιβεβαίωση",
@@ -162,6 +174,7 @@ OC.L10N.register(
     "_Delete {number} thread_::_Delete {number} threads_" : ["Διαγραφή {number} νημάτος","Διαγραφή {number} νημάτων"],
     "Report this bug" : "Αναφέρετε αυτό το σφάλμα",
     "All day" : "Ολοήμερο",
+    "Description" : "Περιγραφή",
     "Create" : "Δημιουργία",
     "Event created" : "Το συμβάν δημιουργήθηκε",
     "Could not create event" : "Αδυναμία δημιουργίας συμβάντος",
@@ -184,7 +197,6 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Καταλογοποίηση των μηνυμάτων σας. Αυτό μπορεί να διαρκέσει περισσότερο για μεγαλύτερα γραμματοκιβώτια.",
     "Choose target mailbox" : "Επιλέξτε γραμματοκιβώτιο προορισμού",
     "No more submailboxes in here" : "Δεν υπάρχουν άλλα υπο-γραμματοκιβώτια εδώ",
-    "Choose" : "Επιλογή",
     "Important info" : "Σημαντική πλροφορία",
     "Other" : "Άλλο",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Τα μηνύματα θα επισημανθούν αυτόματα ως σημαντικά με βάση αυτά με τα οποία επισημαίνετε ως σημαντικά. Στην αρχή ίσως χρειαστεί να τα αλλάζετε χειροκίνητα, έως ότου εκπαιδευτεί το σύστημα, αλλά θα βελτιώνεται σταδιακά με την πάροδο του χρόνου.",
@@ -205,6 +217,7 @@ OC.L10N.register(
     "Save to Files" : "Αποθήκευση στα Αρχεία",
     "Unnamed" : "Ανώνυμο",
     "Embedded message" : "Ενσωματωμένο μήνυμα",
+    "Next week – {timeLocale}" : "Επόμενη εβδομάδα – {timeLocale}",
     "Choose a folder to store the attachment in" : "Επιλέξτε ένα φάκελο για να αποθηκεύσετε τα συνημμένα",
     "Save all to Files" : "Αποθήκευση όλων στα Αρχεία",
     "Download Zip" : "Λήψη Zip",
@@ -221,7 +234,6 @@ OC.L10N.register(
     "Moving" : "Μετακινείται",
     "Moving thread" : "Μετακίνηση νήματος",
     "Moving message" : "Μετακίνηση μηνύματος",
-    "Mail settings" : "Ρυθμίσεις αλληλογραφίας",
     "Quota" : "Σύνολο χώρου",
     "Show only subscribed mailboxes" : "Εμφάνιση μόνο εγγεγραμμένων γραμματοκιβωτίων",
     "Add mailbox" : "Προσθήκη γραμματοκιβωτίου",
@@ -254,7 +266,6 @@ OC.L10N.register(
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} μη αναγνωσμένο από {total}","{unread} μη αναγνωσμένα από {total}"],
     "Outbox" : "Εξερχόμενα",
     "New message" : "Νέο μήνυμα",
-    "Refresh" : "Ανανέωση",
     "Error sending your message" : "Σφάλμα κατά την αποστολή του μηνύματός σας",
     "Retry" : "Δοκιμή ξανά",
     "Uploading attachments …" : "Ανέβασμα συνημμένων ...",
@@ -269,7 +280,6 @@ OC.L10N.register(
     "Message" : "Μήνυμα",
     "Could not open outbox" : "Αδυναμία ανοίγματος εξερχομένων",
     "Pending or not sent messages will show up here" : "Εδώ εμφανίζονται μηνύματα που εκκρεμούν ή δεν έχουν σταλεί",
-    "Delete" : "Διαγραφή",
     "Message could not be sent" : "Δεν ήταν δυνατή η αποστολή του μηνύματος",
     "Message deleted" : "Το μήνυμα διαγράφτηκε",
     "Contacts with this address" : "Επαφές με αυτήν τη διεύθυνση",
@@ -283,17 +293,17 @@ OC.L10N.register(
     "Tags" : "Ετικέτες",
     "Select tags" : "Επιλέξτε ετικέτες",
     "Clear" : "Εκκαθάριση",
-    "Search" : "Αναζήτηση",
     "Date" : "Ημερομηνία",
     "Disabled" : "Απενεργοποιημένο",
     "Enabled" : "Ενεργοποιημένο",
     "IMAP Credentials" : "Διαπιστευτήρια IMAP",
     "Custom" : "Προσαρμοσμένο",
     "Sieve User" : "Χρήστης Sieve",
+    "This weekend – {timeLocale}" : "Αυτή την εβδομάδα – {timeLocale}",
     "Signature …" : "Υπογραφή...",
     "Save signature" : "Αποθήκευση υπογραφής",
-    "Delete tag" : "Διαγραφή ετικέτας",
     "Saving new tag name …" : "Αποθήκευση νέου ονόματος ετικέτας…",
+    "Delete tag" : "Διαγραφή ετικέτας",
     "An error occurred, unable to rename the tag." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η μετονομασία της ετικέτας.",
     "Add default tags" : "Προσθήκη προεπιλεγμένων ετικετών",
     "Add tag" : "Προσθήκη ετικέτας",
@@ -342,17 +352,10 @@ OC.L10N.register(
     "Valid until" : "Έγκυρο έως",
     "Certificate" : "Πιστοποιητικό",
     "Submit" : "Υποβολή",
-    "Keyboard shortcut" : "Συντόμευση πλητρολογίου",
-    "Keyboard shortcuts" : "Συντομεύσεις πληκτρολογίου",
-    "Speed up your Mail experience with these quick shortcuts." : "Βελτιώστε την ταχύτητά σας στην εμπειρία χρήσης στο πρόγραμμα Αλληλογραφίας με αυτές τις συντομεύσεις.",
-    "Compose new message" : "Σύνταξη νέου μηνύματος",
-    "Newer message" : "Νεότερο μήνυμα",
-    "Older message" : "Παλαιότερο μήνυμα",
-    "Toggle star" : "Εναλλαγή αστεριού",
-    "Toggle unread" : "Εναλλαγή αδιάβαστων",
-    "Archive" : "Αρχειοθετημένα",
     "Account connected" : "Συνδεδεμένος λογαριασμός",
     "Connect your mail account" : "Συνδέστε το λογαριασμό αλληλογραφίας σας",
+    "Tomorrow – {timeLocale}" : "Αύριο – {timeLocale}",
+    "Later today – {timeLocale}" : "Αργότερα σήμερα – {timeLocale}",
     "Itinerary for {type} is not supported yet" : "Η διαδρομή για {type} δεν υποστηρίζεται ακόμα",
     "All" : "'Ολα",
     "Drafts" : "Πρόχειρα",
