@@ -45,24 +45,33 @@ OC.L10N.register(
     "Add mail account" : "Aldoni retpoŝtan konton",
     "Use Gravatar and favicon avatars" : "Uzi servon „Gravatar“ kaj avatarojn en retpaĝsimbolo",
     "Register as application for mail links" : "Registriĝi kiel programeto por retpoŝtligiloj",
-    "Show keyboard shortcuts" : "Montri klavarajn ŝparvojojn",
+    "Register" : "Registriĝi",
+    "Compose new message" : "Krei novan mesaĝon",
+    "Newer message" : "Pli nova mesaĝo",
+    "Older message" : "Pli malnova mesaĝo",
+    "Toggle star" : "Baskuligi stelon",
+    "Toggle unread" : "Baskuligi legostaton",
+    "Archive" : "Arĥivujo",
+    "Delete" : "Forigi",
+    "Search" : "Serĉi",
+    "Send" : "Sendi",
+    "Refresh" : "Aktualigi",
     "From" : "De",
     "Select account" : "Elekti konton",
     "To" : "Al",
     "Contact or email address …" : "Kontakto aŭ retpoŝtadreso …",
-    "No contacts found." : "Neniuj kontaktoj trovitaj.",
     "Subject" : "Temo",
     "Subject …" : "Temo …",
     "This message came from a noreply address so your reply will probably not be read." : "Ĉi tiu mesaĝo venis al neresponda-adreso, do via respondo probable ne legus.",
     "Write message …" : "Verku mesaĝon …",
     "Saving draft …" : "Konservado de malneto...",
     "Draft saved" : "Malneto konservita",
+    "Enable formatting" : "Ebligi formatado",
     "Upload attachment" : "Alŝuti kunsendaĵon",
     "Add attachment from Files" : "Aldoni kunsendaĵojn el „Dosieroj“",
-    "Enable formatting" : "Ebligi formatado",
     "Enter a date" : "Entajpu daton",
-    "Send" : "Sendi",
     "Choose a file to add as attachment" : "Elektu dosieron aldonotan kiel kunsendaĵon",
+    "Choose" : "Elekti",
     "Confirm" : "Konfirmi",
     "Plain text" : "Ebenaĵa teksto",
     "Draft: " : "Malneto:",
@@ -78,6 +87,7 @@ OC.L10N.register(
     "Forward" : "Antaŭen",
     "Report this bug" : "Raporti tiun problemon",
     "All day" : "Tuttage",
+    "Description" : "Priskribo",
     "Create" : "Krei",
     "Could not create event" : "Ne eblis krei okazaĵon",
     "Comment" : "Komento",
@@ -85,7 +95,6 @@ OC.L10N.register(
     "Decline" : "Malakcepti",
     "Could not open mailbox" : "Ne eblis malfermi poŝtkesto",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksas viajn mesaĝojn. Tio eble daŭrus iom pli longe por pli grandaj poŝtkestoj.",
-    "Choose" : "Elekti",
     "Other" : "Alia",
     "Reply" : "Respondi",
     "Reply to sender only" : "Respondi nur al sendinto",
@@ -108,20 +117,17 @@ OC.L10N.register(
     "Clear cache" : "Forviŝi la kaŝmemoron",
     "_{total} message_::_{total} messages_" : ["{total} mesaĝo","{total} mesaĝoj"],
     "New message" : "Nova mesaĝo",
-    "Refresh" : "Aktualigi",
     "Error sending your message" : "Eraro dum sendo de via mesaĝo",
     "Retry" : "Reprovi",
     "Uploading attachments …" : "Alŝutas kunsendaĵojn...",
     "Sending …" : "Sendado...",
     "Message" : "Mesaĝo",
-    "Delete" : "Forigi",
     "Copy to clipboard" : "Kopii tondejen",
     "Add" : "Aldoni",
     "Close" : "Malfermi",
     "Tags" : "Etikedoj",
     "Select tags" : "Elekti etikedojn",
     "Clear" : "Viŝi",
-    "Search" : "Serĉi",
     "Date" : "Date",
     "Disabled" : "Malŝaltita",
     "Enabled" : "Ŝaltita",
@@ -156,14 +162,6 @@ OC.L10N.register(
     "Valid until" : "Valida ĝis",
     "Certificate" : "Atestilo",
     "Submit" : "Sendi",
-    "Keyboard shortcuts" : "Fulmoklavoj",
-    "Speed up your Mail experience with these quick shortcuts." : "Plirapidiĝu per tiuj fulmoklavoj.",
-    "Compose new message" : "Krei novan mesaĝon",
-    "Newer message" : "Pli nova mesaĝo",
-    "Older message" : "Pli malnova mesaĝo",
-    "Toggle star" : "Baskuligi stelon",
-    "Toggle unread" : "Baskuligi legostaton",
-    "Archive" : "Arĥivujo",
     "Account connected" : "Konto konektita",
     "Connect your mail account" : "Konekti vian retpoŝtan konton",
     "All" : "Ĉiuj",
