@@ -30,11 +30,20 @@ OC.L10N.register(
     "Change name" : "Cambiar nombre",
     "Cancel" : "Cancelar",
     "Add mail account" : "Agregar cuenta de correo",
+    "Register" : "Registrar",
+    "Compose new message" : "Redactar nuevo mensaje",
+    "Newer message" : "Mensaje mas nuevo",
+    "Older message" : "Mensaje anterior",
+    "Archive" : "Archivar",
+    "Delete" : "Borrar",
+    "Search" : "Buscar",
+    "Send" : "Enviar",
+    "Refresh" : "Recargar",
     "Select account" : "Seleccione la cuenta",
     "Subject" : "Asunto",
     "Add attachment from Files" : "Agregar adjunto desde Archivos",
-    "Send" : "Enviar",
     "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
+    "Choose" : "Elige",
     "Confirm" : "Confirmar",
     "Favorite" : "Favorito",
     "Read" : "Leer",
@@ -43,12 +52,12 @@ OC.L10N.register(
     "Back" : "Atrás",
     "Forward" : "Reenviar",
     "All day" : "Todo el día",
+    "Description" : "Descripción",
     "Create" : "Crear",
     "Comment" : "Comentario",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
     "More options" : "Más opciones",
-    "Choose" : "Elige",
     "Other" : "Otro",
     "Reply" : "Responder",
     "Import into calendar" : "Importar al calendario",
@@ -66,17 +75,14 @@ OC.L10N.register(
     "Edit name" : "Editar nombre",
     "Clear cache" : "Limpiar caché",
     "New message" : "Mensaje nuevo",
-    "Refresh" : "Recargar",
     "Retry" : "Reintentar",
     "Sending …" : "Enviando ...",
     "Message" : "Mensaje",
-    "Delete" : "Borrar",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Añadir",
     "Close" : "Cerrar",
     "Tags" : "Etiquetas",
     "Clear" : "Borrar",
-    "Search" : "Buscar",
     "Date" : "Fecha",
     "Disabled" : "Deshabilitado",
     "Enabled" : "Habilitado",
@@ -94,13 +100,6 @@ OC.L10N.register(
     "Valid until" : "Válido hasta",
     "Certificate" : "Certificado",
     "Submit" : "Enviar",
-    "Keyboard shortcut" : "Atajo del teclado",
-    "Keyboard shortcuts" : "Atajos de teclado",
-    "Speed up your Mail experience with these quick shortcuts." : "Acelera tu experiencia de correo con estos atajos rápidos.",
-    "Compose new message" : "Redactar nuevo mensaje",
-    "Newer message" : "Mensaje mas nuevo",
-    "Older message" : "Mensaje anterior",
-    "Archive" : "Archivar",
     "Account connected" : "Cuenta conectada",
     "Connect your mail account" : "Conecte su cuenta de correo",
     "All" : "Todos",
