@@ -75,7 +75,6 @@ OC.L10N.register(
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Respuesta automática a mensajes entrantes. Si alguien te envía varios mensajes, esta respuesta automática se enviará como máximo una vez cada 4 días.",
     "Please connect to a sieve server first." : "Por favor, conecta primero con un servidor sieve.",
     "Sieve filter rules" : "Reglas de filtro sieve",
-    "Trusted senders" : "Remitentes de confianza",
     "Mail server" : "Servidor de correo",
     "Sieve filter server" : "Servidor de filtro sieve",
     "Update alias" : "Actualizar alias",
@@ -88,16 +87,29 @@ OC.L10N.register(
     "Add alias" : "Agregar alias",
     "Create alias" : "Crear alias",
     "Cancel" : "Cancelar",
+    "Mail settings" : "Configuración de correo",
     "Add mail account" : "Agregar cuenta de correo",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permitir que la aplicación recopile datos sobre tus interacciones. Con base en estos datos, la aplicación se adaptará a tus preferencias. Los datos se almacenarán solo localmente.",
+    "Trusted senders" : "Remitentes de confianza",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
     "Register as application for mail links" : "Registrarse como aplicación para enlaces de correo",
-    "Show keyboard shortcuts" : "Mostrar accesos directos de teclado",
+    "Register" : "Registrar",
     "Manage S/MIME certificates" : "Administrar certificados S/MIME",
+    "Sorting" : "Ordenar",
     "Newest" : "Más recientes",
     "Oldest" : "Más antiguos",
     "Looking for a way to encrypt your emails?" : "¿Buscas una forma de cifrar tus correos electrónicos?",
-    "Install Mailvelope browser extension here" : "Instala la extensión del navegador Mailvelope aquí",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permitir que la aplicación recopile datos sobre tus interacciones. Con base en estos datos, la aplicación se adaptará a tus preferencias. Los datos se almacenarán solo localmente.",
+    "Keyboard" : "Teclado",
+    "Compose new message" : "Escribir mensaje nuevo",
+    "Newer message" : "Mensaje más nuevo",
+    "Older message" : "Mensaje más antiguo",
+    "Toggle star" : "Alternar favoritos",
+    "Toggle unread" : "Alternar no leídos",
+    "Archive" : "Archivar",
+    "Delete" : "Borrar",
+    "Search" : "Buscar",
+    "Send" : "Enviar",
+    "Refresh" : "Actualizar",
     "Put my text to the bottom of a reply instead of on top of it." : "Colocar mi texto en la parte inferior de una respuesta en lugar de en la parte superior.",
     "Automatically classify importance of new email" : "Clasificar automáticamente la importancia del nuevo correo electrónico",
     "Could not update preference" : "No se pudo actualizar la preferencia",
@@ -114,7 +126,6 @@ OC.L10N.register(
     "Toggle recipients list mode" : "Alternar modo de lista de destinatarios",
     "Cc" : "Cc",
     "Bcc" : "Cco",
-    "No contacts found." : "No se encontraron contactos.",
     "Subject" : "Asunto",
     "Subject …" : "Asunto...",
     "This message came from a noreply address so your reply will probably not be read." : "Este mensaje proviene de una dirección \"noreply\", por lo que probablemente no se lea tu respuesta.",
@@ -126,12 +137,12 @@ OC.L10N.register(
     "Draft saved" : "Borrador guardado",
     "Save draft" : "Guardar borrador",
     "Discard & close draft" : "Descartar y cerrar borrador",
+    "Enable formatting" : "Activar formato",
+    "Disable formatting" : "Desactivar formato",
     "Upload attachment" : "Cargar adjunto",
     "Add attachment from Files" : "Agregar adjunto desd Archivos",
     "Smart picker" : "Selector inteligente",
     "Send later" : "Enviar más tarde",
-    "Enable formatting" : "Activar formato",
-    "Disable formatting" : "Desactivar formato",
     "Request a read receipt" : "Solicitar confirmación de lectura",
     "Sign message with S/MIME" : "Firmar mensaje con S/MIME",
     "Encrypt message with S/MIME" : "Cifrar mensaje con S/MIME",
@@ -147,7 +158,6 @@ OC.L10N.register(
     "Encrypt with S/MIME and send" : "Cifrar con S/MIME y enviar",
     "Encrypt with Mailvelope and send later" : "Cifrar con Mailvelope y enviar más tarde",
     "Encrypt with Mailvelope and send" : "Cifrar con Mailvelope y enviar",
-    "Send" : "Enviar",
     "Message {id} could not be found" : "No se pudo encontrar el mensaje {id}",
     "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Se seleccionó Firmar o Cifrar con S/MIME, pero no tenemos un certificado para el alias seleccionado. El mensaje no será firmado ni cifrado.",
     "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Cualquier formato existente (por ejemplo, negrita, cursiva, subrayado o imágenes en línea) se eliminará.",
@@ -156,6 +166,7 @@ OC.L10N.register(
     "Keep formatting" : "Conservar formato",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
     "Choose a file to share as a link" : "Elige un archivo para compartir como enlace",
+    "Choose" : "Seleccionar",
     "_{count} attachment_::_{count} attachments_" : ["{count} adjunto","{count} adjuntos","{count} adjuntos"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["El archivo adjunto supera el tamaño permitido de archivos adjuntos de {size}. Comparte el archivo a través de un enlace en su lugar.","Los archivos adjuntos superan el tamaño permitido de archivos adjuntos de {size}. Comparte los archivos a través de un enlace en su lugar.","Los archivos adjuntos superan el tamaño permitido de archivos adjuntos de {size}. Comparte los archivos a través de un enlace en su lugar."],
     "Expand composer" : "Expandir redactor",
@@ -207,6 +218,8 @@ OC.L10N.register(
     "_Delete {number} thread_::_Delete {number} threads_" : ["Eliminar {number} hilo","Eliminar {number} hilos","Eliminar {number} hilos"],
     "Report this bug" : "Informar de este error",
     "All day" : "Todo el día",
+    "Select calendar" : "Seleccionar calendario",
+    "Description" : "Descripción",
     "Create" : "Crear",
     "Event created" : "Evento creado",
     "Could not create event" : "No se pudo crear el evento",
@@ -236,7 +249,6 @@ OC.L10N.register(
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "No tienes permiso para mover este mensaje al buzón de archivos y/o eliminar este mensaje de la carpeta actual",
     "Choose target mailbox" : "Selecciona el buzón de destino",
     "No more submailboxes in here" : "No hay más sub-buzones aquí",
-    "Choose" : "Seleccionar",
     "Important info" : "Información importante",
     "Other" : "Otro",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Los mensajes se marcarán automáticamente como importantes en función de los mensajes con los que interactúes o que marques como importantes. Al principio, es posible que debas cambiar manualmente la importancia para enseñar al sistema, pero mejorará con el tiempo.",
@@ -277,7 +289,6 @@ OC.L10N.register(
     "Moving" : "Moviendo",
     "Moving thread" : "Moviendo hilo",
     "Moving message" : "Moviendo mensaje",
-    "Mail settings" : "Configuración de correo",
     "Provisioned account is disabled" : "La cuenta proporcionada está desactivada",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Inicia sesión usando una contraseña para habilitar esta cuenta. La sesión actual está utilizando autenticación sin contraseña, como SSO o WebAuthn.",
     "Quota" : "Cuota",
@@ -316,7 +327,6 @@ OC.L10N.register(
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} sin leer de {total}","{unread} sin leer de {total}","{unread} sin leer de {total}"],
     "Outbox" : "Bandeja de salida",
     "New message" : "Mensaje nuevo",
-    "Refresh" : "Actualizar",
     "Error sending your message" : "Error al enviar tu mensaje",
     "Retry" : "Reintentar",
     "Uploading attachments …" : "Subiendo adjuntos...",
@@ -343,7 +353,6 @@ OC.L10N.register(
     "Save autoresponder" : "Guardar respuesta automática",
     "Could not open outbox" : "No se pudo abrir la bandeja de salida",
     "Pending or not sent messages will show up here" : "Los mensajes pendientes o no enviados aparecerán aquí",
-    "Delete" : "Borrar",
     "Message could not be sent" : "No se pudo enviar el mensaje",
     "Message deleted" : "Mensaje eliminado",
     "Contacts with this address" : "Contactos con esta dirección",
@@ -369,7 +378,6 @@ OC.L10N.register(
     "Marked as" : "Marcado como",
     "Has attachments" : "Tiene archivos adjuntos",
     "Clear" : "Limpiar",
-    "Search" : "Buscar",
     "Date" : "Fecha",
     "Disabled" : "Deshabilitado",
     "Enabled" : "Habilitado",
@@ -398,7 +406,6 @@ OC.L10N.register(
     "Tag name is a hidden system tag" : "El nombre de la etiqueta es una etiqueta oculta del sistema",
     "Tag already exists" : "La etiqueta ya existe",
     "An error occurred, unable to create the tag." : "Ocurrió un error, no se pudo crear la etiqueta.",
-    "Select calendar" : "Seleccionar calendario",
     "No calendars with task list support" : "No hay calendarios con soporte de lista de tareas",
     "Task created" : "Tarea creada",
     "Could not create task" : "No se pudo crear la tarea",
@@ -542,15 +549,6 @@ OC.L10N.register(
     "Certificate imported successfully" : "Certificado importado con éxito",
     "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Error al importar el certificado. Por favor, asegúrate de que la clave privada coincida con el certificado y no esté protegida por una contraseña.",
     "Failed to import the certificate" : "Error al importar el certificado",
-    "Keyboard shortcut" : "Atajo del teclado",
-    "Keyboard shortcuts" : "Atajos del teclado",
-    "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
-    "Compose new message" : "Escribir mensaje nuevo",
-    "Newer message" : "Mensaje más nuevo",
-    "Older message" : "Mensaje más antiguo",
-    "Toggle star" : "Alternar favoritos",
-    "Toggle unread" : "Alternar no leídos",
-    "Archive" : "Archivar",
     "Account connected" : "Cuenta conectada",
     "You can close this window" : "Puedes cerrar esta ventana",
     "Connect your mail account" : "Conecta tu cuenta de correo",
