@@ -28,15 +28,29 @@ OC.L10N.register(
     "Signature" : "Firma",
     "Go back" : "Regresar",
     "Change name" : "Cambiar nombre",
+    "Email address" : "Dirección de correo electrónico",
     "Cancel" : "Cancelar",
     "Add mail account" : "Agregar cuenta de correo",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
+    "Register" : "Registrar",
+    "Sorting" : "Ordenando",
+    "Compose new message" : "Escribir mensaje nuevo",
+    "Newer message" : "Mensaje más nuevo",
+    "Older message" : "Mensaje más antiguo",
+    "Toggle star" : "Alternar favoritos",
+    "Toggle unread" : "Alternar no leídos",
+    "Archive" : "Archivar",
+    "Delete" : "Borrar",
+    "Search" : "Buscar",
+    "Send" : "Enviar",
+    "Refresh" : "Actualizar",
     "Select account" : "Selecciona la cuenta",
     "Subject" : "Asunto",
     "Upload attachment" : "Cargar adjunto",
     "Add attachment from Files" : "Agregar adjunto desd Archivos",
-    "Send" : "Enviar",
+    "Enter a date" : "Ingrese una fecha",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
+    "Choose" : "Seleccionar",
     "Confirm" : "Confirmar",
     "Unfavorite" : "Quitar favorito",
     "Favorite" : "Marcar como favorito",
@@ -47,11 +61,11 @@ OC.L10N.register(
     "Back" : "Atrás",
     "Forward" : "Adelante",
     "All day" : "Todo el día",
+    "Description" : "Descripción",
     "Create" : "Crear",
     "Comment" : "Comentario",
     "Accept" : "Aceptar",
     "Decline" : "Rechazar",
-    "Choose" : "Seleccionar",
     "Other" : "Otro",
     "Reply" : "Responder",
     "Import into calendar" : "Importar al calendario",
@@ -69,24 +83,22 @@ OC.L10N.register(
     "Edit name" : "Editar nombre",
     "Clear cache" : "Borrar el caché",
     "New message" : "Mensaje nuevo",
-    "Refresh" : "Actualizar",
     "Retry" : "Reintentar",
     "Sending …" : "Enviando ...",
     "Message" : "Mensaje",
-    "Delete" : "Borrar",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Agregar",
     "Close" : "Cerrar",
     "Tags" : "Etiquetas",
     "Select tags" : "Selecciona las etiquetas",
     "Clear" : "Limpiar",
-    "Search" : "Buscar",
     "Date" : "Fecha",
     "Disabled" : "Deshabilitado",
     "Enabled" : "Habilitado",
     "Custom" : "Personalizado",
     "Add tag" : "Agregar etiqueta",
     "Tag already exists" : "La etiqueta ya existe",
+    "Not found" : "No encontrado",
     "Remove" : "Eliminar",
     "Reset" : "Reiniciar",
     "Client ID" : "ID del cliente",
@@ -98,15 +110,7 @@ OC.L10N.register(
     "Valid until" : "Válido hasta",
     "Certificate" : "Certificado",
     "Submit" : "Enviar",
-    "Keyboard shortcut" : "Atajo del teclado",
-    "Keyboard shortcuts" : "Atajos del teclado",
-    "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
-    "Compose new message" : "Escribir mensaje nuevo",
-    "Newer message" : "Mensaje más nuevo",
-    "Older message" : "Mensaje más antiguo",
-    "Toggle star" : "Alternar favoritos",
-    "Toggle unread" : "Alternar no leídos",
-    "Archive" : "Archivar",
+    "Account connected" : "Cuenta conectada",
     "Connect your mail account" : "Conecta tu cuenta de correo",
     "All" : "Todos",
     "Drafts" : "Borradores",
