@@ -23,34 +23,45 @@ OC.L10N.register(
     "Connecting" : "Conectando",
     "Save" : "Guardar",
     "Connect" : "Conectar",
+    "Password required" : "Contraseña requerida",
+    "Aliases" : "Aliases",
     "Signature" : "Firma",
+    "Go back" : "Regresar",
     "Cancel" : "Cancelar",
     "Add mail account" : "Agregar cuenta de correo",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
+    "Register" : "Registrar",
+    "Compose new message" : "Escribir mensaje nuevo",
+    "Newer message" : "Mensaje más nuevo",
+    "Older message" : "Mensaje más antiguo",
+    "Toggle star" : "Alternar favoritos",
+    "Toggle unread" : "Alternar no leídos",
+    "Archive" : "Archivar",
+    "Delete" : "Borrar",
+    "Search" : "Buscar",
+    "Send" : "Enviar",
+    "Refresh" : "Actualizar",
     "Select account" : "Selecciona la cuenta",
     "Subject" : "Asunto",
     "Upload attachment" : "Cargar adjunto",
     "Add attachment from Files" : "Agregar adjunto desd Archivos",
-    "Sending …" : "Enviando ...",
-    "Go back" : "Regresar",
-    "Retry" : "Reintentar",
-    "Message sent!" : "¡Mensaje enviado!",
-    "Send" : "Enviar",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
+    "Choose" : "Seleccionar",
+    "Confirm" : "Confirmar",
     "Unfavorite" : "Quitar favorito",
     "Favorite" : "Hacer favorito",
     "Read" : "Leer",
     "Select" : "Seleccionar",
     "Edit tags" : "Editar etiquetas",
-    "Move" : "Mover",
     "More actions" : "Más acciones",
+    "Back" : "Atrás",
     "Forward" : "Adelante",
     "All day" : "Todo el día",
+    "Description" : "Descripción",
     "Create" : "Crear",
     "Comment" : "Comentario",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
-    "Choose" : "Seleccionar",
     "Other" : "Otro",
     "Reply" : "Responder",
     "Import into calendar" : "Importar al calendario",
@@ -60,19 +71,21 @@ OC.L10N.register(
     "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
     "Save all to Files" : "Guardar todo a Archivos",
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
+    "Move" : "Mover",
     "Quota" : "Cuota",
     "Saving" : "Guardando",
     "Remove account" : "Eliminar cuenta",
     "Mark all as read" : "Marcar todos como leídos",
     "Clear cache" : "Borrar el caché",
     "New message" : "Mensaje nuevo",
+    "Retry" : "Reintentar",
+    "Sending …" : "Enviando ...",
     "Message" : "Mensaje",
-    "Delete" : "Borrar",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Agregar",
+    "Close" : "Cerrar",
     "Tags" : "Etiquetas",
     "Select tags" : "Selecciona las etiquetas",
-    "Search" : "Buscar",
     "Date" : "Fecha",
     "Disabled" : "Deshabilitado",
     "Enabled" : "Habilitado",
@@ -86,18 +99,11 @@ OC.L10N.register(
     "User" : "Ususario",
     "Host" : "Servidor",
     "Port" : "Puerto",
-    "Keyboard shortcut" : "Atajo del teclado",
-    "Keyboard shortcuts" : "Atajos del teclado",
-    "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
-    "Compose new message" : "Escribir mensaje nuevo",
-    "Newer message" : "Mensaje más nuevo",
-    "Older message" : "Mensaje más antiguo",
-    "Toggle star" : "Alternar favoritos",
-    "Toggle unread" : "Alternar no leídos",
-    "Refresh" : "Actualizar",
+    "Valid until" : "Válido hasta",
+    "Certificate" : "Certificado",
+    "Submit" : "Enviar",
     "Connect your mail account" : "Conecta tu cuenta de correo",
     "All" : "Todos",
-    "Archive" : "Archivar",
     "Drafts" : "Borradores",
     "Favorites" : "Favoritos",
     "All inboxes" : "Todos los buzones de entrada",
