@@ -28,12 +28,19 @@ OC.L10N.register(
     "Go back" : "Mine tagasi",
     "Email address" : "E-posti aadress",
     "Cancel" : "Loobu",
+    "List" : "Nimekiri",
+    "Register" : "Registreeru",
+    "Archive" : "Arhiiv",
+    "Delete" : "Kustuta",
+    "Search" : "Otsi",
+    "Send" : "Saada",
+    "Refresh" : "Värskenda",
     "From" : "Saatja",
     "To" : "Saaja",
     "Subject" : "Teema",
     "Enter a date" : "Sisesta kuupäev",
-    "Send" : "Saada",
     "Choose a file to add as attachment" : "Vali fail, mida manustada",
+    "Choose" : "Vali",
     "_{count} attachment_::_{count} attachments_" : ["{count} manus","{count} manust"],
     "Confirm" : "Kinnita",
     "Favorite" : "Lemmik",
@@ -44,11 +51,11 @@ OC.L10N.register(
     "Create event" : "Lisa sündmus",
     "Forward" : "Edasi",
     "All day" : "Kogu päev",
+    "Description" : "Kirjeldus",
     "Create" : "Loo",
     "Comment" : "Kommentaar",
     "Accept" : "Nõustu",
     "Decline" : "Keeldu",
-    "Choose" : "Vali",
     "Other" : "Muu",
     "Reply" : "Vasta",
     "Unnamed" : "Nimeta",
@@ -61,17 +68,14 @@ OC.L10N.register(
     "Edit name" : "Muuda nime",
     "Clear cache" : "Tühjenda puhver",
     "New message" : "Uus sõnum",
-    "Refresh" : "Värskenda",
     "Retry" : "Proovi uuesti",
     "Sending …" : "Saadan ...",
     "Message" : "Sõnum",
-    "Delete" : "Kustuta",
     "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
     "Add" : "Lisa",
     "Close" : "Sulge",
     "Tags" : "Sildid",
     "Clear" : "Tühjenda",
-    "Search" : "Otsi",
     "Date" : "Kuupäev",
     "Disabled" : "Keelatud",
     "Enabled" : "Lubatud",
@@ -88,9 +92,6 @@ OC.L10N.register(
     "Valid until" : "Kehtib kuni",
     "Certificate" : "Sertifikaat",
     "Submit" : "Saada",
-    "Keyboard shortcut" : "Klaviatuuri otsetee",
-    "Keyboard shortcuts" : "Klaviatuuri otseteed",
-    "Archive" : "Arhiiv",
     "Account connected" : "Konto ühendatud",
     "All" : "Kõik",
     "Drafts" : "Mustandid",
