@@ -84,7 +84,6 @@ OC.L10N.register(
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days.",
     "Please connect to a sieve server first." : "Please connect to a sieve server first.",
     "Sieve filter rules" : "Sieve filter rules",
-    "Trusted senders" : "Trusted senders",
     "Mail server" : "سرور پست الکترونیکی",
     "Sieve filter server" : "Sieve filter server",
     "Update alias" : "Update alias",
@@ -97,16 +96,30 @@ OC.L10N.register(
     "Add alias" : "Add alias",
     "Create alias" : "Create alias",
     "Cancel" : "لغو",
+    "Mail settings" : "Mail settings",
+    "List" : "فهرست",
     "Add mail account" : "حساب کاربری پست الکترونیکی اضافه کنید",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally.",
+    "Trusted senders" : "Trusted senders",
     "Use Gravatar and favicon avatars" : "از آواتارهای Gravatar و Favicon استفاده کنید",
     "Register as application for mail links" : "به عنوان برنامه برای پیوندهای نامه ثبت نام کنید",
-    "Show keyboard shortcuts" : "Show keyboard shortcuts",
+    "Register" : "ثبت‌نام",
     "Manage S/MIME certificates" : "Manage S/MIME certificates",
+    "Sorting" : "مرتب سازی",
     "Newest" : "Newest",
     "Oldest" : "Oldest",
     "Looking for a way to encrypt your emails?" : "Looking for a way to encrypt your emails?",
-    "Install Mailvelope browser extension here" : "Install Mailvelope browser extension here",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally.",
+    "Keyboard" : "Keyboard",
+    "Compose new message" : "نوشتن پیام جدید",
+    "Newer message" : "پیام جدیدتر",
+    "Older message" : "پیام قدیمی تر",
+    "Toggle star" : "تعویض ستاره",
+    "Toggle unread" : "تغییر حالت خوانده نشده",
+    "Archive" : "آرشیو",
+    "Delete" : "حذف",
+    "Search" : "جستجو",
+    "Send" : "ارسال",
+    "Refresh" : "تازه‌سازی",
     "Put my text to the bottom of a reply instead of on top of it." : "Put my text to the bottom of a reply instead of on top of it.",
     "Automatically classify importance of new email" : "Automatically classify importance of new email",
     "Could not update preference" : "Could not update preference",
@@ -123,7 +136,6 @@ OC.L10N.register(
     "Toggle recipients list mode" : "Toggle recipients list mode",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
-    "No contacts found." : "هیچ تماسی یافت نشد.",
     "Subject" : "موضوع",
     "Subject …" : "موضوع …",
     "This message came from a noreply address so your reply will probably not be read." : "این پیام از یک آدرس خیلی روشن آمده است بنابراین پاسخ شما احتمالاً خوانده نمی شود.",
@@ -135,12 +147,12 @@ OC.L10N.register(
     "Draft saved" : "پیش نویس ذخیره شد",
     "Save draft" : "Save draft",
     "Discard & close draft" : "Discard & close draft",
+    "Enable formatting" : "قالب بندی را فعال کنید",
+    "Disable formatting" : "Disable formatting",
     "Upload attachment" : "پیوست را بارگیری کنید",
     "Add attachment from Files" : "پیوست را از پرونده ها اضافه کنید",
     "Smart picker" : "Smart picker",
     "Send later" : "Send later",
-    "Enable formatting" : "قالب بندی را فعال کنید",
-    "Disable formatting" : "Disable formatting",
     "Request a read receipt" : "Request a read receipt",
     "Sign message with S/MIME" : "Sign message with S/MIME",
     "Encrypt message with S/MIME" : "Encrypt message with S/MIME",
@@ -156,7 +168,6 @@ OC.L10N.register(
     "Encrypt with S/MIME and send" : "Encrypt with S/MIME and send",
     "Encrypt with Mailvelope and send later" : "Encrypt with Mailvelope and send later",
     "Encrypt with Mailvelope and send" : "Encrypt with Mailvelope and send",
-    "Send" : "ارسال",
     "Message {id} could not be found" : "Message {id} could not be found",
     "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted.",
     "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Any existing formatting (for example bold, italic, underline or inline images) will be removed.",
@@ -165,6 +176,7 @@ OC.L10N.register(
     "Keep formatting" : "Keep formatting",
     "Choose a file to add as attachment" : "پرونده ای را برای اضافه کردن به عنوان پیوست انتخاب کنید",
     "Choose a file to share as a link" : "Choose a file to share as a link",
+    "Choose" : "انتخاب کنید",
     "_{count} attachment_::_{count} attachments_" : ["{count} attachment","{count} attachments"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["The attachment exceed the allowed attachments size of {size}. Please share the file via link instead.","The attachments exceed the allowed attachments size of {size}. Please share the files via link instead."],
     "Expand composer" : "Expand composer",
@@ -224,6 +236,8 @@ OC.L10N.register(
     "_Delete {number} thread_::_Delete {number} threads_" : ["Delete {number} thread","Delete {number} threads"],
     "Report this bug" : "گزارش این اشکال",
     "All day" : "تمام روز",
+    "Select calendar" : "Select calendar",
+    "Description" : "شرح",
     "Create" : "ساخت",
     "Event created" : "Event created",
     "Could not create event" : "رویداد ایجاد نشد",
@@ -253,7 +267,6 @@ OC.L10N.register(
     "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "You are not allowed to move this message to the archive folder and/or delete this message from the current folder",
     "Choose target mailbox" : "Choose target mailbox",
     "No more submailboxes in here" : "No more submailboxes in here",
-    "Choose" : "انتخاب کنید",
     "Important info" : "Important info",
     "Other" : "دیگر",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time.",
@@ -297,7 +310,6 @@ OC.L10N.register(
     "Moving" : "Moving",
     "Moving thread" : "Moving thread",
     "Moving message" : "Moving message",
-    "Mail settings" : "Mail settings",
     "Provisioned account is disabled" : "Provisioned account is disabled",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn.",
     "Quota" : "سهم",
@@ -336,7 +348,6 @@ OC.L10N.register(
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} unread of {total}","{unread} unread of {total}"],
     "Outbox" : "Outbox",
     "New message" : "پیام جدید",
-    "Refresh" : "تازه‌سازی",
     "Error sending your message" : "خطایی در ارسال پیام شما",
     "Retry" : "تلاش دوباره",
     "Uploading attachments …" : "درحال بارگذاری پیوستها …",
@@ -363,7 +374,6 @@ OC.L10N.register(
     "Save autoresponder" : "Save autoresponder",
     "Could not open outbox" : "Could not open outbox",
     "Pending or not sent messages will show up here" : "Pending or not sent messages will show up here",
-    "Delete" : "حذف",
     "Message could not be sent" : "Message could not be sent",
     "Message deleted" : "Message deleted",
     "Contacts with this address" : "Contacts with this address",
@@ -389,7 +399,6 @@ OC.L10N.register(
     "Marked as" : "Marked as",
     "Has attachments" : "Has attachments",
     "Clear" : "پاک کردن",
-    "Search" : "جستجو",
     "Date" : "تاریخ",
     "Disabled" : "غیرفعال شده",
     "Enabled" : "فعال شده",
@@ -419,7 +428,6 @@ OC.L10N.register(
     "Tag name is a hidden system tag" : "Tag name is a hidden system tag",
     "Tag already exists" : "تگ از قبل وجود دارد",
     "An error occurred, unable to create the tag." : "An error occurred, unable to create the tag.",
-    "Select calendar" : "Select calendar",
     "No calendars with task list support" : "No calendars with task list support",
     "Task created" : "Task created",
     "Could not create task" : "Could not create task",
@@ -485,8 +493,6 @@ OC.L10N.register(
     "Provision all accounts" : "Provision all accounts",
     "Allow additional mail accounts" : "Allow additional mail accounts",
     "Allow additional Mail accounts from User Settings" : "Allow additional Mail accounts from User Settings",
-    "Enable thread summary" : "Enable thread summary",
-    "Enable thread summaries" : "Enable thread summaries",
     "Anti Spam Service" : "Anti Spam Service",
     "You can set up an anti spam service email address here." : "You can set up an anti spam service email address here.",
     "Any email that is marked as spam will be sent to the anti spam service." : "Any email that is marked as spam will be sent to the anti spam service.",
@@ -571,15 +577,6 @@ OC.L10N.register(
     "Certificate imported successfully" : "Certificate imported successfully",
     "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase.",
     "Failed to import the certificate" : "Failed to import the certificate",
-    "Keyboard shortcut" : "صفحه کلید",
-    "Keyboard shortcuts" : "میان بر صفحه ی کلید",
-    "Speed up your Mail experience with these quick shortcuts." : "تجربه ایمیل خود را با این میانبرهای سریع سرعت بخشید.",
-    "Compose new message" : "نوشتن پیام جدید",
-    "Newer message" : "پیام جدیدتر",
-    "Older message" : "پیام قدیمی تر",
-    "Toggle star" : "تعویض ستاره",
-    "Toggle unread" : "تغییر حالت خوانده نشده",
-    "Archive" : "آرشیو",
     "Account connected" : "Account connected",
     "You can close this window" : "You can close this window",
     "Connect your mail account" : "حساب ایمیل خود را وصل کنید",
