@@ -70,7 +70,6 @@ OC.L10N.register(
     "Default folders" : "Oletuskansiot",
     "Autoresponder" : "Automaattivastaukset",
     "Sieve filter rules" : "Sieve-filtterin säännöt",
-    "Trusted senders" : "Luotetut lähettäjät",
     "Mail server" : "Sähköpostipalvelin",
     "Sieve filter server" : "Sieve-filtteripalvelin",
     "Update alias" : "Päivitä alias",
@@ -81,16 +80,29 @@ OC.L10N.register(
     "Add alias" : "Lisää alias",
     "Create alias" : "Luo alias",
     "Cancel" : "Peruuta",
+    "Mail settings" : "Sähköpostin asetukset",
     "Add mail account" : "Lisää sähköpostitili",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Salli sovelluksen kerätä tietoa vuorovaikutuksestasi. Tämän tiedon perusteella sovellus sopeutuu mieltymyksiisi. Nämä tiedot talletetaan vain paikallisesti.",
+    "Trusted senders" : "Luotetut lähettäjät",
     "Use Gravatar and favicon avatars" : "Käytä Gravatar- ja favicon-avatareja",
     "Register as application for mail links" : "Rekisteröi sovellukseksi mail-linkeille",
-    "Show keyboard shortcuts" : "Näytä pikanäppäimet",
+    "Register" : "Rekisteröidy",
     "Manage S/MIME certificates" : "Hallitse S/MIME-varmenteita",
+    "Sorting" : "Lajittelu",
     "Newest" : "Uusimmat",
     "Oldest" : "Vanhimmat",
     "Looking for a way to encrypt your emails?" : "Etsitkö tapaa salata sähköpostisi?",
-    "Install Mailvelope browser extension here" : "Asenna Mailvelope-selainlaajennus täältä",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Salli sovelluksen kerätä tietoa vuorovaikutuksestasi. Tämän tiedon perusteella sovellus sopeutuu mieltymyksiisi. Nämä tiedot talletetaan vain paikallisesti.",
+    "Keyboard" : "Näppäimistö",
+    "Compose new message" : "Uusi viesti",
+    "Newer message" : "Uudempi",
+    "Older message" : "Vanhempi viesti",
+    "Toggle star" : "Lisää/poista tähti",
+    "Toggle unread" : "Merkitse luetuksi/lukemattomaksi",
+    "Archive" : "Arkisto",
+    "Delete" : "Poista",
+    "Search" : "Etsi",
+    "Send" : "Lähetä",
+    "Refresh" : "Päivitä",
     "Put my text to the bottom of a reply instead of on top of it." : "Aseta tekstini vastauksen alaosaan yläosan sijaan",
     "Automatically classify importance of new email" : "Merkitse sähköpostin tärkeys automaattisesti",
     "Could not update preference" : "Asetuksia ei voitu päivittää",
@@ -102,10 +114,10 @@ OC.L10N.register(
     "From" : "Lähettäjä",
     "Select account" : "Valitse tili",
     "To" : "Vastaanottaja",
+    "Select recipient" : "Valitse vastaanottaja",
     "Contact or email address …" : "Yhteystieto tai sähköpostiosoite…",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
-    "No contacts found." : "Yhteystietoja ei löytynyt.",
     "Subject" : "Aihe",
     "Subject …" : "Aihe…",
     "This message came from a noreply address so your reply will probably not be read." : "Tämä viesti saapui noreply-osoitteesta, joten vastaustasi ei luultavasti lueta.",
@@ -117,11 +129,11 @@ OC.L10N.register(
     "Draft saved" : "Luonnos tallennettu",
     "Save draft" : "Tallenna luonnos",
     "Discard & close draft" : "Hylkää ja sulje luonnos",
+    "Enable formatting" : "Käytä muotoilua",
+    "Disable formatting" : "Poista muotoilu käytöstä",
     "Upload attachment" : "Lähetä liite",
     "Add attachment from Files" : "Lisää liitteitä tiedostosovelluksesta",
     "Send later" : "Lähetä myöhemmin",
-    "Enable formatting" : "Käytä muotoilua",
-    "Disable formatting" : "Poista muotoilu käytöstä",
     "Request a read receipt" : "Pyydä lukukuittaus",
     "Sign message with S/MIME" : "Allekirjoita viesti S/MIME:llä",
     "Encrypt message with S/MIME" : "Salaa viesti S/MIME:llä",
@@ -136,7 +148,6 @@ OC.L10N.register(
     "Encrypt with S/MIME and send" : "Salaa S/MIME:llä ja lähetä",
     "Encrypt with Mailvelope and send later" : "Salaa Mailvelopella ja lähetä myöhemmin",
     "Encrypt with Mailvelope and send" : "Salaa Mailvelopella ja lähetä",
-    "Send" : "Lähetä",
     "Message {id} could not be found" : "Viestiä {id} ei löytynyt",
     "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Mikä tahansa aiempi muotoilu (esimerkiksi lihavointi, kursivointi, alleviivaus tai sisennetyt kuvat) poistetaan.",
     "Turn off formatting" : "Poista muotoilu käytöstä",
@@ -144,6 +155,7 @@ OC.L10N.register(
     "Keep formatting" : "Säilytä muotoilu",
     "Choose a file to add as attachment" : "Valitse liitteeksi lisättävä tiedosto",
     "Choose a file to share as a link" : "Valitse tiedosto, joka jaetaan linkkinä",
+    "Choose" : "Valitse",
     "_{count} attachment_::_{count} attachments_" : ["{count} liite","{count} liitettä"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Liite ylittää sallitun enimmäiskoon {size}. Jaa tiedosto linkin kautta.","Liitteet ylittävät sallitun enimmäiskoon {size}. Jaa tiedostot linkin kautta."],
     "Expand composer" : "Laajenna lähetysikkunaa",
@@ -194,6 +206,8 @@ OC.L10N.register(
     "_Delete {number} thread_::_Delete {number} threads_" : ["Poista {number} ketju","Poista {number} ketjua"],
     "Report this bug" : "Ilmoita viasta",
     "All day" : "Koko päivä",
+    "Select calendar" : "Valitse kalenteri",
+    "Description" : "Kuvaus",
     "Create" : "Luo",
     "Event created" : "Tapahtuma luotu",
     "Could not create event" : "Tapahtumaa ei voitu luoda",
@@ -217,7 +231,6 @@ OC.L10N.register(
     "Could not open mailbox" : "Postilaatikkoa ei voitu avata",
     "Loading messages …" : "Ladataan viestejä …",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Viestejäsi indeksoidaan. Tämä saattaa kestää hetken varsinkin suurikokoisissa postilaatikoissa.",
-    "Choose" : "Valitse",
     "Important info" : "Tärkeää tietoa",
     "Other" : "Muu",
     "The sender of this message has asked to be notified when you read this message." : "Tämän viestin lähettäjä on pyytänyt ilmoitusta, kun luet tämän viestin.",
@@ -255,7 +268,6 @@ OC.L10N.register(
     "Moving" : "Siirretään",
     "Moving thread" : "Siirretään ketjua",
     "Moving message" : "Siirretään viestiä",
-    "Mail settings" : "Sähköpostin asetukset",
     "Quota" : "Kiintiö",
     "Show only subscribed mailboxes" : "Näytä vain tilatut postilaatikot",
     "Add mailbox" : "Lisää postilaatikko",
@@ -290,7 +302,6 @@ OC.L10N.register(
     "_{total} message_::_{total} messages_" : ["{total} viesti","{total} viestiä"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lukematonta {total} viestistä","{unread} lukematonta {total} viestistä"],
     "New message" : "Uusi viesti",
-    "Refresh" : "Päivitä",
     "Error sending your message" : "Virhe viestiäsi lähettäessä",
     "Retry" : "Yritä uudelleen",
     "Uploading attachments …" : "Lähetetään liitteitä…",
@@ -314,7 +325,6 @@ OC.L10N.register(
     "Oh Snap!" : "Oho!",
     "Save autoresponder" : "Tallenna automaattivastaus",
     "Pending or not sent messages will show up here" : "Odottavat tai vielä lähettämättömät viestit näkyvät täällä",
-    "Delete" : "Poista",
     "Message could not be sent" : "Viestiä ei voitu lähettää",
     "Message deleted" : "Viesti poistettu",
     "Contacts with this address" : "Yhteystiedot tällä osoitteella",
@@ -333,7 +343,6 @@ OC.L10N.register(
     "Select tags" : "Valitse tunnisteet",
     "Has attachments" : "On liitteitä",
     "Clear" : "Tyhjennä",
-    "Search" : "Etsi",
     "Date" : "Päivä",
     "Disabled" : "Pois käytöstä",
     "Enabled" : "Käytössä",
@@ -351,8 +360,8 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Allekirjoituksesi koko on yli kaksi megatavua. Tämä saattaa vaikuttaa muokkaimen suorituskykyyn.",
     "Save signature" : "Tallenna allekirjoitus",
     "Place signature above quoted text" : "Aseta allekirjoitus lainatun tekstin yläpuolelle",
-    "Delete tag" : "Poista tunniste",
     "Saving new tag name …" : "Tallennetaan uuden tunnisteen nimeä…",
+    "Delete tag" : "Poista tunniste",
     "An error occurred, unable to rename the tag." : "Tapahtui virhe, tunnistetta ei voitu nimetä uudelleen.",
     "Add default tags" : "Lisää oletustunnisteet",
     "Add tag" : "Lisää tunniste",
@@ -360,7 +369,6 @@ OC.L10N.register(
     "Tag name is a hidden system tag" : "Tunnisteen nimi on piilotettu järjestelmätunniste",
     "Tag already exists" : "Tunniste on jo olemassa",
     "An error occurred, unable to create the tag." : "Tapahtui virhe, tunnistetta ei voitu luoda.",
-    "Select calendar" : "Valitse kalenteri",
     "Task created" : "Tehtävä luotu",
     "Loading thread" : "Ladataan ketjua",
     "Not found" : "Ei löytynyt",
@@ -442,15 +450,6 @@ OC.L10N.register(
     "Certificate imported successfully" : "Varmenne tuotu onnistuneesti",
     "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Varmenteen tuonti epäonnistui. Varmista, että yksityinen avain vastaa varmennetta ja ettei se ole suojattu tunnuslauseella.",
     "Failed to import the certificate" : "Varmenteen tuominen epäonnistui",
-    "Keyboard shortcut" : "Näppäimistön pikanäppäin",
-    "Keyboard shortcuts" : "Pikanäppäimet",
-    "Speed up your Mail experience with these quick shortcuts." : "Nopeuta sähköpostikokemustasi näillä pikanäppäimillä.",
-    "Compose new message" : "Uusi viesti",
-    "Newer message" : "Uudempi",
-    "Older message" : "Vanhempi viesti",
-    "Toggle star" : "Lisää/poista tähti",
-    "Toggle unread" : "Merkitse luetuksi/lukemattomaksi",
-    "Archive" : "Arkisto",
     "Account connected" : "Tili yhdistetty",
     "You can close this window" : "Voit sulkea tämän ikkunan",
     "Connect your mail account" : "Yhdistä sähköpostitilisi",
