@@ -48,7 +48,6 @@ OC.L10N.register(
     "Writing mode" : "מצב כתיבה",
     "Preferred writing mode for new messages and replies." : "מצב כתיבה מועדף להודעות חדשות ולתגובות.",
     "Default folders" : "תיקיות בררת מחדל",
-    "Trusted senders" : "שולחים מהימנים",
     "Mail server" : "שרת דוא״ל",
     "Go back" : "חזרה",
     "Change name" : "החלפת שם",
@@ -56,17 +55,28 @@ OC.L10N.register(
     "Add alias" : "הוספת כינוי",
     "Cancel" : "ביטול",
     "Add mail account" : "הוספת חשבון דוא״ל",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "לאפשר ליישומן לאסוף נתונים על אופן השימוש שלך. על בסיס המידע הזה, היישומון יתאים את עצמו להעדפות שלך. הנתונים יישמרו מקומית בלבד.",
+    "Trusted senders" : "שולחים מהימנים",
     "Use Gravatar and favicon avatars" : "להשתמש בסמלים של Gravatar ושל favicon",
     "Register as application for mail links" : "רישום כיישום לטיפול בקישורי דוא״ל (mailto)",
-    "Show keyboard shortcuts" : "הצגת קיצורי מקלדת",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "לאפשר ליישומן לאסוף נתונים על אופן השימוש שלך. על בסיס המידע הזה, היישומון יתאים את עצמו להעדפות שלך. הנתונים יישמרו מקומית בלבד.",
+    "Register" : "רישום",
+    "Sorting" : "מיון",
+    "Compose new message" : "כתיבת הודעה חדשה",
+    "Newer message" : "הודעה חדשה יותר",
+    "Older message" : "הודעה ישנה יותר",
+    "Toggle star" : "החלפת מצב כוכב",
+    "Toggle unread" : "החלפת מצב קריאה",
+    "Archive" : "לארכיון",
+    "Delete" : "מחיקה",
+    "Search" : "חיפוש",
+    "Send" : "שליחה",
+    "Refresh" : "רענון",
     "From" : "מאת",
     "Select account" : "בחר חשבון",
     "To" : "אל",
     "Contact or email address …" : "איש קשר או כתובת דוא״ל…",
     "Cc" : "עותק",
     "Bcc" : "עותק נסתר",
-    "No contacts found." : "לא נמצאו אנשי קשר.",
     "Subject" : "נושא",
     "Subject …" : "נושא…",
     "This message came from a noreply address so your reply will probably not be read." : "הודעה זו הגיעה מכתובת שאינה מיועדת למענה (noreply) ולכן כנראה שהתגובה שלך לא תיקרא.",
@@ -74,17 +84,17 @@ OC.L10N.register(
     "Write message …" : "כתיבת הודעה…",
     "Saving draft …" : "הטיוטה נשמרת…",
     "Draft saved" : "הטיוטה נשמרה",
+    "Enable formatting" : "הפעלת עיצוב",
     "Upload attachment" : "העלאת קובץ מצורף",
     "Add attachment from Files" : "הוספת קובץ מצורף מהקבצים",
-    "Enable formatting" : "הפעלת עיצוב",
     "Request a read receipt" : "בקשת אישור קריאה",
     "Encrypt message with Mailvelope" : "הצפנת הודעה עם Mailvelope",
     "Enter a date" : "נא למלא תאריך",
     "Add share link from {productName} Files" : "הוספת קישור שיתוף מקבצים של {productName}",
-    "Send" : "שליחה",
     "Message {id} could not be found" : "לא ניתן למצוא את הודעה {id}",
     "Choose a file to add as attachment" : "בחירת קובץ להוספה כקובץ מצורף",
     "Choose a file to share as a link" : "נא לבחור קובץ לשיתוף כקישור",
+    "Choose" : "בחר",
     "Confirm" : "אימות",
     "Plain text" : "טקסט פשוט",
     "Rich text" : "טקסט עשיר",
@@ -110,9 +120,10 @@ OC.L10N.register(
     "Could not delete message" : "לא ניתן למחוק הודעה",
     "Forward" : "העברה",
     "Load more" : "לטעון עוד",
-    "_Mark {number} unread_::_Mark {number} unread_" : ["סימון {number} שלא נקראה","סימון {number} שלא נקראו","סימון {number} שלא נקראו","סימון {number} שלא נקראו"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["סימון {number} שלא נקראה","סימון {number} שלא נקראו","סימון {number} שלא נקראו"],
     "Report this bug" : "דיווח על התקלה הזו",
     "All day" : "כל היום",
+    "Description" : "תיאור",
     "Create" : "יצירה",
     "Could not create event" : "לא ניתן ליצור אירוע",
     "Comment" : "הערה",
@@ -120,7 +131,6 @@ OC.L10N.register(
     "Decline" : "דחייה",
     "Could not open mailbox" : "לא ניתן לפתוח את תיבת הדואר",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "ההודעות שלך מסודרות באינדקס. פעולה זו עשויה לארוך זמן מה בתיבות דואר גדולות.",
-    "Choose" : "בחר",
     "Important info" : "מידע חשוב",
     "Other" : "אחר",
     "Reply" : "תגובה",
@@ -160,17 +170,15 @@ OC.L10N.register(
     "The mailbox and all messages in it will be deleted." : "תיבת הדוא״ל על כל ההודעות שבה תימחק.",
     "Delete mailbox {name}" : "מחיקת תיבת הדוא״ל {name}",
     "An error occurred, unable to rename the mailbox." : "אירעה שגיאה, לא ניתן לשנות את שם תיבת הדוא״ל.",
-    "_{total} message_::_{total} messages_" : ["הודעה אחת","{total} הודעות","{total} הודעות","{total} הודעות"],
+    "_{total} message_::_{total} messages_" : ["הודעה אחת","{total} הודעות","{total} הודעות"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["אחת לא נקראה מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}"],
     "New message" : "הודעה חדשה",
-    "Refresh" : "רענון",
     "Error sending your message" : "שליחת ההודעה שלך נכשלה",
     "Retry" : "ניסיון חוזר",
     "Uploading attachments …" : "הקבצים המצורפים מועלים…",
     "Sending …" : "שולח...",
     "Message" : "הודעה",
     "Oh Snap!" : "שוד ושבר!",
-    "Delete" : "מחיקה",
     "Copy to clipboard" : "העתקה ללוח הגזירים",
     "Add" : "הוספה",
     "Close" : "סגירה",
@@ -178,7 +186,6 @@ OC.L10N.register(
     "Tags" : "תגיות",
     "Select tags" : "בחירת תגיות",
     "Clear" : "פינוי",
-    "Search" : "חיפוש",
     "Date" : "תאריך",
     "Disabled" : "מושבת",
     "Enabled" : "מופעל",
@@ -231,15 +238,6 @@ OC.L10N.register(
     "Valid until" : "בתוקף עד",
     "Certificate" : "אישור",
     "Submit" : "שליחה",
-    "Keyboard shortcut" : "קיצור מקלדת",
-    "Keyboard shortcuts" : "קיצורי מקלדת",
-    "Speed up your Mail experience with these quick shortcuts." : "ניתן להאיץ את חוויית הדוא״ל שלך עם קיצורי המקלדת הזריזים האלו.",
-    "Compose new message" : "כתיבת הודעה חדשה",
-    "Newer message" : "הודעה חדשה יותר",
-    "Older message" : "הודעה ישנה יותר",
-    "Toggle star" : "החלפת מצב כוכב",
-    "Toggle unread" : "החלפת מצב קריאה",
-    "Archive" : "לארכיון",
     "Account connected" : "חשבון מחובר",
     "Connect your mail account" : "התחברות לחשבון הדוא״ל שלך",
     "Itinerary for {type} is not supported yet" : "פירוט המסלול {type} אינו נתמך עדיין",
@@ -254,7 +252,7 @@ OC.L10N.register(
     "Trash" : "פח אשפה",
     "Error while sharing file" : "שגיאה בשיתוף הקובץ",
     "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["הודעה חדשה \nמאת {from}","2 הודעות חדשות \nמאת {from}","%n הודעות חדשות \nמאת {from}","%n הודעות חדשות \nמאת {from}"],
+    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["הודעה חדשה \nמאת {from}","2 הודעות חדשות \nמאת {from}","%n הודעות חדשות \nמאת {from}"],
     "Nextcloud Mail" : "דוא״ל Nextcloud",
     "Attachments were not copied. Please add them manually." : "הקבצים המצורפים לא הועתקו. נא להוסיף אותם ידנית.",
     "Message sent" : "הודעה נשלחה",
@@ -270,4 +268,4 @@ OC.L10N.register(
     "The link leads to %s" : "הקישור מוביל אל %s",
     "Continue to %s" : "ממשיך אל %s"
 },
-"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
+"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
