@@ -49,7 +49,6 @@ OC.L10N.register(
     "Preferred writing mode for new messages and replies." : "Željeni način pisanja za nove poruke i odgovore.",
     "Default folders" : "Zadane mape",
     "Sieve filter rules" : "Pravila filtra Sieve",
-    "Trusted senders" : "Pouzdani pošiljatelji",
     "Mail server" : "Poslužitelj e-pošte",
     "Sieve filter server" : "Poslužitelj filtra Sieve",
     "Update alias" : "Ažuriraj pseudonim",
@@ -61,11 +60,24 @@ OC.L10N.register(
     "Add alias" : "Dodaj pseudonim",
     "Create alias" : "Stvori pseudonim",
     "Cancel" : "Odustani",
+    "List" : "Popis",
     "Add mail account" : "Dodaj račun e-pošte",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Dopustite aplikaciji da prikuplja podatke o vašim interakcijama. Aplikacija će se prilagoditi vašim željama na temelju tih podataka. Podaci će biti pohranjeni samo lokalno.",
+    "Trusted senders" : "Pouzdani pošiljatelji",
     "Use Gravatar and favicon avatars" : "Upotrijebi avatare Gravatar i Favicon",
     "Register as application for mail links" : "Registriraj kao aplikaciju za poveznice e-pošte",
-    "Show keyboard shortcuts" : "Prikaži tipkovne prečace",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Dopustite aplikaciji da prikuplja podatke o vašim interakcijama. Aplikacija će se prilagoditi vašim željama na temelju tih podataka. Podaci će biti pohranjeni samo lokalno.",
+    "Register" : "Registriraj se",
+    "Sorting" : "Razvrstavanje",
+    "Compose new message" : "Sastavi novu poruku",
+    "Newer message" : "Novija poruka",
+    "Older message" : "Starija poruka",
+    "Toggle star" : "Uključi/isključi zvijezdu",
+    "Toggle unread" : "Uključi/isključi nepročitano",
+    "Archive" : "Arhiva",
+    "Delete" : "Izbriši",
+    "Search" : "Traži",
+    "Send" : "Pošalji",
+    "Refresh" : "Osvježi",
     "Put my text to the bottom of a reply instead of on top of it." : "Stavite tekst na dno odgovora umjesto na vrh.",
     "Automatically classify importance of new email" : "Automatski klasificirajte važnost nove e-pošte",
     "Could not update preference" : "Ažuriranje postavki nije uspjelo",
@@ -75,7 +87,6 @@ OC.L10N.register(
     "Contact or email address …" : "Kontakt ili adresa e-pošte...",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
-    "No contacts found." : "Nikakvi kontakti nisu nađeni.",
     "Subject" : "Predmet",
     "Subject …" : "Naslov...",
     "This message came from a noreply address so your reply will probably not be read." : "Ova je poruka poslana s adrese na koju se ne može odgovoriti pa vaš odgovor vjerojatno nitko neće pročitati.",
@@ -83,17 +94,17 @@ OC.L10N.register(
     "Write message …" : "Napiši poruku...",
     "Saving draft …" : "Spremanje skice...",
     "Draft saved" : "Skica je spremljena",
+    "Enable formatting" : "Omogući oblikovanje",
     "Upload attachment" : "Otpremi privitak",
     "Add attachment from Files" : "Dodaj privitak iz datoteka",
-    "Enable formatting" : "Omogući oblikovanje",
     "Request a read receipt" : "Zatražite potvrdu o čitanju",
     "Encrypt message with Mailvelope" : "Šifriraj poruku s Mailvelope",
     "Enter a date" : "Unesi datum",
     "Add share link from {productName} Files" : "Dodaj poveznicu za dijeljenje iz datoteka {productName}",
-    "Send" : "Pošalji",
     "Message {id} could not be found" : "Poruka {id} nije pronađena",
     "Choose a file to add as attachment" : "Izaberi datoteku kao privitak",
     "Choose a file to share as a link" : "Izaberi datoteku za dijeljenje putem poveznice",
+    "Choose" : "Odaberite",
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Privitak prekoračuje dopuštenu veličinu privitaka od {size}. Dijelite datoteku putem poveznice.","Privici prekoračuju dopuštenu veličinu privitaka od {size}. Dijelite datoteke putem poveznice.","Privici prekoračuju dopuštenu veličinu privitaka od {size}. Dijelite datoteke putem poveznice."],
     "Confirm" : "Potvrdi",
     "Plain text" : "Običan tekst",
@@ -133,6 +144,7 @@ OC.L10N.register(
     "_Delete {number} thread_::_Delete {number} threads_" : ["Izbriši {number} dretvu","Izbriši {number} dretve","Izbriši {number} dretvi"],
     "Report this bug" : "Prijavi ovu pogrešku",
     "All day" : "Cijeli dan",
+    "Description" : "Opis",
     "Create" : "Stvori",
     "Event created" : "Događaj je stvoren",
     "Could not create event" : "Nije moguće stvoriti događaj",
@@ -144,7 +156,6 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksiranje poruka u tijeku. Ova radnja može potrajati za veće sandučiće.",
     "Choose target mailbox" : "Odaberi ciljni sandučić",
     "No more submailboxes in here" : "Ovdje više nema podsandučića",
-    "Choose" : "Odaberite",
     "Important info" : "Važne informacije",
     "Other" : "Ostalo",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Poruke se automatski označavaju kao važne na temelju poruka kojima ste rukovali ili koje ste označili kao važne. U početku ćete možda morati ručno mijenjati važnost poruka kako bi sustav zapamtio vaše želje, ali s vremenom će se poboljšati.",
@@ -210,7 +221,6 @@ OC.L10N.register(
     "_{total} message_::_{total} messages_" : ["{total} poruka","{total} poruka","{total} poruka"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} nepročitana od {total}","{unread} nepročitane od {total}","{unread} nepročitanih od {total}"],
     "New message" : "Nova poruka",
-    "Refresh" : "Osvježi",
     "Error sending your message" : "Pogreška pri slanju poruke",
     "Retry" : "Pokušaj ponovno",
     "Uploading attachments …" : "Otpremanje privitaka...",
@@ -221,7 +231,6 @@ OC.L10N.register(
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Pokušavate poslati poruku velikom broju primatelja koji su navedeni u poljima Za i/ili Cc. Razmislite o korištenju polja Bcc kako adrese primatelja ne bi bile vidljive.",
     "Message" : "Poruka",
     "Oh Snap!" : "Oh Snap!",
-    "Delete" : "Izbriši",
     "Contacts with this address" : "Kontakti s ovom adresom",
     "Add to Contact" : "Dodaj kontaktu",
     "New Contact" : "Novi kontakt",
@@ -233,7 +242,6 @@ OC.L10N.register(
     "Tags" : "Oznake",
     "Select tags" : "Odaberite oznake",
     "Clear" : "Izbriši",
-    "Search" : "Traži",
     "Date" : "Datum",
     "Disabled" : "Onemogućeno",
     "Enabled" : "Omogućeno",
@@ -250,8 +258,8 @@ OC.L10N.register(
     "Signature …" : "Potpis...",
     "Save signature" : "Spremi potpis",
     "Place signature above quoted text" : "Stavi potpis iznad citiranog teksta",
-    "Delete tag" : "Izbriši oznaku",
     "Saving new tag name …" : "Spremanje novog naziva oznake…",
+    "Delete tag" : "Izbriši oznaku",
     "An error occurred, unable to rename the tag." : "Došlo je do pogreške, nije moguće promijeniti naziv oznake.",
     "Add default tags" : "Dodaj zadane oznake",
     "Add tag" : "Dodaj oznaku",
@@ -348,15 +356,6 @@ OC.L10N.register(
     "Valid until" : "Vrijedi do",
     "Certificate" : "Vjerodajnica",
     "Submit" : "Šalji",
-    "Keyboard shortcut" : "Tipkovni prečac",
-    "Keyboard shortcuts" : "Tipkovni prečaci",
-    "Speed up your Mail experience with these quick shortcuts." : "Ubrzajte korištenje e-pošte s pomoću ovih brzih prečaca.",
-    "Compose new message" : "Sastavi novu poruku",
-    "Newer message" : "Novija poruka",
-    "Older message" : "Starija poruka",
-    "Toggle star" : "Uključi/isključi zvijezdu",
-    "Toggle unread" : "Uključi/isključi nepročitano",
-    "Archive" : "Arhiva",
     "Account connected" : "Račun povezan",
     "Connect your mail account" : "Poveži svoj račun e-pošte",
     "Itinerary for {type} is not supported yet" : "Raspored za {type} još uvijek nije podržan",
