@@ -17,12 +17,16 @@ OC.L10N.register(
     "Connect" : "Connecter se",
     "Go back" : "Retornar",
     "Cancel" : "Cancellar",
+    "Delete" : "Deler",
+    "Search" : "Cercar",
     "Send" : "Inviar",
+    "Refresh" : "Refrescar",
     "Choose a file to add as attachment" : "Selectiona un file pro adder como attachamento",
     "Confirm" : "Confirmar",
     "Favorite" : "Favorite",
     "Select" : "Selectionar",
     "Back" : "Retro",
+    "Description" : "Description",
     "Create" : "Crear",
     "Comment" : "Commentario",
     "Accept" : "Acceptar",
@@ -35,13 +39,10 @@ OC.L10N.register(
     "Quota" : "Quota",
     "Saving" : "Salveguardante",
     "Remove account" : "Remover conto",
-    "Refresh" : "Refrescar",
     "Sending …" : "Inviante ...",
-    "Delete" : "Deler",
     "Add" : "Adder",
     "Close" : "Clauder",
     "Tags" : "Etiquettas",
-    "Search" : "Cercar",
     "Date" : "Date",
     "Enabled" : "Activate",
     "Custom" : "Personalisate",
@@ -51,8 +52,6 @@ OC.L10N.register(
     "Host" : "Hospite",
     "Port" : "Porto",
     "Valid until" : "Valide usque",
-    "Keyboard shortcut" : "Combination de claves",
-    "Keyboard shortcuts" : "Combinationes de claves",
     "All" : "Tote",
     "Favorites" : "Favoritos",
     "All inboxes" : "Tote cassas de entrata",
