@@ -20,12 +20,18 @@ OC.L10N.register(
     "Go back" : "Kembali",
     "Email address" : "Alamat surel",
     "Cancel" : "Membatalkan",
+    "List" : "Daftar",
     "Add mail account" : "Tambahkan akun surel",
-    "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
+    "Register" : "Daftar",
+    "Archive" : "Arsip",
+    "Delete" : "Hapus",
+    "Search" : "Cari",
+    "Send" : "Kirim",
+    "Refresh" : "Segarkan",
     "Subject" : "Subjek",
     "Upload attachment" : "Unggah lampiran",
-    "Send" : "Kirim",
     "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
+    "Choose" : "Pilih",
     "Confirm" : "Konfirmasi",
     "Favorite" : "Favorit",
     "Read" : "Baca",
@@ -36,11 +42,11 @@ OC.L10N.register(
     "Create event" : "Buat acara",
     "Forward" : "Teruskan",
     "All day" : "Sepanjang hari",
+    "Description" : "Deskrisi",
     "Create" : "Buat",
     "Comment" : "Komentar",
     "Accept" : "Terima",
     "Decline" : "Tolak",
-    "Choose" : "Pilih",
     "Other" : "Lainnya",
     "Reply" : "Balas",
     "Import into calendar" : "Impor ke kalender",
@@ -54,24 +60,22 @@ OC.L10N.register(
     "Edit name" : "Edit nama",
     "Clear cache" : "Bersihkan cache",
     "New message" : "Pesan baru",
-    "Refresh" : "Segarkan",
     "Retry" : "Ulangi",
     "Sending …" : "Mengirim ...",
     "Draft" : "Draf",
     "Message" : "Pesan",
-    "Delete" : "Hapus",
     "Copy to clipboard" : "Salin ke papan klip",
     "Add" : "Masukkan",
     "Close" : "Tutup",
     "Tags" : "Tag",
     "Clear" : "Bersihkan",
-    "Search" : "Cari",
     "Date" : "Date",
     "Disabled" : "Dinonaktifkan",
     "Enabled" : "Diaktifkan",
     "Add tag" : "Tambahkan tag",
     "Tag already exists" : "Tag sudah ada",
     "Unsubscribe" : "Berhenti berlangganan",
+    "Mark as unread" : "Tandai belum dibaca",
     "Mark as read" : "tandai sudah dibaca",
     "Remove" : "Buang",
     "(organizer)" : "(penyelenggara)",
@@ -86,9 +90,6 @@ OC.L10N.register(
     "Port" : "Port",
     "Valid until" : "Berlaku sampai",
     "Certificate" : "Sertifikat",
-    "Keyboard shortcut" : "Pintasan keyboard",
-    "Keyboard shortcuts" : "Pintasan keyboard",
-    "Archive" : "Arsip",
     "Account connected" : "Akun terhubung",
     "Connect your mail account" : "Hubungkan akun surel Anda",
     "All" : "Semua",
