@@ -52,14 +52,24 @@ OC.L10N.register(
     "Add mail account" : "Bæta við notandaaðgangi",
     "Use Gravatar and favicon avatars" : "Nota Gravatar og veftáknmyndir (favicon)",
     "Register as application for mail links" : "Skrá sem forrit fyrir pósttengla",
-    "Show keyboard shortcuts" : "Birta flýtivísanir á lyklaborði",
+    "Register" : "Nýskráning",
+    "Sorting" : "Röðun",
+    "Compose new message" : "Semja ný skilaboð",
+    "Newer message" : "Nýrri skilaboð",
+    "Older message" : "Eldri skilaboð",
+    "Toggle star" : "Víxla stjörnumerkingu af/á",
+    "Toggle unread" : "Víxla ólesnu af/á",
+    "Archive" : "Setja í safnskrá",
+    "Delete" : "Eyða",
+    "Search" : "Leita",
+    "Send" : "Senda",
+    "Refresh" : "Endurlesa",
     "From" : "Frá",
     "Select account" : "Veldu notandaaðgang",
     "To" : "Til",
     "Contact or email address …" : "Tengiliður eða tölvupóstfang …",
     "Cc" : "Afrit (Cc)",
     "Bcc" : "Falið afrit (Bcc)",
-    "No contacts found." : "Engir tengiliðir fundust.",
     "Subject" : "Viðfangsefni",
     "Subject …" : "Viðfangsefni …",
     "This message came from a noreply address so your reply will probably not be read." : "Skilaboðin komu frá ekki-svara netfangi (noreply) þannig að svarið þitt verður líklega ekki lesið.",
@@ -67,13 +77,16 @@ OC.L10N.register(
     "Write message …" : "Skrifa skilaboð …",
     "Saving draft …" : "Vista drög …",
     "Draft saved" : "Drög vistuð",
+    "Enable formatting" : "Virkja sniðmótun",
     "Upload attachment" : "Senda inn viðhengi",
     "Add attachment from Files" : "Bæta við viðhengi úr skrám",
-    "Enable formatting" : "Virkja sniðmótun",
+    "Smart picker" : "Snjall-veljari",
     "Encrypt message with Mailvelope" : "Dulrita skilaboð með Mailvelope",
-    "Send" : "Senda",
+    "Enter a date" : "Settu inn dagsetningu",
     "Choose a file to add as attachment" : "Veldu skrá til að setja sem viðhengi",
     "Choose a file to share as a link" : "Veldu skrá til að deila sem tengli",
+    "Choose" : "Velja",
+    "_{count} attachment_::_{count} attachments_" : ["{count} viðhengi","{count} viðhengi"],
     "Confirm" : "Staðfesta",
     "Plain text" : "Ósniðinn texti",
     "Rich text" : "Sniðinn texti",
@@ -91,6 +104,7 @@ OC.L10N.register(
     "Back" : "Til baka",
     "Edit as new message" : "Breyta sem nýjum skilaboðum",
     "Create event" : "Búa til atburð",
+    "Create task" : "Búa til verkefni",
     "Blind copy recipients only" : "Einungis viðtakendur dulinna afrita",
     "No trash mailbox configured" : "Ekkert ruslpósthólf er stillt",
     "Could not delete message" : "Gat ekki eytt skilaboðum",
@@ -98,6 +112,7 @@ OC.L10N.register(
     "Load more" : "Hlaða inn meira",
     "Report this bug" : "Tilkynna þessa villu",
     "All day" : "Heilsdagsviðburður",
+    "Description" : "Lýsing",
     "Create" : "Búa til",
     "Could not create event" : "Tókst ekki að útbúa atburð",
     "Comment" : "Athugasemd",
@@ -105,7 +120,6 @@ OC.L10N.register(
     "Decline" : "Hafna",
     "Could not open mailbox" : "Tókst ekki að opna pósthólf",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Geri atriðaskrá yfir skilaboðin þín. Þetta getur tekið drjúga stund fyrir stór pósthólf.",
-    "Choose" : "Velja",
     "Important info" : "Mikilvægar upplýsingar",
     "Other" : "Annað",
     "Reply" : "Svara",
@@ -116,6 +130,7 @@ OC.L10N.register(
     "Save to Files" : "Vista í skrár",
     "Unnamed" : "Nafnlaust",
     "Embedded message" : "Ívafin skilaboð",
+    "Next week – {timeLocale}" : "Í næstu viku – {timeLocale}",
     "Choose a folder to store the attachment in" : "Veldu möppu þar sem á að geyma viðhengið",
     "Save all to Files" : "Vista allt í skrár",
     "Choose a folder to store the attachments in" : "Veldu möppu þar sem á að geyma viðhengin",
@@ -146,13 +161,12 @@ OC.L10N.register(
     "_{total} message_::_{total} messages_" : ["{total} skilaboð","{total} skilaboð"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} ólesið af {total}","{unread} ólesin af {total}"],
     "New message" : "Ný skilaboð",
-    "Refresh" : "Endurlesa",
     "Error sending your message" : "Villa við að senda skilaboðin þín",
     "Retry" : "Reyna aftur",
     "Uploading attachments …" : "Sendi inn viðhengi…",
     "Sending …" : "Sendi ...",
+    "First day" : "Fyrsta dag",
     "Message" : "Skilaboð",
-    "Delete" : "Eyða",
     "Copy to clipboard" : "Afrita á klippispjald",
     "Add" : "Bæta við",
     "Close" : "Loka",
@@ -160,11 +174,11 @@ OC.L10N.register(
     "Tags" : "Merki",
     "Select tags" : "Veldu merki",
     "Clear" : "Hreinsa",
-    "Search" : "Leita",
     "Date" : "Dagsetning",
     "Disabled" : "Óvirkt",
     "Enabled" : "Virkt",
     "Custom" : "Sérsniðið",
+    "This weekend – {timeLocale}" : "Þessa helgi – {timeLocale}",
     "Signature …" : "Undirskrift …",
     "Save signature" : "Vista undirskrift",
     "Delete tag" : "Eyða merki",
@@ -204,17 +218,10 @@ OC.L10N.register(
     "Valid until" : "Gildir til",
     "Certificate" : "Skilríki",
     "Submit" : "Senda inn",
-    "Keyboard shortcut" : "Flýtilykill",
-    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
-    "Speed up your Mail experience with these quick shortcuts." : "Flýttu fyrir vinnu þinni með póst með þessum flýtilyklum.",
-    "Compose new message" : "Semja ný skilaboð",
-    "Newer message" : "Nýrri skilaboð",
-    "Older message" : "Eldri skilaboð",
-    "Toggle star" : "Víxla stjörnumerkingu af/á",
-    "Toggle unread" : "Víxla ólesnu af/á",
-    "Archive" : "Setja í safnskrá",
     "Account connected" : "Aðgangur er tengdur",
     "Connect your mail account" : "Tengdu notandaaðganginn þinn",
+    "Tomorrow – {timeLocale}" : "Á morgun – {timeLocale}",
+    "Later today – {timeLocale}" : "Síðar í dag – {timeLocale}",
     "Itinerary for {type} is not supported yet" : "Það er ekki ennþá stuðningur við leið af gerðinni {type}",
     "All" : "Allt",
     "Drafts" : "Drög",
