@@ -30,12 +30,23 @@ OC.L10N.register(
     "Cancel" : "უარყოფა",
     "Add mail account" : "საფოსტო ანგარიშის დამატება",
     "Use Gravatar and favicon avatars" : "მოიხმარეთ Gravatar და favicon ავატარები",
+    "Register" : "რეგისტრაცია",
+    "Compose new message" : "ახალი წერილის შედგენა",
+    "Newer message" : "უფრო ახალი წერილი",
+    "Older message" : "ძველი წერილი",
+    "Toggle star" : "ვარსკლავის გადართვა",
+    "Toggle unread" : "წაუკითხავის გადართვა",
+    "Archive" : "არქივი",
+    "Delete" : "გაუქმება",
+    "Search" : "ძიება",
+    "Send" : "გაგზავნა",
+    "Refresh" : "განახლება",
     "Select account" : "აირჩიეთ ანგარიში",
     "Subject" : "სათაური",
     "Upload attachment" : "დანართის ატვირთვა",
     "Add attachment from Files" : "დანართის დამატება ფაილებიდან",
-    "Send" : "გაგზავნა",
     "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
+    "Choose" : "აირჩიეთ",
     "Confirm" : "დადასტურება",
     "Unfavorite" : "რჩეულებიდან ამოშლა",
     "Favorite" : "რჩეული",
@@ -46,11 +57,11 @@ OC.L10N.register(
     "Back" : "უკან",
     "Forward" : "წინ",
     "All day" : "მთელი დღე",
+    "Description" : "აღწერილობა",
     "Create" : "შექმნა",
     "Comment" : "კომენტარი",
     "Accept" : "მიღება",
     "Decline" : "ურაყოფა",
-    "Choose" : "აირჩიეთ",
     "Other" : "სხვა",
     "Reply" : "პასუხი",
     "Import into calendar" : "იმპორტი კალენდარში",
@@ -67,18 +78,15 @@ OC.L10N.register(
     "Mark all as read" : "ყველას წაკითხულად მონიშვნა",
     "Clear cache" : "კეშის გასუფთავება",
     "New message" : "ახალი წერილი",
-    "Refresh" : "განახლება",
     "Retry" : "ვცადოთ ახლიდან",
     "Sending …" : "იგზავნება …",
     "Message" : "წერილი",
-    "Delete" : "გაუქმება",
     "Copy to clipboard" : "კოპირება ბუფერში",
     "Add" : "დამატება",
     "Close" : "დახურვა",
     "Tags" : "ტეგები",
     "Select tags" : "აირჩიეთ ტეგები",
     "Clear" : "გასუფთავება",
-    "Search" : "ძიება",
     "Date" : "თარიღი",
     "Disabled" : "არაა მოქმედი",
     "Enabled" : "მოქმედია",
@@ -97,15 +105,6 @@ OC.L10N.register(
     "Valid until" : "ვარგისია",
     "Certificate" : "სერტიფიკატი",
     "Submit" : "გაგზავნა",
-    "Keyboard shortcut" : "კლავიატურის კომბინაცია",
-    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
-    "Speed up your Mail experience with these quick shortcuts." : "მოიხმარეთ ეს კომბინაციები ფოსტასთან უფრო სწრაფად სამუშაოდ.",
-    "Compose new message" : "ახალი წერილის შედგენა",
-    "Newer message" : "უფრო ახალი წერილი",
-    "Older message" : "ძველი წერილი",
-    "Toggle star" : "ვარსკლავის გადართვა",
-    "Toggle unread" : "წაუკითხავის გადართვა",
-    "Archive" : "არქივი",
     "Connect your mail account" : "დააკავშირეთ თქვენი ელ-ფოსტის ანგარიში",
     "All" : "ყველა",
     "Drafts" : "მონახაზები",
