@@ -64,21 +64,36 @@ OC.L10N.register(
     "Preferred writing mode for new messages and replies." : "Pageidaujama rašymo veiksena naujuose laiškuose ir atsakant į laiškus.",
     "Default folders" : "Numatytieji aplankai",
     "Autoresponder" : "Atsakiklis",
-    "Trusted senders" : "Patikimi siuntėjai",
     "Mail server" : "Pašto serveris",
     "Go back" : "Grįžti",
     "Change name" : "Keisti vardą",
     "Email address" : "El. pašto adresas",
     "Add alias" : "Pridėti alternatyvų vardą",
     "Cancel" : "Atsisakyti",
+    "Mail settings" : "Pašto nustatymai",
+    "Layout" : "Išdėstymas",
+    "List" : "Sąrašas",
     "Add mail account" : "Pridėti pašto paskyrą",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Leisti programėlei rinkti duomenis apie jūsų sąveikas. Remiantis šiais duomenimis, programėlė prisitaikys prie jūsų nuostatų. Duomenys bus laikomi tik vietoje.",
+    "Trusted senders" : "Patikimi siuntėjai",
     "Use Gravatar and favicon avatars" : "Naudoti Gravatar ir svetainių piktogramų avatarus",
     "Register as application for mail links" : "Registruoti kaip pašto nuorodų programėlę",
-    "Show keyboard shortcuts" : "Rodyti sparčiuosius klavišus",
+    "Register" : "Registruotis",
+    "Sorting" : "Rikiavimas",
     "Newest" : "Naujausios",
     "Oldest" : "Seniausios",
     "Looking for a way to encrypt your emails?" : "Ieškote būdo šifruoti el. laiškus?",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Leisti programėlei rinkti duomenis apie jūsų sąveikas. Remiantis šiais duomenimis, programėlė prisitaikys prie jūsų nuostatų. Duomenys bus laikomi tik vietoje.",
+    "Keyboard" : "Klaviatūra",
+    "Compose new message" : "Rašyti naują laišką",
+    "Newer message" : "Naujesni laiškai",
+    "Older message" : "Senesni laiškai",
+    "Toggle star" : "Perjungti laiško žymėjimą, kaip pažymėtą žvaigždute",
+    "Toggle unread" : "Perjungti laiško žymėjimą, kaip neskaityto",
+    "Archive" : "Archyvuoti",
+    "Delete" : "Ištrinti",
+    "Search" : "Ieškoti",
+    "Send" : "Siųsti",
+    "Refresh" : "Įkelti iš naujo",
     "Could not update preference" : "Nepavyko atnaujinti nuostatos",
     "From" : "Nuo",
     "Select account" : "Pasirinkti paskyrą",
@@ -86,7 +101,6 @@ OC.L10N.register(
     "Contact or email address …" : "Adresatas ar el. pašto adresas…",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
-    "No contacts found." : "Adresatų nerasta.",
     "Subject" : "Tema",
     "Subject …" : "Tema…",
     "This message came from a noreply address so your reply will probably not be read." : "Šis laiškas atėjo iš adreso, kuris nėra skirtas atsakyti, taigi jūsų atsakymas, tikriausiai, nebus perskaitytas.",
@@ -98,11 +112,11 @@ OC.L10N.register(
     "Draft saved" : "Juodraštis įrašytas",
     "Save draft" : "Įrašyti juodraštį",
     "Discard & close draft" : "Atmesti ir užverti juodraštį",
+    "Enable formatting" : "Įjungti formatavimą",
+    "Disable formatting" : "Išjungti formatavimą",
     "Upload attachment" : "Įkelti priedą",
     "Add attachment from Files" : "Pridėti priedą iš Failų",
     "Send later" : "Siųsti vėliau",
-    "Enable formatting" : "Įjungti formatavimą",
-    "Disable formatting" : "Išjungti formatavimą",
     "Sign message with S/MIME" : "Pasirašyti laišką naudojant S/MIME",
     "Encrypt message with S/MIME" : "Šifruoti laišką naudojant S/MIME",
     "Encrypt message with Mailvelope" : "Šifruoti laišką naudojant Mailvelope",
@@ -113,12 +127,12 @@ OC.L10N.register(
     "Encrypt with S/MIME and send" : "Šifruoti naudojant S/MIME ir siųsti",
     "Encrypt with Mailvelope and send later" : "Šifruoti naudojant Mailvelope ir siųsti vėliau",
     "Encrypt with Mailvelope and send" : "Šifruoti naudojant Mailvelope ir siųsti",
-    "Send" : "Siųsti",
     "Turn off formatting" : "Išjungti formatavimą",
     "Turn off and remove formatting" : "Išjungti ir šalinti formatavimą",
     "Keep formatting" : "Palikti formatavimą",
     "Choose a file to add as attachment" : "Pasirinkite failą, kurį prisegsite prie laiško",
     "Choose a file to share as a link" : "Pasirinkite failą, kurį bendrinsite kaip nuorodą",
+    "Choose" : "Pasirinkite",
     "_{count} attachment_::_{count} attachments_" : ["{count} priedas","{count} priedai","{count} priedų","{count} priedas"],
     "Confirm" : "Patvirtinti",
     "Plain text" : "Grynasis tekstas",
@@ -153,6 +167,7 @@ OC.L10N.register(
     "_Mark {number} read_::_Mark {number} read_" : ["Žymėti {number} kaip skaitytą","Žymėti {number} kaip skaitytus","Žymėti {number} kaip skaitytus","Žymėti {number} kaip skaitytą"],
     "Report this bug" : "Pranešti apie šią klaidą",
     "All day" : "Visą dieną",
+    "Description" : "Aprašas",
     "Create" : "Sukurti",
     "Event created" : "Įvykis sukurtas",
     "Could not create event" : "Nepavyko sukurti įvykio",
@@ -166,7 +181,6 @@ OC.L10N.register(
     "Could not open mailbox" : "Nepavyko atverti pašto dėžutės",
     "Loading messages …" : "Įkeliami laiškai…",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksuojami jūsų laiškai. Didelėse pašto dėžutėse tai gali užtrukti šiek tiek ilgiau.",
-    "Choose" : "Pasirinkite",
     "Important info" : "Svarbi informacija",
     "Other" : "Kita",
     "The sender of this message has asked to be notified when you read this message." : "Šio laiško siuntėjas paprašė, kad jam būtų pranešta, kai perskaitysite šį laišką.",
@@ -197,7 +211,6 @@ OC.L10N.register(
     "Always show images from {domain}" : "Visada rodyti paveikslus iš {domain}",
     "Quoted text" : "Cituojamas tekstas",
     "Move" : "Perkelti",
-    "Mail settings" : "Pašto nustatymai",
     "Quota" : "Leidžiamas duomenų kiekis",
     "Show only subscribed mailboxes" : "Rodyti tik prenumeruotas pašto dėžutes",
     "Add mailbox" : "Pridėti pašto dėžutę",
@@ -227,7 +240,6 @@ OC.L10N.register(
     "_{total} message_::_{total} messages_" : ["{total} laiškas","{total} laiškai","{total} laiškų","{total} laiškas"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} neskaitytas iš {total}","{unread} neskaityti iš {total}","{unread} neskaitytų iš {total}","{unread} neskaitytas iš {total}"],
     "New message" : "Naujas laiškas",
-    "Refresh" : "Įkelti iš naujo",
     "Error sending your message" : "Klaida siunčiant jūsų laišką",
     "Retry" : "Bandyti dar kartą",
     "Uploading attachments …" : "Įkeliami priedai …",
@@ -245,7 +257,6 @@ OC.L10N.register(
     "Message" : "Žinutė",
     "Oh Snap!" : "O, ne!",
     "Pending or not sent messages will show up here" : "Čia bus rodomi laukiantys ar neišsiųsti laiškai",
-    "Delete" : "Ištrinti",
     "Message could not be sent" : "Nepavyko išsiųsti laiško",
     "Message deleted" : "Laiškas ištrintas",
     "Contacts with this address" : "Adresatai turintys šį adresą",
@@ -258,7 +269,6 @@ OC.L10N.register(
     "Tags" : "Žymės",
     "Select tags" : "Pasirinkti žymes",
     "Clear" : "Išvalyti",
-    "Search" : "Ieškoti",
     "Date" : "Data",
     "Disabled" : "Išjungta",
     "Enabled" : "Įjungta",
@@ -326,15 +336,6 @@ OC.L10N.register(
     "Submit" : "Pateikti",
     "Certificate imported successfully" : "Liudijimas sėkmingai importuotas",
     "Failed to import the certificate" : "Nepavyko importuoti liudijimo",
-    "Keyboard shortcut" : "Spartusis klavišas",
-    "Keyboard shortcuts" : "Klaviatūros greitieji klavišai",
-    "Speed up your Mail experience with these quick shortcuts." : "Padidinkite savo našumą naudodamiesi šiomis nuorodomis.",
-    "Compose new message" : "Rašyti naują laišką",
-    "Newer message" : "Naujesni laiškai",
-    "Older message" : "Senesni laiškai",
-    "Toggle star" : "Perjungti laiško žymėjimą, kaip pažymėtą žvaigždute",
-    "Toggle unread" : "Perjungti laiško žymėjimą, kaip neskaityto",
-    "Archive" : "Archyvuoti",
     "Account connected" : "Paskyra prijungta",
     "You can close this window" : "Galite užverti šį langą",
     "Connect your mail account" : "Priregistruoti elektroninio pašto paskyrą",
