@@ -39,13 +39,19 @@ OC.L10N.register(
     "Go back" : "Atpakaļ",
     "Cancel" : "Atcelt",
     "Add mail account" : "Pievienot e-pasta kontu",
+    "Archive" : "Arhīvi",
+    "Delete" : "Dzēst",
+    "Search" : "Meklēt",
+    "Send" : "Sūtīt",
+    "Refresh" : "Atsvaidzināt",
     "Select account" : "Izvēlieties kontu",
     "Subject" : "Temats",
     "Write message …" : "Rakstiet ziņu...",
     "Add attachment from Files" : "Pievienot pielikumu no failiem",
     "Enter a date" : "Ievadiet datumu",
-    "Send" : "Sūtīt",
     "Choose a file to add as attachment" : "Izvēlēties datni ko pievienot kā pielikumu",
+    "Choose a file to share as a link" : "Izvēlieties failu, ko vēlaties koplietot kā saiti",
+    "Choose" : "Izvēlies",
     "Confirm" : "Apstiprināt",
     "Favorite" : "Favorīts",
     "Read" : "Lasīt",
@@ -53,13 +59,14 @@ OC.L10N.register(
     "Select" : "Atzīmēt",
     "Edit tags" : "Rediģēt atzīmes",
     "Back" : "Atpakaļ",
+    "Create event" : "Izveidot notikumu",
     "Forward" : "Turpināt",
     "All day" : "Visas dienas",
+    "Description" : "Apraksts",
     "Create" : "Izveidot",
     "Comment" : "Komentārs",
     "Accept" : "Pieņemt",
     "Decline" : "Noraidīt",
-    "Choose" : "Izvēlies",
     "Other" : "Cits",
     "Reply" : "Atbildēt",
     "View source" : "Skatīt avotu",
@@ -74,18 +81,16 @@ OC.L10N.register(
     "Quota" : "Kvota",
     "Saving" : "Saglabā",
     "Remove account" : "Noņemt kontu",
+    "Subscribed" : "Abonēts",
     "New message" : "Jauna ziņa",
-    "Refresh" : "Atsvaidzināt",
     "Retry" : "Mēģināt vēlreiz",
     "Sending …" : "Sūta …",
     "Message" : "Ziņojums",
-    "Delete" : "Dzēst",
     "Copy to clipboard" : "Kopēt starpliktuvē",
     "Add" : "Pievienot",
     "Close" : "Aizvērt",
     "Tags" : "Birkas",
     "Select tags" : "Izvēlies birkas",
-    "Search" : "Meklēt",
     "Date" : "Datums",
     "Disabled" : "Atspējots",
     "Enabled" : "Iespējots",
@@ -93,6 +98,7 @@ OC.L10N.register(
     "Delete tag" : "Dzēst atzīmi",
     "Tag already exists" : "Birka jau pastāv",
     "Remove" : "Noņemt",
+    "Untitled event" : "Nenosaukts notikums",
     "Reset" : "Atiestatīt",
     "Client ID" : "Klienta ID",
     "General" : "Vispārīgs",
@@ -102,9 +108,6 @@ OC.L10N.register(
     "Valid until" : "Derīgs līdz",
     "Certificate" : "Sertifikāts",
     "Submit" : "Iesniegt",
-    "Keyboard shortcut" : "Tastatūras saīsne",
-    "Keyboard shortcuts" : "Tastatūras saīsnes",
-    "Archive" : "Arhīvi",
     "Connect your mail account" : "Pievienojiet savu e-pasta kontu",
     "All" : "Visi",
     "Drafts" : "Melnraksti",
@@ -114,6 +117,7 @@ OC.L10N.register(
     "Junk" : "Nevēlams",
     "Sent" : "Izsūtne",
     "Trash" : "Miskaste",
+    "Error while sharing file" : "Radās kļūda koplietojot failu",
     "{from}\n{subject}" : "{from}\n{subject}",
     "Could not load {tag}{name}{endtag}" : "Nevarēja ielādēt {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Radusies problēma, ielādējot {tag}{name}{endtag}",
