@@ -72,7 +72,6 @@ OC.L10N.register(
     "Automatic trash deletion" : "Автоматско бришење на корпата со отпадоци",
     "Days after which messages in Trash will automatically be deleted:" : "Денови по кои пораките во корпата автоматски ќе се избришат:",
     "Autoresponder" : "Автоматски одговор",
-    "Trusted senders" : "Доверливи испраќачи",
     "Mail server" : "Сервер за е-пошта",
     "Update alias" : "Ажурирај алијас",
     "Delete alias" : "Избриши алијас",
@@ -82,11 +81,24 @@ OC.L10N.register(
     "Add alias" : "Додади псевдоним",
     "Create alias" : "Креирај алијас",
     "Cancel" : "Откажи",
+    "Mail settings" : "Параметри за е-пошта",
     "Add mail account" : "Додади е-пошта сметка",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Дозволете апликацијата да собира податоци за вашите интеракции. Врз основа на овие податоци, апликацијата ќе се прилагоди на вашите потреби. Податоците ќе се зачувуваат само локално.",
+    "Trusted senders" : "Доверливи испраќачи",
     "Use Gravatar and favicon avatars" : "Користете Граватар и Фавикон аватари",
     "Register as application for mail links" : "Регистрирај како апликација за отварање на е-пошта линкови ",
-    "Show keyboard shortcuts" : "Прикажи кратенки преку тастатура",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Дозволете апликацијата да собира податоци за вашите интеракции. Врз основа на овие податоци, апликацијата ќе се прилагоди на вашите потреби. Податоците ќе се зачувуваат само локално.",
+    "Register" : "Регистрирај се",
+    "Keyboard" : "Тастатура",
+    "Compose new message" : "Состави нова порака",
+    "Newer message" : "Понови пораки",
+    "Older message" : "Постари пораки",
+    "Toggle star" : "Вклучи омилени",
+    "Toggle unread" : "Вклучи непрочитани",
+    "Archive" : "Архива",
+    "Delete" : "Избриши",
+    "Search" : "Барај",
+    "Send" : "Прати",
+    "Refresh" : "Освежи",
     "Automatically classify importance of new email" : "Автоматски класификација на важноста на новите пораки",
     "Could not update preference" : "Неможе да се ажурираат параметрите",
     "Select an alias" : "Избери алијас",
@@ -98,11 +110,11 @@ OC.L10N.register(
     "From" : "Од",
     "Select account" : "Избете сметка",
     "To" : "До",
+    "Select recipient" : "Избери примач",
     "Contact or email address …" : "Контакт или е-пошта адреса ...",
     "Toggle recipients list mode" : "Вклучи ја листата на примачи",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
-    "No contacts found." : "Не е пронајден контакт.",
     "Subject" : "Наслов",
     "Subject …" : "Наслов ...",
     "This message came from a noreply address so your reply will probably not be read." : "Оваа порака е испратена од адреса што е назначена без одговор, така што вашиот одговор веројатно нема да биде прочитан.",
@@ -114,11 +126,11 @@ OC.L10N.register(
     "Draft saved" : "Нацртот е зачуван",
     "Save draft" : "Зачувај примерок",
     "Discard & close draft" : "Отфрли & затвори примерок",
+    "Enable formatting" : "Овозможи форматирање",
+    "Disable formatting" : "Оневозможи форматирање",
     "Upload attachment" : "Прикачи прилог",
     "Add attachment from Files" : "Додади прилог од датотеките",
     "Send later" : "Испрати покасно",
-    "Enable formatting" : "Овозможи форматирање",
-    "Disable formatting" : "Оневозможи форматирање",
     "Request a read receipt" : "Побарај потврда за прочитана порака",
     "Sign message with S/MIME" : "Потпиши ја пораката со S/MIME",
     "Encrypt message with S/MIME" : "Шифрирај порака со S/MIME",
@@ -134,7 +146,6 @@ OC.L10N.register(
     "Encrypt with S/MIME and send" : "Шифрирај со S/MIME и испрати",
     "Encrypt with Mailvelope and send later" : "Шифрирај со Mailvelope и испрати ја подоцна",
     "Encrypt with Mailvelope and send" : "Шифрирај со Mailvelope и испрати",
-    "Send" : "Прати",
     "Message {id} could not be found" : "Пораката {id} не е пронајдена",
     "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Сите постоечки форматирања (како пример: болд, потцртан текст, италик итн.) ќе бидат отстранети.",
     "Turn off formatting" : "Исклучи форматирање",
@@ -142,6 +153,7 @@ OC.L10N.register(
     "Keep formatting" : "Зачувај го форматирањето",
     "Choose a file to add as attachment" : "Избери датотека за да додадете прилог",
     "Choose a file to share as a link" : "Избери датотека за да се сподели како линк",
+    "Choose" : "Избери",
     "_{count} attachment_::_{count} attachments_" : ["{count} прилог","{count} прилози"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Прилогот ја надминува најголемата дозволена големина за прилози од {size}. Споделете го прилогот со линк.","Прилозите ја надминуваат најголемата дозволена големина за прилози од {size}. Споделете ги прилозите со линк."],
     "Untitled message" : "Неименувана порака",
@@ -185,6 +197,7 @@ OC.L10N.register(
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Препрати како прилог","Препрати {number} како прилозиt"],
     "Report this bug" : "Пријави грешка",
     "All day" : "Цели денови",
+    "Select calendar" : "Избери календар",
     "Create" : "Креирај",
     "Event created" : "Создаден е настан",
     "Could not create event" : "Неможе да се креира настан",
@@ -203,7 +216,6 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Индексирање на пораките. Ова може да трае многу долго за големи сандачиња.",
     "Choose target mailbox" : "Изберете дојдовно сандаче",
     "No more submailboxes in here" : "Нема повеќе подсандачиња тука",
-    "Choose" : "Избери",
     "Important info" : "Важна информација",
     "Other" : "Останато",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Пораките автоматски ќе бидат означени како важни врз основа на кои пораки сте комуницирале или сте ги означиле како важни. На почетокот можеби ќе треба рачно да ја менувате важноста да го научите системот, но тоа ќе се подобрува со текот на времето.",
@@ -238,7 +250,6 @@ OC.L10N.register(
     "Move" : "Премести",
     "Moving" : "Преместува",
     "Moving message" : "Преместување порака",
-    "Mail settings" : "Параметри за е-пошта",
     "Quota" : "Квота",
     "Show only subscribed mailboxes" : "Прикажи само претплатени сандачиња",
     "Add mailbox" : "Додади сандаче",
@@ -274,7 +285,6 @@ OC.L10N.register(
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} непрочитана од {total}","{unread} непрочитани од {total}"],
     "Outbox" : "Излезно сандаче",
     "New message" : "Нова порака",
-    "Refresh" : "Освежи",
     "Error sending your message" : "Грешка при испраќање на пораката",
     "Retry" : "Обидете се повторно",
     "Uploading attachments …" : "Прикачување на прилог ...",
@@ -295,7 +305,6 @@ OC.L10N.register(
     "Save autoresponder" : "Зачувај автоматски одговор",
     "Could not open outbox" : "Неможе да се отвори излезното сандаче",
     "Pending or not sent messages will show up here" : "Овде се појавуваат пораките кој се на чекање или што не се испратени",
-    "Delete" : "Избриши",
     "Message could not be sent" : "Пораката неможе да се испрати",
     "Message deleted" : "Пораката е избришана",
     "Contacts with this address" : "Контакти со оваа адреса",
@@ -318,7 +327,6 @@ OC.L10N.register(
     "Marked as" : "Означено како",
     "Has attachments" : "Има прилози",
     "Clear" : "Исчисти",
-    "Search" : "Барај",
     "Date" : "Датум",
     "Disabled" : "Оневозможено",
     "Enabled" : "Овозможено",
@@ -343,7 +351,6 @@ OC.L10N.register(
     "Tag name is a hidden system tag" : "Името на ознаката е сокриена системска ознака",
     "Tag already exists" : "Тагот веќе постои",
     "An error occurred, unable to create the tag." : "Настана грешка, неможе да се креира ознака.",
-    "Select calendar" : "Избери календар",
     "Not found" : "Не е пронајдено",
     "Could not load your message thread" : "Неможат да се преземат информации за пораката",
     "Mark as unfavorite" : "Од-означи омилена",
@@ -391,15 +398,6 @@ OC.L10N.register(
     "Valid until" : "Валиден до",
     "Certificate" : "Сертификат",
     "Submit" : "Испрати",
-    "Keyboard shortcut" : "Кратенка преку тастатура",
-    "Keyboard shortcuts" : "Кратенки преку тастатура",
-    "Speed up your Mail experience with these quick shortcuts." : "Забрзајте го вашето искуство со овие брзи кратенки.",
-    "Compose new message" : "Состави нова порака",
-    "Newer message" : "Понови пораки",
-    "Older message" : "Постари пораки",
-    "Toggle star" : "Вклучи омилени",
-    "Toggle unread" : "Вклучи непрочитани",
-    "Archive" : "Архива",
     "Account connected" : "Сметката е поврзана",
     "You can close this window" : "Можете да го затворите овој прозорец",
     "Connect your mail account" : "Поврзете ја вашата е-пошта сметка",
