@@ -22,21 +22,27 @@ OC.L10N.register(
     "Signature" : "Гарын үсэг",
     "Go back" : "Буцах",
     "Cancel" : "болиулах",
+    "List" : "Жагсаалт",
     "Add mail account" : "шуудангийн хаяг нэмэх",
+    "Archive" : "архив",
+    "Delete" : "Устгах",
+    "Search" : "Хайх",
+    "Send" : "илгээх",
+    "Refresh" : "Сэргээх",
     "Select account" : "Аккаунт сонгох",
     "Subject" : "Сэдэв",
     "Add attachment from Files" : "Файлаас хавсралт нэмэх",
-    "Send" : "илгээх",
+    "Choose" : "Сонгох",
     "Confirm" : "Батлах",
     "Favorite" : "Дуртай",
     "Select" : "Сонгох",
     "Back" : "буцах",
     "Forward" : "дамжих",
+    "Description" : "Тодорхойлолт",
     "Create" : "Үүсгэх",
     "Comment" : "undefined",
     "Accept" : "Хүлээн зөвшөөрөх",
     "Decline" : "Зөвшөөрөхгүй",
-    "Choose" : "Сонгох",
     "Other" : "Бусад",
     "Reply" : "хариулт",
     "Download attachment" : "Татаж авах хавсралт",
@@ -50,13 +56,10 @@ OC.L10N.register(
     "Remove account" : "Аккаунт устгах",
     "Loading …" : "Уншиж байна...",
     "New message" : "шинэ зурвас",
-    "Refresh" : "Сэргээх",
     "Retry" : "Дахин оролдох",
     "Sending …" : "илгээмж",
-    "Delete" : "Устгах",
     "Add" : "нэмэх",
     "Tags" : "Tag-үүд",
-    "Search" : "Хайх",
     "Date" : "Он сар өдөр",
     "Disabled" : "идэвхигүй",
     "Enabled" : "Идэвхижүүлэх",
@@ -70,8 +73,6 @@ OC.L10N.register(
     "Port" : "порт",
     "Certificate" : "Гэрчилгээ",
     "Submit" : "мэдэгдэх",
-    "Keyboard shortcut" : "Keyboard товчлуур",
-    "Archive" : "архив",
     "Connect your mail account" : "Таны мэйл бүртгэлийг холбоно",
     "All" : "бүх",
     "Drafts" : "ноорог",
