@@ -51,7 +51,6 @@ OC.L10N.register(
     "Preferred writing mode for new messages and replies." : "Gewenste schrijfmodus voor nieuwe berichten en antwoorden.",
     "Default folders" : "Standaardmappen",
     "Sieve filter rules" : "Sieve filterregels",
-    "Trusted senders" : "Vertrouwde afzenders",
     "Mail server" : "Mailserver",
     "Sieve filter server" : "Sieve filterserver",
     "Update alias" : "Bijwerken alias",
@@ -63,11 +62,25 @@ OC.L10N.register(
     "Add alias" : "Voeg bijnaam toe",
     "Create alias" : "Aanmaken alias",
     "Cancel" : "Annuleren",
+    "List" : "Lijst",
     "Add mail account" : "Voeg e-mailaccount toe",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Laat de app gegevens verzamelen over jouw interacties. Op basis van deze gegevens zal de app zich aanpassen aan je voorkeuren. De gegevens worden alleen lokaal opgeslagen.",
+    "Trusted senders" : "Vertrouwde afzenders",
     "Use Gravatar and favicon avatars" : "Gebruik Gravatar en favicon avatars",
     "Register as application for mail links" : "Registreer als applicatie voor e-maillinks",
-    "Show keyboard shortcuts" : "Toon sneltoetsen",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Laat de app gegevens verzamelen over jouw interacties. Op basis van deze gegevens zal de app zich aanpassen aan je voorkeuren. De gegevens worden alleen lokaal opgeslagen.",
+    "Register" : "Aanmelden",
+    "Sorting" : "Sorteren",
+    "Keyboard" : "Keyboard",
+    "Compose new message" : "Opstellen nieuw bericht",
+    "Newer message" : "Recenter bericht",
+    "Older message" : "Ouder bericht",
+    "Toggle star" : "Omschakelen ster",
+    "Toggle unread" : "Omschakelen ongelezen",
+    "Archive" : "Archiveer",
+    "Delete" : "Verwijderen",
+    "Search" : "Zoeken",
+    "Send" : "Versturen",
+    "Refresh" : "Verversen",
     "Put my text to the bottom of a reply instead of on top of it." : "Zet mijn tekst onderaan een antwoord in plaats van erboven.",
     "Automatically classify importance of new email" : "Automatisch classificeren van belangrijke e-mails",
     "Could not update preference" : "Kon voorkeuren niet bijwerken",
@@ -77,7 +90,6 @@ OC.L10N.register(
     "Contact or email address …" : "Contact of e-mailadres ...",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
-    "No contacts found." : "Geen contacten gevonden.",
     "Subject" : "Onderwerp",
     "Subject …" : "Onderwerp ...",
     "This message came from a noreply address so your reply will probably not be read." : "Dit bericht kwam van een noreply-adres. Je antwoord zal dus niet worden gelezen.",
@@ -86,17 +98,18 @@ OC.L10N.register(
     "Saving draft …" : "Concept aan het opslaan ...",
     "Draft saved" : "Concept opgeslagen",
     "Discard & close draft" : "Verwijderen & concept sluiten",
+    "Enable formatting" : "Inschakelen formattering",
     "Upload attachment" : "Bijlage uploaden",
     "Add attachment from Files" : "Bijlage toevoegen vanuit Bestanden",
-    "Enable formatting" : "Inschakelen formattering",
     "Request a read receipt" : "Vraag een leesbevestiging",
     "Encrypt message with Mailvelope" : "Versleutel bericht met Mailvelope",
     "Enter a date" : "Voeg een datum toe",
     "Add share link from {productName} Files" : "Toevoegen deellink van {productName} Bestanden",
-    "Send" : "Versturen",
     "Message {id} could not be found" : "Bericht {id} kon niet worden gevonden",
     "Choose a file to add as attachment" : "Kies een bestand om als bijlage toe te voegen",
     "Choose a file to share as a link" : "Kies een bestand om als link te delen",
+    "Choose" : "Kies",
+    "_{count} attachment_::_{count} attachments_" : ["{count} bijlagen","{count} bijlagen"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["De bijlage overschrijdt de toegestane omvang van {size}. Deel de bestanden in plaats daarvan via een link.","De bijlagen overschrijden de toegestane omvang van {size}. Deel de bestanden in plaats daarvan via een link."],
     "Confirm" : "Bevestigen",
     "Plain text" : "Platte tekst",
@@ -138,6 +151,7 @@ OC.L10N.register(
     "_Delete {number} thread_::_Delete {number} threads_" : ["Verwijderen {number} draadje","Verwijderen {number} draadjes"],
     "Report this bug" : "Meld deze fout",
     "All day" : "Alle dagen",
+    "Description" : "Omschrijving",
     "Create" : "Aanmaken",
     "Event created" : "Afspraak aangemaakt",
     "Could not create event" : "Kon afspraak niet creëren",
@@ -150,7 +164,6 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexeren van je berichten. Dit kan wat tijd kosten voor grote brievenbussen.",
     "Choose target mailbox" : "Kies doel postbus",
     "No more submailboxes in here" : "Niet meer subpostbussen hier",
-    "Choose" : "Kies",
     "Important info" : "Belangrijke informatie",
     "Other" : "Ander",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Berichten zullen automatisch als belangrijk gemarkeerd worden, gebaseerd op met welke berichten je gewerkt hebt of welke je als belangrijk hebt gemarkeerd. In het begin moet je misschien handmatig de belangrijkheid aanpassen om het systeem in te leren, maar het wordt beter met de tijd.",
@@ -169,6 +182,7 @@ OC.L10N.register(
     "Save to Files" : "Opslaan in Bestanden",
     "Unnamed" : "Onbenoemd",
     "Embedded message" : "Ingebed bericht",
+    "Next week – {timeLocale}" : "Volgende week - {timeLocale}",
     "Choose a folder to store the attachment in" : "Kies een map op de bijlage in op te slaan",
     "Save all to Files" : "Sla alles op in Bestanden",
     "Download Zip" : "Download Zip",
@@ -217,7 +231,6 @@ OC.L10N.register(
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} ongelezen van de {total}","{unread} ongelezen van de {total}"],
     "Outbox" : "Uitbak",
     "New message" : "Nieuw bericht",
-    "Refresh" : "Verversen",
     "Error sending your message" : "Fout bij het versturen van jouw bericht",
     "Retry" : "Opnieuw proberen",
     "Uploading attachments …" : "Bijlage aan het uploaden ...",
@@ -229,7 +242,6 @@ OC.L10N.register(
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Je probeert een e-mail te versturen met veel ontvangers in Aan en /of Cc. Overweeg om Bcc te gebruiken om de adressen van de ontvangers voor elkaar te verbergen.",
     "Message" : "Bericht",
     "Oh Snap!" : "O nee!",
-    "Delete" : "Verwijderen",
     "Contacts with this address" : "Contactpersonen met dit adres",
     "Add to Contact" : "Toevoegen aan contactpersoon",
     "New Contact" : "Nieuwe contactpersoon",
@@ -241,7 +253,6 @@ OC.L10N.register(
     "Tags" : "Tags",
     "Select tags" : "Kies tags",
     "Clear" : "Terug",
-    "Search" : "Zoeken",
     "Date" : "Datum",
     "Disabled" : "Uitgeschakeld",
     "Enabled" : "Ingeschakeld",
@@ -255,11 +266,12 @@ OC.L10N.register(
     "Sieve Password" : "Sieve Wachtwoord",
     "Save sieve settings" : "Bewaar sieve instellingen",
     "Save sieve script" : "Bewaar sieve-script",
+    "This weekend – {timeLocale}" : "Dit weekend - {timeLocale}",
     "Signature …" : "Handtekening ...",
     "Save signature" : "Handtekening opslaan",
     "Place signature above quoted text" : "Plaats handtekening boven de aangehaalde tekst",
-    "Delete tag" : "Verwijderen tag",
     "Saving new tag name …" : "Sla nieuw tag op ...",
+    "Delete tag" : "Verwijderen tag",
     "An error occurred, unable to rename the tag." : "Er is een fout opgetreden, kan tag niet hernoemen",
     "Add default tags" : "Voeg standaard tags toe",
     "Add tag" : "Toevoegen tag",
@@ -356,17 +368,10 @@ OC.L10N.register(
     "Valid until" : "Geldig tot",
     "Certificate" : "Certificaat",
     "Submit" : "Verwerken",
-    "Keyboard shortcut" : "Sneltoets",
-    "Keyboard shortcuts" : "Sneltoetsen",
-    "Speed up your Mail experience with these quick shortcuts." : "Versnel je e-mailervaring met deze handige snelkoppelingen.",
-    "Compose new message" : "Opstellen nieuw bericht",
-    "Newer message" : "Recenter bericht",
-    "Older message" : "Ouder bericht",
-    "Toggle star" : "Omschakelen ster",
-    "Toggle unread" : "Omschakelen ongelezen",
-    "Archive" : "Archiveer",
     "Account connected" : "Account verbonden",
     "Connect your mail account" : "Verbind je e-mailaccount",
+    "Tomorrow – {timeLocale}" : "Morgen - {timeLocale}",
+    "Later today – {timeLocale}" : "Later vandaag – {timeLocale}",
     "Itinerary for {type} is not supported yet" : "route voor {type} wordt nog niet ondersteund",
     "All" : "Alle",
     "Drafts" : "Concepten",
