@@ -12,25 +12,26 @@ OC.L10N.register(
     "Connect" : "Kopla til",
     "Signature" : "Signatur",
     "Cancel" : "Avbryt",
+    "Delete" : "Ta bort",
+    "Search" : "Search",
     "Send" : "Send",
+    "Refresh" : "Last inn på nytt",
+    "Choose" : "Vel",
     "Favorite" : "Favoritt",
     "Select" : "Vel",
     "Back" : "Tilbake",
+    "Description" : "Skildring",
     "Create" : "Lag",
     "Comment" : "Kommentér",
-    "Choose" : "Vel",
     "Other" : "Anna",
     "Reply" : "Svare",
     "Move" : "Move",
     "Quota" : "Kvote",
     "Saving" : "Lagrar",
-    "Refresh" : "Last inn på nytt",
     "Retry" : "Forsøk att",
-    "Delete" : "Ta bort",
     "Add" : "Legg til",
     "Close" : "Lat att",
     "Tags" : "Emneord",
-    "Search" : "Search",
     "Date" : "Dato",
     "Disabled" : "Deaktivert",
     "Remove" : "Fjern",
@@ -40,7 +41,6 @@ OC.L10N.register(
     "Host" : "Tenar",
     "Port" : "Port",
     "Certificate" : "Sertifikat",
-    "Keyboard shortcuts" : "Tastatursnarvegar",
     "All" : "Alle",
     "Favorites" : "Favorit",
     "Sent" : "Sendt",
