@@ -12,6 +12,8 @@ OC.L10N.register(
     "To Do" : "Do zrobienia",
     "Later" : "Później",
     "Mail" : "Poczta",
+    "You are reaching your mailbox quota limit for {account_email}" : "Osiągnięto limit skrzynki pocztowej dla {account_email}",
+    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Obecnie używasz {percentage} przestrzeni dyskowej skrzynki pocztowej. Zrób trochę miejsca, usuwając niepotrzebne wiadomości e-mail.",
     "Mails" : "E-maile",
     "💌 A mail app for Nextcloud" : "💌 Aplikacja poczty dla Nextcloud",
     "Your session has expired. The page will be reloaded." : "Twoja sesja wygasła. Strona zostanie ponownie załadowana.",
@@ -19,6 +21,8 @@ OC.L10N.register(
     "Sent messages are saved in:" : "Wysłane wiadomości są zapisywane w:",
     "Deleted messages are moved in:" : "Usunięte wiadomości są przenoszone do:",
     "Archived messages are moved in:" : "Zarchiwizowane wiadomości są przenoszone w:",
+    "Snoozed messages are moved in:" : "Odłożone wiadomości są przenoszone:",
+    "Junk messages are saved in:" : "Wiadomości-śmieci są zapisywane w:",
     "Auto" : "Automatycznie",
     "Name" : "Nazwa",
     "Mail address" : "Adres mailowy",
@@ -62,6 +66,7 @@ OC.L10N.register(
     "IMAP connection failed" : "Połączenie IMAP nie powiodło się",
     "SMTP connection failed" : "Połączenie SMTP nie powiodło się",
     "Authorization pop-up closed" : "Wyskakujące okienko autoryzacji zostało zamknięte",
+    "Configuration discovery temporarily not available. Please try again later." : "Wykrywanie konfiguracji tymczasowo niedostępne. Spróbuj ponownie później.",
     "There was an error while setting up your account" : "Wystąpił błąd podczas zakładania konta",
     "Account settings" : "Ustawienia konta",
     "Aliases" : "Aliasy",
@@ -70,14 +75,17 @@ OC.L10N.register(
     "Writing mode" : "Tryb pisania",
     "Preferred writing mode for new messages and replies." : "Preferowany tryb pisania dla nowych wiadomości i odpowiedzi.",
     "Default folders" : "Katalogi domyślne",
+    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "Foldery używane dla wersji roboczych, wysłanych wiadomości, usuniętych wiadomości, zarchiwizowanych wiadomości i wiadomości-śmieci.",
+    "Automatic trash deletion" : "Automatyczne usuwanie śmieci",
+    "Days after which messages in Trash will automatically be deleted:" : "Dni, po których wiadomości w Koszu zostaną automatycznie usunięte:",
     "Autoresponder" : "Automatyczna wiadomość zwrotna",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automatyczna odpowiedź na przychodzące wiadomości. Jeśli ktoś wyśle Tobie kilka wiadomości, ta automatyczna odpowiedź będzie wysyłana co najwyżej raz na 4 dni.",
     "Please connect to a sieve server first." : "Najpierw połącz się z serwerem Sieve.",
     "Sieve filter rules" : "Zasady filtra Sieve",
-    "Trusted senders" : "Zaufani nadawcy",
     "Mail server" : "Serwer poczty",
     "Sieve filter server" : "Serwer filtra Sieve",
     "Update alias" : "Zaktualizuj alias",
+    "Rename alias" : "Zmień nazwę aliasu",
     "Show update alias form" : "Pokaż formularz aktualizacji aliasu",
     "Delete alias" : "Usuń alias",
     "Go back" : "Wstecz",
@@ -86,27 +94,48 @@ OC.L10N.register(
     "Add alias" : "Dodaj alias",
     "Create alias" : "Utwórz alias",
     "Cancel" : "Anuluj",
+    "Mail settings" : "Ustawienia Poczty",
+    "Layout" : "Wygląd",
+    "List" : "Lista",
+    "Account creation" : "Tworzenie konta",
     "Add mail account" : "Dodaj konto e-mail",
+    "Data collection consent" : "Zgoda na zbieranie danych",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Zezwól aplikacji na zbieranie danych o Twoich interakcjach. Na podstawie tych danych aplikacja dostosuje się do Twoich preferencji. Dane będą przechowywane tylko lokalnie.",
+    "Trusted senders" : "Zaufani nadawcy",
+    "Gravatar settings" : "Ustawienia Gravatara",
     "Use Gravatar and favicon avatars" : "Używaj awatarów Gravatar i favicon",
+    "Reply text position" : "Pozycja tekstu odpowiedzi",
     "Register as application for mail links" : "Zarejestruj się jako aplikacja do linków pocztowych",
-    "Show keyboard shortcuts" : "Pokaż skróty klawiaturowe",
+    "Register" : "Zarejestruj się",
     "Manage S/MIME certificates" : "Zarządzaj certyfikatami S/MIME",
+    "Sorting" : "Sortuj",
     "Newest" : "Najnowsza",
     "Oldest" : "Najstarsza",
     "Looking for a way to encrypt your emails?" : "Szukasz sposobu na szyfrowanie wiadomości e-mail?",
-    "Install Mailvelope browser extension here" : "Zainstaluj rozszerzenie przeglądarki Mailvelope tutaj",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Zezwól aplikacji na zbieranie danych o Twoich interakcjach. Na podstawie tych danych aplikacja dostosuje się do Twoich preferencji. Dane będą przechowywane tylko lokalnie.",
+    "Keyboard" : "Klawiatura",
+    "Compose new message" : "Napisz nową wiadomość",
+    "Newer message" : "Nowsza wiadomość",
+    "Older message" : "Starsza wiadomość",
+    "Toggle star" : "Oznacz gwiazdką",
+    "Toggle unread" : "Oznacz jako nieprzeczytane",
+    "Archive" : "Archiwizuj",
+    "Delete" : "Usuń",
+    "Search" : "Szukaj",
+    "Send" : "Wyślij",
+    "Refresh" : "Odśwież",
+    "Activate" : "Aktywuj",
     "Put my text to the bottom of a reply instead of on top of it." : "Umieść mój tekst na dole odpowiedzi, zamiast nad nią.",
     "Automatically classify importance of new email" : "Automatycznie klasyfikuj ważność nowej wiadomości e-mail",
     "Could not update preference" : "Nie udało się zaktualizować preferencji",
+    "Certificate updated" : "Aktualizacja certyfikatu",
     "From" : "Od",
     "Select account" : "Wybierz konto",
     "To" : "Do",
+    "Select recipient" : "Wybierz odbiorcę",
     "Contact or email address …" : "Kontakt lub adres e-mail…",
     "Toggle recipients list mode" : "Przełącz tryb listy odbiorców",
     "Cc" : "DW",
     "Bcc" : "UDW",
-    "No contacts found." : "Nie znaleziono kontaktów.",
     "Subject" : "Temat",
     "Subject …" : "Temat…",
     "This message came from a noreply address so your reply will probably not be read." : "Ta wiadomość przyszła z adresu noreply, więc Twoja odpowiedź prawdopodobnie nie zostanie odczytana.",
@@ -117,12 +146,12 @@ OC.L10N.register(
     "Draft saved" : "Zapisano wersję roboczą",
     "Save draft" : "Zapisz wersję roboczą",
     "Discard & close draft" : "Odrzuć i zamknij wersję roboczą",
+    "Enable formatting" : "Włącz formatowanie",
+    "Disable formatting" : "Wyłącz formatowanie",
     "Upload attachment" : "Dodaj załącznik",
     "Add attachment from Files" : "Dodaj załącznik z Plików",
     "Smart picker" : "Inteligentna selekcja",
     "Send later" : "Wyślij później",
-    "Enable formatting" : "Włącz formatowanie",
-    "Disable formatting" : "Wyłącz formatowanie",
     "Request a read receipt" : "Poproś o potwierdzenie przeczytania",
     "Encrypt message with Mailvelope" : "Zaszyfruj wiadomość za pomocą Mailvelope",
     "Send now" : "Wyślij teraz",
@@ -132,7 +161,6 @@ OC.L10N.register(
     "Custom date and time" : "Własna data i godzina",
     "Enter a date" : "Wpisz datę",
     "Add share link from {productName} Files" : "Dodaj link do udostępnienia z Plików {productName}",
-    "Send" : "Wyślij",
     "Message {id} could not be found" : "Nie można znaleźć wiadomości {id}",
     "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Wszelkie istniejące formatowanie (na przykład pogrubienie, kursywa, podkreślenie lub obrazy w tekście) zostaną usunięte.",
     "Turn off formatting" : "Wyłącz formatowanie",
@@ -140,8 +168,10 @@ OC.L10N.register(
     "Keep formatting" : "Zachowaj formatowanie",
     "Choose a file to add as attachment" : "Wybierz plik, aby dodać jako załącznik",
     "Choose a file to share as a link" : "Wybierz plik do udostępnienia przez link",
+    "Choose" : "Wybierz",
     "_{count} attachment_::_{count} attachments_" : ["{count} załącznik","{count} załączniki","{count} załączników","{count} załączników"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Załącznik przekracza dozwolony rozmiar załączników z {size}. Zamiast tego udostępnij plik za pośrednictwem linku.","Załączniki przekraczają dozwolony rozmiar załączników z {size}. Zamiast tego udostępnij pliki za pośrednictwem linku.","Załączniki przekraczają dozwolony rozmiar załączników z {size}. Zamiast tego udostępnij pliki za pośrednictwem linku.","Załączniki przekraczają dozwolony rozmiar załączników z {size}. Zamiast tego udostępnij pliki za pośrednictwem linku."],
+    "Untitled message" : "Wiadomość bez tytułu",
     "Confirm" : "Potwierdź",
     "Plain text" : "Zwykły tekst",
     "Rich text" : "Tekst sformatowany",
@@ -186,12 +216,14 @@ OC.L10N.register(
     "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Oznacz {number} jako nieważne","Oznacz {number} jako nieważne","Oznacz {number} jako nieważne","Oznacz {number} jako nieważne"],
     "_Unfavorite {number}_::_Unfavorite {number}_" : ["Nie ulubiona {number}","Nie ulubione {number}","Nie ulubionych {number}","Nie ulubionych {number}"],
     "_Favorite {number}_::_Favorite {number}_" : ["Ulubiona {number}","Ulubione {number}","Ulubionych {number}","Ulubionych {number}"],
+    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Oznacz {numer} jako spam","Oznacz {numer} jako spam","Oznacz {numer} jako spam","Oznacz {numer} jako spam"],
     "_Unselect {number}_::_Unselect {number}_" : ["Odznacz {number}","Odznacz {number}","Odznacz {number}","Odznacz {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Przenieś {number} wątek","Przenieś {number} wątki","Przenieś {number} wątków","Przenieś {number} wątków"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Przekaż {number} jako załącznik","Przekaż {number} jako załączniki","Przekaż {number} jako załączniki","Przekaż {number} jako załączniki"],
     "_Delete {number} thread_::_Delete {number} threads_" : ["Usuń {number} wątek","Usuń {number} wątki","Usuń {number} wątków","Usuń {number} wątków"],
     "Report this bug" : "Zgłoś ten błąd",
     "All day" : "Cały dzień",
+    "Select calendar" : "Wybierz kalendarz",
     "Create" : "Utwórz",
     "Event created" : "Utworzono wydarzenie",
     "Could not create event" : "Nie można utworzyć wydarzenia",
@@ -219,7 +251,6 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksowanie wiadomości. W przypadku większych skrzynek pocztowych może to potrwać trochę dłużej.",
     "Choose target mailbox" : "Wybierz docelową skrzynkę pocztową",
     "No more submailboxes in here" : "Nie ma więcej skrzynek podrzędnych",
-    "Choose" : "Wybierz",
     "Important info" : "Ważna informacja",
     "Other" : "Inne",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Wiadomości będą automatycznie oznaczane jako ważne na podstawie wiadomości, z którymi wchodziłeś w interakcję lub które oznaczałeś jako ważne. Na początku być może trzeba będzie ręcznie zmienić ważność dla uczenia systemu, ale z czasem będzie się poprawiać.",
@@ -259,7 +290,6 @@ OC.L10N.register(
     "Moving" : "przenoszenie",
     "Moving thread" : "Przenoszenie wątku",
     "Moving message" : "Przenoszenie wiadomości",
-    "Mail settings" : "Ustawienia Poczty",
     "Provisioned account is disabled" : "Zabezpieczone konto jest wyłączone",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Zaloguj się przy użyciu hasła, aby włączyć to konto. Bieżąca sesja korzysta z uwierzytelniania bez hasła, m.in. SSO lub WebAuthn.",
     "Quota" : "Limit",
@@ -297,7 +327,6 @@ OC.L10N.register(
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} nieprzeczytana z {total}","{unread} nieprzeczytane z {total}","{unread} nieprzeczytanych z {total}","{unread} nieprzeczytanych z {total}"],
     "Outbox" : "Skrzynka nadawcza",
     "New message" : "Nowa wiadomość",
-    "Refresh" : "Odśwież",
     "Error sending your message" : "Błąd podczas wysyłania wiadomości",
     "Retry" : "Powtórz",
     "Uploading attachments …" : "Wysyłanie załączników…",
@@ -320,7 +349,6 @@ OC.L10N.register(
     "Save autoresponder" : "Zapisz automatyczną wiadomość zwrotną",
     "Could not open outbox" : "Nie udało się otworzyć skrzynki nadawczej",
     "Pending or not sent messages will show up here" : "Oczekujące lub niewysłane wiadomości pojawią się tutaj",
-    "Delete" : "Usuń",
     "Message could not be sent" : "Nie można wysłać wiadomości",
     "Message deleted" : "Wiadomość usunięta",
     "Contacts with this address" : "Kontakty z adresem",
@@ -342,7 +370,6 @@ OC.L10N.register(
     "Marked as" : "Oznaczono jako",
     "Has attachments" : "Posiada załączniki",
     "Clear" : "Wyczyść ",
-    "Search" : "Szukaj",
     "Date" : "Data",
     "Disabled" : "Wyłączone",
     "Enabled" : "Włączone",
@@ -361,8 +388,8 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Twój podpis jest większy niż 2 MB. Może to wpłynąć na wydajność Twojego edytora.",
     "Save signature" : "Zapisz podpis",
     "Place signature above quoted text" : "Umieść podpis nad cytowanym tekstem",
-    "Delete tag" : "Usuń etykiety",
     "Saving new tag name …" : "Zapisywanie nowej nazwy etykiety…",
+    "Delete tag" : "Usuń etykiety",
     "An error occurred, unable to rename the tag." : "Wystąpił błąd, nie można zmienić nazwy etykiety.",
     "Add default tags" : "Dodaj etykiety domyślne",
     "Add tag" : "Dodaj etykietę",
@@ -492,15 +519,6 @@ OC.L10N.register(
     "Certificate imported successfully" : "Certyfikat został zaimportowany pomyślnie",
     "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Nie udało się zaimportować certyfikatu. Upewnij się, że klucz prywatny jest zgodny z certyfikatem i nie jest chroniony hasłem.",
     "Failed to import the certificate" : "Nie udało się zaimportować certyfikatu",
-    "Keyboard shortcut" : "Skrót klawiaturowy",
-    "Keyboard shortcuts" : "Skróty klawiaturowe",
-    "Speed up your Mail experience with these quick shortcuts." : "Aby przyspieszyć korzystanie z aplikacji Poczty użyj tych skrótów.",
-    "Compose new message" : "Napisz nową wiadomość",
-    "Newer message" : "Nowsza wiadomość",
-    "Older message" : "Starsza wiadomość",
-    "Toggle star" : "Oznacz gwiazdką",
-    "Toggle unread" : "Oznacz jako nieprzeczytane",
-    "Archive" : "Archiwizuj",
     "Account connected" : "Połączono z kontem",
     "You can close this window" : "Możesz zamknąć okno",
     "Connect your mail account" : "Podłącz konto pocztowe",
