@@ -45,36 +45,42 @@ OC.L10N.register(
     "Writing mode" : "Modo de escrita",
     "Preferred writing mode for new messages and replies." : "Modo de escrita pré definido para novas mensagens e respostas.",
     "Default folders" : "Pastas pré definidas",
-    "Trusted senders" : "Remetentes confiáveis",
     "Mail server" : "Servidor de correio electrónico",
     "Go back" : "Voltar",
     "Change name" : "Alterar nome",
     "Email address" : "Endereço de email",
     "Add alias" : "Adicionar alcunha",
     "Cancel" : "Cancelar",
+    "List" : "Lista",
     "Add mail account" : "Adicionar conta de email",
+    "Trusted senders" : "Remetentes confiáveis",
     "Use Gravatar and favicon avatars" : "Usar Gravatar e favicon avatars",
     "Register as application for mail links" : "Registar como aplicação para ligações de correio",
-    "Show keyboard shortcuts" : "Mostrar atalhos de teclado",
+    "Register" : "Registar",
+    "Compose new message" : "Compor nova mensagem",
+    "Archive" : "Arquivar",
+    "Delete" : "Eliminar",
+    "Search" : "Pesquisar",
+    "Send" : "Enviar",
+    "Refresh" : "Atualizar",
     "From" : "De",
     "Select account" : "Seleccionar uma conta",
     "To" : "Para",
     "Contact or email address …" : "Contacto ou endereço de email",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
-    "No contacts found." : "Não foram encontrados contactos",
     "Subject" : "Assunto",
     "Subject …" : "Assunto...",
     "Write message …" : "Nova mensagem...",
     "Saving draft …" : "A guardar rascunho ...",
     "Draft saved" : "Rascunho guardado",
+    "Enable formatting" : "Activar formatação",
     "Upload attachment" : "Carregar anexo",
     "Add attachment from Files" : "Adicionar anexo a partir dos ficheiros",
-    "Enable formatting" : "Activar formatação",
     "Request a read receipt" : "Solicitar um recibo de leitura",
     "Encrypt message with Mailvelope" : "Cifrar a mensagem com Mailvelope",
-    "Send" : "Enviar",
     "Choose a file to add as attachment" : "Escolha um ficheiro para adicionar como anexo",
+    "Choose" : "Escolher",
     "Confirm" : "Confirmar",
     "Plain text" : "Texto simples",
     "No messages" : "Sem mensagens",
@@ -94,12 +100,12 @@ OC.L10N.register(
     "Forward" : "Encaminhar",
     "Load more" : "Carregar mais",
     "All day" : "Todo o dia",
+    "Description" : "Descrição",
     "Create" : "Criar",
     "Could not create event" : "Não foi possível criar o evento",
     "Comment" : "Comentário",
     "Accept" : "Aceitar",
     "Decline" : "Recusar",
-    "Choose" : "Escolher",
     "Important info" : "Informação importante",
     "Other" : "Outro",
     "Notify the sender" : "Notificar o remetente",
@@ -141,7 +147,6 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Limpe a cache de dados local no caso de ter problemas com a sincronização.",
     "Subscribed" : "Subscrito",
     "New message" : "Nova mensagem",
-    "Refresh" : "Atualizar",
     "Error sending your message" : "Erro ao enviar a sua mensagem",
     "Retry" : "Repetir",
     "Uploading attachments …" : "A enviar anexos ...",
@@ -149,7 +154,6 @@ OC.L10N.register(
     "Warning sending your message" : "Aviso ao enviar a sua mensagem",
     "Send anyway" : "Enviar de qualquer maneira",
     "Message" : "Mensagem",
-    "Delete" : "Eliminar",
     "Contacts with this address" : "Contactos com este endereço",
     "Add to Contact" : "Adicionar aos contactos",
     "New Contact" : "Novo contacto",
@@ -160,7 +164,6 @@ OC.L10N.register(
     "Body" : "Corpo",
     "Tags" : "Etiquetas",
     "Clear" : "Limpar",
-    "Search" : "Pesquisar",
     "Date" : "Data",
     "Disabled" : "Desactivado",
     "Enabled" : "Activo",
@@ -194,10 +197,6 @@ OC.L10N.register(
     "Valid until" : "Válido até",
     "Certificate" : "Certificado",
     "Submit" : "Submeter",
-    "Keyboard shortcut" : "Atalho de teclado",
-    "Keyboard shortcuts" : "Atalhos de teclado",
-    "Compose new message" : "Compor nova mensagem",
-    "Archive" : "Arquivar",
     "Account connected" : "Conta ligada",
     "Connect your mail account" : "Ligue a sua conta de e-mail",
     "All" : "Todos",
