@@ -84,7 +84,6 @@ OC.L10N.register(
     "Autoresponder" : "Автоответчик",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Автоматический ответ на входящие сообщения. Если кто-то отправит вам несколько сообщений, этот автоматический ответ будет отправляться не чаще одного раза в 4 дня.",
     "Sieve filter rules" : "Правила sieve фильтра",
-    "Trusted senders" : "Доверенные отправители",
     "Mail server" : "Почтовый сервер",
     "Sieve filter server" : "Сервер sieve фильтра",
     "Update alias" : "Обновить псевдоним",
@@ -97,16 +96,30 @@ OC.L10N.register(
     "Add alias" : "Добавить псевдоним",
     "Create alias" : "Создать псевдоним",
     "Cancel" : "Отмена",
+    "Mail settings" : "Параметры эл. почты",
+    "List" : "Список",
     "Add mail account" : "Добавить учётную запись",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Разрешить приложению собирать данные о взаимодействии.  Основываясь на этих данных, приложение адаптируется к вашим предпочтениям. Данные будут храниться только локально.",
+    "Trusted senders" : "Доверенные отправители",
     "Use Gravatar and favicon avatars" : "Использовать значки Gravatar и favicon",
     "Register as application for mail links" : "Зарегистрировать в качестве приложения для обработки почтовых ссылок",
-    "Show keyboard shortcuts" : "Показать справку о комбинациях клавиш",
+    "Register" : "Регистрация",
     "Manage S/MIME certificates" : "Управление сертификатами S/MIME",
+    "Sorting" : "Сортировка",
     "Newest" : "Более новые",
     "Oldest" : "Более старые",
     "Looking for a way to encrypt your emails?" : "Необходимо использовать шифрование электронных писем?",
-    "Install Mailvelope browser extension here" : "Установите расширение для браузера Mailvelope здесь",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Разрешить приложению собирать данные о взаимодействии.  Основываясь на этих данных, приложение адаптируется к вашим предпочтениям. Данные будут храниться только локально.",
+    "Keyboard" : "Клавиатура",
+    "Compose new message" : "Создать новое сообщение",
+    "Newer message" : "Самое новое сообщение",
+    "Older message" : "Самое старое сообщение",
+    "Toggle star" : "Переключить отметку звёздочкой",
+    "Toggle unread" : "Переключить отметку прочтения",
+    "Archive" : "Переместить в архив",
+    "Delete" : "Удалить",
+    "Search" : "Поиск",
+    "Send" : "Отправить",
+    "Refresh" : "Обновить",
     "Put my text to the bottom of a reply instead of on top of it." : "Поместить мой текст внизу ответа, а не поверх него.",
     "Automatically classify importance of new email" : "Автоматически определять важность новых писем",
     "Could not update preference" : "Не удалось обновить свойство",
@@ -123,7 +136,6 @@ OC.L10N.register(
     "Toggle recipients list mode" : "Развернуть список получателей",
     "Cc" : "Коп",
     "Bcc" : "СкрКоп",
-    "No contacts found." : "Контакты не найдены.",
     "Subject" : "Тема",
     "Subject …" : "Тема…",
     "This message came from a noreply address so your reply will probably not be read." : "Это сообщение было отправлено с адреса, не предусматривающего получения ответов. Ваше сообщение, направленное на этот адрес, возможно никогда не будет прочитано.",
@@ -135,12 +147,12 @@ OC.L10N.register(
     "Draft saved" : "Черновик сохранён",
     "Save draft" : "Сохранить черновик",
     "Discard & close draft" : "Отменить изменения и закрыть черновик",
+    "Enable formatting" : "Использовать форматирование",
+    "Disable formatting" : "Выключить форматирование",
     "Upload attachment" : "Загрузить файл с ПК",
     "Add attachment from Files" : "Из приложения «Файлы»",
     "Smart picker" : "Умный подборщик",
     "Send later" : "Отправить позже",
-    "Enable formatting" : "Использовать форматирование",
-    "Disable formatting" : "Выключить форматирование",
     "Request a read receipt" : "Запросить подтверждение прочтения",
     "Sign message with S/MIME" : "Подписать сообщение с помощью S/MIME",
     "Encrypt message with S/MIME" : "Зашифровать сообщение с помощью S/MIME",
@@ -156,7 +168,6 @@ OC.L10N.register(
     "Encrypt with S/MIME and send" : "Зашифруйте с помощью S/MIME и отправить",
     "Encrypt with Mailvelope and send later" : "Зашифруйте с помощью Mailvelope и отправьте позже",
     "Encrypt with Mailvelope and send" : "Зашифруйте с помощью Mailvelope и отправьте",
-    "Send" : "Отправить",
     "Message {id} could not be found" : "Не удалось найти сообщение {id}",
     "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Был выбран вариант «Подписать или зашифровать с помощью S/MIME», но у нас нет сертификата для выбранного псевдонима. Сообщение не будет подписано или зашифровано.",
     "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Любое существующее форматирование (например, жирный шрифт, курсив, подчеркивание или встроенные изображения) будет удалено.",
@@ -165,6 +176,7 @@ OC.L10N.register(
     "Keep formatting" : "Сохранить форматирование",
     "Choose a file to add as attachment" : "Выбрать файл для вложения",
     "Choose a file to share as a link" : "Выберите файл для публикации ссылкой",
+    "Choose" : "Выберите",
     "_{count} attachment_::_{count} attachments_" : ["{count} вложение","{count} вложения","{count} вложений","{count} вложений"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Размер этого вложения превышает установленный лимит. Опубликуйте этот файл с доступом по ссылке и перешлите ссылку, вместо отправки файла.","Размер этих вложений превышает установленный лимит. Опубликуйте эти файы с доступом по ссылке и перешлите ссылку, вместо отправки файла.","Размер этих вложений превышает установленный лимит. Опубликуйте эти файы с доступом по ссылке и перешлите ссылку, вместо отправки файла.","Размер этих вложений превышает установленный лимит. Опубликуйте эти файы с доступом по ссылке и перешлите ссылку, вместо отправки файла."],
     "Untitled message" : "Сообщение без названия",
@@ -218,6 +230,8 @@ OC.L10N.register(
     "_Delete {number} thread_::_Delete {number} threads_" : ["Удалить {number} ветку","Удалить {number} ветки","Удалить {number} веток","Удалить {number} веток"],
     "Report this bug" : "Отправить отчёт об этой ошибке",
     "All day" : "Весь день",
+    "Select calendar" : "Выбрать календарь",
+    "Description" : "Описание",
     "Create" : "Создать",
     "Event created" : "Событие создано",
     "Could not create event" : "Не удалось создать событие",
@@ -242,7 +256,6 @@ OC.L10N.register(
     "To archive a message please configure an archive mailbox in account settings" : "Чтобы заархивировать сообщение, настройте архивный почтовый ящик в настройках учетной записи.",
     "Choose target mailbox" : "Выберите папку",
     "No more submailboxes in here" : "Вложенные папки отсутствуют",
-    "Choose" : "Выберите",
     "Important info" : "Важная информация",
     "Other" : "Прочие",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Письма будут автоматически отмечаться важными на основе анализа ваших действий и присвоения метки «Важно». В первое время, возможно, потребуется обучить систему присвоением и удалением меток вручную.",
@@ -281,7 +294,6 @@ OC.L10N.register(
     "Moving" : "Выполняется перемещение",
     "Moving thread" : "Перемещение ветки",
     "Moving message" : "Сообщение перемещается",
-    "Mail settings" : "Параметры эл. почты",
     "Provisioned account is disabled" : "Предоставленный аккаунт отключен",
     "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Пожалуйста, войдите в систему, используя пароль, чтобы активировать эту учетную запись. Текущий сеанс использует аутентификацию без пароля, например. Единый вход или WebAuthn.",
     "Quota" : "Квота",
@@ -321,7 +333,6 @@ OC.L10N.register(
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["Непрочитано {unread} из {total}","Непрочитано {unread} из {total}","Непрочитано {unread} из {total}","Непрочитано {unread} из {total}"],
     "Outbox" : "Исходящие",
     "New message" : "Создать сообщение",
-    "Refresh" : "Обновить",
     "Error sending your message" : "Ошибка при отправке вашего сообщения",
     "Retry" : "Попробовать снова",
     "Uploading attachments …" : "Загрузка вложений ...",
@@ -350,7 +361,6 @@ OC.L10N.register(
     "Save autoresponder" : "Сохранить автоответчик",
     "Could not open outbox" : "Не удалось открыть исходящие",
     "Pending or not sent messages will show up here" : "В этой папке будут представлены отложенные и неотправленные сообщения",
-    "Delete" : "Удалить",
     "Message could not be sent" : "Сообщение не может быть отправлено",
     "Message deleted" : "Сообщение удалено",
     "Contacts with this address" : "Контакты с этим адресом",
@@ -374,7 +384,6 @@ OC.L10N.register(
     "Marked as" : "Отмечено как",
     "Has attachments" : "Имеет вложения",
     "Clear" : "Очистить",
-    "Search" : "Поиск",
     "Date" : "Дата",
     "Disabled" : "Отключено",
     "Enabled" : "Включено",
@@ -395,8 +404,8 @@ OC.L10N.register(
     "Save signature" : "Сохранить подпись",
     "Place signature above quoted text" : "Размещать подпись над цитируемым текстом",
     "Edit name or color" : "Отредактируйте название или цвет",
-    "Delete tag" : "Удалить метку",
     "Saving new tag name …" : "Сохранение нового названия метки…",
+    "Delete tag" : "Удалить метку",
     "Set tag" : "Установить тег",
     "Unset tag" : "Неустановленный тег",
     "An error occurred, unable to rename the tag." : "Не удалось переименовать метку.",
@@ -406,7 +415,6 @@ OC.L10N.register(
     "Tag name is a hidden system tag" : "Имя тега является скрытым системным тегом",
     "Tag already exists" : "Метка уже существует",
     "An error occurred, unable to create the tag." : "Не удалось создать метку.",
-    "Select calendar" : "Выбрать календарь",
     "No calendars with task list support" : "Нет календарей с поддержкой списка задач",
     "Task created" : "Задача создана",
     "Could not create task" : "Не удалось создать задачу",
@@ -549,15 +557,6 @@ OC.L10N.register(
     "Certificate imported successfully" : "Сертификат успешно импортирован",
     "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Не удалось импортировать сертификат. Убедитесь, что закрытый ключ соответствует сертификату и не защищен парольной фразой.",
     "Failed to import the certificate" : "Не удалось импортировать сертификат",
-    "Keyboard shortcut" : "Комбинации клавиш",
-    "Keyboard shortcuts" : "Комбинации клавиш",
-    "Speed up your Mail experience with these quick shortcuts." : "Ускорьте работу с почтой использованием этих комбинаций клавиш.",
-    "Compose new message" : "Создать новое сообщение",
-    "Newer message" : "Самое новое сообщение",
-    "Older message" : "Самое старое сообщение",
-    "Toggle star" : "Переключить отметку звёздочкой",
-    "Toggle unread" : "Переключить отметку прочтения",
-    "Archive" : "Переместить в архив",
     "Account connected" : "Аккаунт подключен",
     "You can close this window" : "Вы можете закрыть это окно",
     "Connect your mail account" : "Настройка учётной записи электронной почты",
