@@ -12,6 +12,8 @@ OC.L10N.register(
     "To Do" : "Naloge",
     "Later" : "Za kasneje",
     "Mail" : "Pošta",
+    "You are reaching your mailbox quota limit for {account_email}" : "Kmalu bo dosežena omejitev prostora za račun {account_email}",
+    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Trenutno uporabljate {percentage} dodaljenega prostora za poštni predal. Prostor lahko povečate z brisanjem nepotrebnih sporočil.",
     "Mails" : "Sporočila",
     "💌 A mail app for Nextcloud" : "💌 Poštni program za Nextcloud",
     "Your session has expired. The page will be reloaded." : "Seja je potekla. Stran bo samodejno osvežena.",
@@ -19,6 +21,7 @@ OC.L10N.register(
     "Sent messages are saved in:" : "Poslana sporočila se shranjujejo v:",
     "Deleted messages are moved in:" : "Izbrisana sporočila so premaknjena v:",
     "Archived messages are moved in:" : "Arhivirana sporočila so premaknjena v:",
+    "Junk messages are saved in:" : "Neželena sporočila se shranjujejo v:",
     "Auto" : "Samodejno",
     "Name" : "Ime",
     "Mail address" : "Elektronski naslov",
@@ -53,6 +56,7 @@ OC.L10N.register(
     "Password required" : "Zahtevano je geslo",
     "Testing authentication" : "Poteka overjanje podatkov",
     "Awaiting user consent" : "Čakanje na odziv uporabnika",
+    "Account created. Please follow the pop-up instructions to link your Google account" : "Račun je ustvarjen. Za povezavo Googlovega računa sledite navodilom.",
     "Loading account" : "Poteka nalaganje računa",
     "Account updated" : "Račun je posodobljen",
     "IMAP server is not reachable" : "Strežnik IMAP ni dosegljiv",
@@ -62,15 +66,16 @@ OC.L10N.register(
     "IMAP connection failed" : "Povezava IMAP je spodletela",
     "SMTP connection failed" : "Povezava SMTP je spodletela",
     "Account settings" : "Nastavitve računa",
+    "Aliases" : "Vzdevki",
     "Signature" : "Podpis",
     "A signature is added to the text of new messages and replies." : "K besedilu novih sporočil in odgovorov je dodan podpis.",
     "Writing mode" : "Način pisanja",
     "Preferred writing mode for new messages and replies." : "Prednostni način pisanja sporočil za nova sporočila in odgovore.",
     "Default folders" : "Privzete mape",
     "Sieve filter rules" : "Pravila filtra Sieve",
-    "Trusted senders" : "Zaupanja vredni pošiljatelji",
     "Mail server" : "Poštni strežnik",
     "Sieve filter server" : "Strežnik filtra Sieve",
+    "Mailbox search" : "Iskanje po poštnem predalu",
     "Update alias" : "Posodobi vzdevek",
     "Rename alias" : "Preimenuj vzdevek",
     "Show update alias form" : "Pokaži obrazec za posodobitev vzdevka",
@@ -81,15 +86,33 @@ OC.L10N.register(
     "Add alias" : "Dodaj vzdevek",
     "Create alias" : "Ustvari vzdevek",
     "Cancel" : "Prekliči",
+    "Mail settings" : "Nastavitve pošte",
+    "List" : "Seznam",
+    "Account creation" : "Ustvarjanje računa",
     "Add mail account" : "Dodaj račun elektronske pošte",
+    "Data collection consent" : "Strinjanje z zbiranjem podatkov",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Program lahko zbira podatke o vaših pogostih dejanjih in na podlagi teh podatkov prilagaja delovanje vašemu načinu uporabe. Podatki se shranjujejo le krajevno.",
+    "Trusted senders" : "Zaupanja vredni pošiljatelji",
+    "Gravatar settings" : "Nastavitve Gravatar",
     "Use Gravatar and favicon avatars" : "Uporabi podobe Gravatar in Favicon",
     "Register as application for mail links" : "Nastavi kot program za odpiranje povezav na poštne elektronske naslove",
-    "Show keyboard shortcuts" : "Pokaži tipkovne bližnjice",
+    "Register" : "Vpis računa",
     "Manage S/MIME certificates" : "Upravljanje s potrdili S/MIME",
+    "Sorting" : "Razvrščanje",
     "Newest" : "Najnovejše",
     "Oldest" : "Najstarejše",
     "Looking for a way to encrypt your emails?" : "Ali iščete način za šifriranje elektronskih sporočil?",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Program lahko zbira podatke o vaših pogostih dejanjih in na podlagi teh podatkov prilagaja delovanje vašemu načinu uporabe. Podatki se shranjujejo le krajevno.",
+    "Keyboard" : "Tipkovnica",
+    "Compose new message" : "Novo sporočilo",
+    "Newer message" : "Novejše sporočilo",
+    "Older message" : "Starejše sporočilo",
+    "Toggle star" : "Preklopi zvezdico",
+    "Toggle unread" : "Preklopi neprebrano",
+    "Archive" : "Arhiv",
+    "Delete" : "Izbriši",
+    "Search" : "Iskanje",
+    "Send" : "Pošlji",
+    "Refresh" : "Osveži",
     "Put my text to the bottom of a reply instead of on top of it." : "Dodaj besedilo odgovora pod izvorno sporočilo in ne nad.",
     "Automatically classify importance of new email" : "Samodejno določi pomembnost novih sporočil",
     "Could not update preference" : "Lastnosti ni mogoče posodobiti",
@@ -102,11 +125,11 @@ OC.L10N.register(
     "From" : "Od",
     "Select account" : "Izbor računa",
     "To" : "Za",
+    "Select recipient" : "Izbor prejemnika",
     "Contact or email address …" : "Stik ali elektronski naslov ...",
     "Toggle recipients list mode" : "Preklopi način seznama prejemnikov",
     "Cc" : "Kp",
     "Bcc" : "Skp",
-    "No contacts found." : "Ni najdenih stikov.",
     "Subject" : "Zadeva",
     "Subject …" : "Zadeva ...",
     "This message came from a noreply address so your reply will probably not be read." : "Sporočilo je bilo poslano z naslova, ki ni namenjen odgovarjanju, zato odgovor najverjetneje ne bo prispel do naslovnika.",
@@ -118,11 +141,11 @@ OC.L10N.register(
     "Draft saved" : "Osnutek je shranjen",
     "Save draft" : "Shrani osnutek",
     "Discard & close draft" : "Opusti in zapri osnutek",
+    "Enable formatting" : "Omogoči oblikovanje",
+    "Disable formatting" : "Onemogoči oblikovanje",
     "Upload attachment" : "Pošlji prilogo",
     "Add attachment from Files" : "Dodaj prilogo iz Datotek",
     "Send later" : "Pošlji kasneje",
-    "Enable formatting" : "Omogoči oblikovanje",
-    "Disable formatting" : "Onemogoči oblikovanje",
     "Request a read receipt" : "Zahtevaj povratnico",
     "Sign message with S/MIME" : "Podpiši sporočila z S/MIME",
     "Encrypt message with S/MIME" : "Šifriraj z S/MIME",
@@ -138,13 +161,13 @@ OC.L10N.register(
     "Encrypt with S/MIME and send" : "Šifriraj z S/MIME in pošlji",
     "Encrypt with Mailvelope and send later" : "Šifriraj z Mailvelope in pošlji kasneje",
     "Encrypt with Mailvelope and send" : "Šifriraj z Mailvelope in pošlji",
-    "Send" : "Pošlji",
     "Message {id} could not be found" : "Sporočila {id} ni mogoče najti.",
     "Turn off formatting" : "Onemogoči oblikovanje",
     "Turn off and remove formatting" : "Onemogoči in odstrani oblikovanje",
     "Keep formatting" : "Ohrani oblikovanje",
     "Choose a file to add as attachment" : "Izbor datoteke za prilogo",
     "Choose a file to share as a link" : "Izberite datoteko, ki jo želite dati v skupno rabo kot povezavo",
+    "Choose" : "Izbor",
     "_{count} attachment_::_{count} attachments_" : ["{count} priloga","{count} prilogi","{count} priloge","{count} prilog"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Velikost priloge presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave.","Velikost prilog presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave.","Velikost prilog presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave.","Velikost prilog presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave."],
     "Untitled message" : "Nenaslovljeno sporočilo",
@@ -196,6 +219,8 @@ OC.L10N.register(
     "_Delete {number} thread_::_Delete {number} threads_" : ["Izbriši {number} nit sporočil","Izbriši {number} niti sporočil","Izbriši {number} niti sporočil","Izbriši {number} niti sporočil"],
     "Report this bug" : "Pošlji poročilo o hrošču",
     "All day" : "Ves dan",
+    "Select calendar" : "Izbor koledarja",
+    "Description" : "Opis",
     "Create" : "Ustvari",
     "Event created" : "Dogodek je ustvarjen",
     "Could not create event" : "Ni mogoče ustvariti dogodka",
@@ -223,7 +248,6 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Poteka ustvarjanje kazala sporočil. Opravilo je lahko dolgotrajno pri velikih poštnih predalih.",
     "Choose target mailbox" : "Izbor ciljnega poštnega predala",
     "No more submailboxes in here" : "V tem predalu ni drugih predalov",
-    "Choose" : "Izbor",
     "Important info" : "Pomembno",
     "Other" : "Drugo",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Sporočila bodo samodejno označena kot pomembna na podlagi do sedaj označenih takih sporočil. V začetku bo verjetno treba kakšno označiti še ročno, a se bo sistem s časom izboljševal.",
@@ -262,7 +286,6 @@ OC.L10N.register(
     "Moving" : "Premikanje",
     "Moving thread" : "Poteka premikanje niti ...",
     "Moving message" : "Poteka premikanje sporočila ...",
-    "Mail settings" : "Nastavitve pošte",
     "Provisioned account is disabled" : "Povezan račun je onemogočen",
     "Quota" : "Količinska omejitev",
     "Show only subscribed mailboxes" : "Pokaži le naročene poštne predale",
@@ -300,7 +323,6 @@ OC.L10N.register(
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} neprebrano od skupno {total}","{unread} neprebrana od skupno {total}","{unread} neprebrana od skupno {total}","{unread} neprebranih od skupno {total}"],
     "Outbox" : "Odhodna pošta",
     "New message" : "Novo sporočilo",
-    "Refresh" : "Osveži",
     "Error sending your message" : "Prošlo je do napake med pošiljanjem sporočila",
     "Retry" : "Poskusi  znova",
     "Uploading attachments …" : "Poteka pošiljanje prilog ...",
@@ -321,7 +343,6 @@ OC.L10N.register(
     "Message" : "Sporočilo",
     "Oh Snap!" : "Ojoj!",
     "Could not open outbox" : "Ni mogoče odpreti odhodnega predala",
-    "Delete" : "Izbriši",
     "Message could not be sent" : "Sporočila ni mogoče poslati",
     "Message deleted" : "Sporočilo je izbrisano",
     "Contacts with this address" : "Stiki s tem naslovom",
@@ -347,7 +368,6 @@ OC.L10N.register(
     "Marked as" : "Označeno kot",
     "Has attachments" : "Vsebuje prilogo",
     "Clear" : "Počisti",
-    "Search" : "Iskanje",
     "Date" : "Datum",
     "Disabled" : "Onemogočeno",
     "Enabled" : "Omogočeno",
@@ -367,8 +387,8 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Nastavljen podpis je večji od 2 MB. Velikost lahko vpliva na delovanje urejevalnika.",
     "Save signature" : "Shrani podpis",
     "Place signature above quoted text" : "Postavi podpis nad navedeno besedilo.",
-    "Delete tag" : "Izbriši oznako",
     "Saving new tag name …" : "Poteka shranjevanje imena oznake ...",
+    "Delete tag" : "Izbriši oznako",
     "Set tag" : "Nastavi oznako",
     "Unset tag" : "Odstrani oznako",
     "An error occurred, unable to rename the tag." : "Prišlo je do napake, oznake ni mogoče preimenovati.",
@@ -378,7 +398,6 @@ OC.L10N.register(
     "Tag name is a hidden system tag" : "Ime oznake je skrita sistemska oznaka",
     "Tag already exists" : "Oznaka že obstaja",
     "An error occurred, unable to create the tag." : "Prišlo je do napake, oznake ni mogoče ustvariti.",
-    "Select calendar" : "Izbor koledarja",
     "No calendars with task list support" : "Koledar s podporo seznama nalog",
     "Task created" : "Naloga je ustvarjena",
     "Could not create task" : "Naloge ni mogoče ustvariti",
@@ -478,15 +497,6 @@ OC.L10N.register(
     "Private key (optional)" : "Zasebni ključ (izbirno)",
     "Submit" : "Pošlji",
     "Failed to import the certificate" : "Uvažanje potrdila je spodletelo",
-    "Keyboard shortcut" : "Tipkovna bližnica",
-    "Keyboard shortcuts" : "Tipkovne bližnjice",
-    "Speed up your Mail experience with these quick shortcuts." : "Pospešite delo s Pošto z uporabo tipkovnih bližnjic.",
-    "Compose new message" : "Novo sporočilo",
-    "Newer message" : "Novejše sporočilo",
-    "Older message" : "Starejše sporočilo",
-    "Toggle star" : "Preklopi zvezdico",
-    "Toggle unread" : "Preklopi neprebrano",
-    "Archive" : "Arhiv",
     "Account connected" : "Račun je povezan",
     "Connect your mail account" : "Povežite svoj elektronski račun",
     "Tomorrow – {timeLocale}" : "Jutri – {timeLocale}",
