@@ -29,12 +29,22 @@ OC.L10N.register(
     "Go back" : "Shko prapa",
     "Cancel" : "Anullo",
     "Add mail account" : "Shto llogarinë e postës elektronike",
+    "Register" : "Regjistrohu",
+    "Newer message" : "Mesazhe më të reja",
+    "Older message" : "Mesazhe më të vjetra",
+    "Toggle star" : "Toggle star",
+    "Toggle unread" : "Toggle i pa lexuar",
+    "Archive" : "Arkiva",
+    "Delete" : "Fshij",
+    "Search" : "Kërko",
+    "Send" : "Dërgo",
+    "Refresh" : "Rifresko",
     "Select account" : "Përzgjidhni llogari",
     "Subject" : "Temë",
     "Upload attachment" : "Ngarko bashkëngjitje",
     "Add attachment from Files" : "Shto bashkëlidhje nga Dosjet",
-    "Send" : "Dërgo",
     "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
+    "Choose" : "Zgjidhni",
     "Confirm" : "Konfirmo",
     "Unfavorite" : "Jo i/e preferuar",
     "Favorite" : "I/E Preferuar",
@@ -45,11 +55,11 @@ OC.L10N.register(
     "Back" : "Prapa",
     "Forward" : "Përpara",
     "All day" : "Gjithë ditën",
+    "Description" : "Përshkrim",
     "Create" : "Krijo",
     "Comment" : "Koment",
     "Accept" : "Prano",
     "Decline" : "Refuzo",
-    "Choose" : "Zgjidhni",
     "Other" : "Tjetër",
     "Reply" : "Përgjigju",
     "Import into calendar" : "Importo në kalendar",
@@ -66,18 +76,15 @@ OC.L10N.register(
     "Mark all as read" : "Shënoji krejt si të lexuar",
     "Clear cache" : "Pastroje fshehtinën",
     "New message" : "Mesazh i ri",
-    "Refresh" : "Rifresko",
     "Retry" : "Riprovoni",
     "Sending …" : "Po dërgohet …",
     "Message" : "Mesazh",
-    "Delete" : "Fshij",
     "Copy to clipboard" : "Kopjo në dërrasë ",
     "Add" : "Shto",
     "Close" : "Mbylleni",
     "Tags" : "Etiketat",
     "Select tags" : "Përzgjidh etiketat",
     "Clear" : "Pastro",
-    "Search" : "Kërko",
     "Date" : "Data",
     "Disabled" : "I çaktivizuar",
     "Enabled" : "I aktivizuar",
@@ -98,14 +105,6 @@ OC.L10N.register(
     "Valid until" : "E vlefshme deri më",
     "Certificate" : "Çertifikata",
     "Submit" : "Dërgo",
-    "Keyboard shortcut" : "Shkurtore tastiere",
-    "Keyboard shortcuts" : "Shkurtoret e tastierës",
-    "Speed up your Mail experience with these quick shortcuts." : "Përmirësoni përvojën tuaj në Mail me këto shkurtore të shpejta.",
-    "Newer message" : "Mesazhe më të reja",
-    "Older message" : "Mesazhe më të vjetra",
-    "Toggle star" : "Toggle star",
-    "Toggle unread" : "Toggle i pa lexuar",
-    "Archive" : "Arkiva",
     "Connect your mail account" : "Lidhni llogarinë tuaj të postës elektronike",
     "All" : "Të gjithë",
     "Drafts" : "Skica",
