@@ -50,7 +50,6 @@ OC.L10N.register(
     "Writing mode" : "Skrivläge",
     "Preferred writing mode for new messages and replies." : "Föredraget skrivläge för nya meddelanden och svar.",
     "Default folders" : "Standardmappar",
-    "Trusted senders" : "Betrodda avsändare",
     "Mail server" : "E-postserver",
     "Update alias" : "Uppdatera alias",
     "Delete alias" : "Radera alias",
@@ -61,11 +60,23 @@ OC.L10N.register(
     "Create alias" : "Skapa alias",
     "Cancel" : "Avbryt",
     "Add mail account" : "Lägg till e-postkonto",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Låt appen samla in data om dina interaktioner. Baserat på denna information kommer appen att anpassas till dina preferenser. Uppgifterna lagras endast lokalt.",
+    "Trusted senders" : "Betrodda avsändare",
     "Use Gravatar and favicon avatars" : "Använd Gravatar och favicon som profilbild",
     "Register as application for mail links" : "Registrera som app för e-postlänkar",
-    "Show keyboard shortcuts" : "Visa tangentbordsgenvägar",
+    "Register" : "Registrera",
+    "Sorting" : "Sortering",
     "Looking for a way to encrypt your emails?" : "Söker du efter ett sätt att kryptera meddelanden?",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Låt appen samla in data om dina interaktioner. Baserat på denna information kommer appen att anpassas till dina preferenser. Uppgifterna lagras endast lokalt.",
+    "Compose new message" : "Skapa nytt meddelande",
+    "Newer message" : "Nyare meddelande",
+    "Older message" : "Äldre meddelande",
+    "Toggle star" : "Växla stjärna",
+    "Toggle unread" : "Visa/dölj oläst",
+    "Archive" : "Arkivera",
+    "Delete" : "Ta bort",
+    "Search" : "Sök",
+    "Send" : "Skicka",
+    "Refresh" : "Uppdatera",
     "Put my text to the bottom of a reply instead of on top of it." : "Infoga min text längst ner i ett svar i stället för längst upp.",
     "Automatically classify importance of new email" : "Sortera inkommande e-post efter viktighetsklass automatiskt",
     "Could not update preference" : "Kunde inte uppdatera inställningar",
@@ -75,7 +86,6 @@ OC.L10N.register(
     "Contact or email address …" : "Kontakt eller e-postadress …",
     "Cc" : "Cc",
     "Bcc" : "Bcc",
-    "No contacts found." : "Inga kontakter hittades.",
     "Subject" : "Ämne",
     "Subject …" : "Ämne …",
     "This message came from a noreply address so your reply will probably not be read." : "Det här meddelandet kom från en noreply adress så ditt svar kommer förmodligen inte att läsas.",
@@ -86,11 +96,11 @@ OC.L10N.register(
     "Draft saved" : "Utkast sparat",
     "Save draft" : "Spara utkast",
     "Discard & close draft" : "Stäng och radera utkast",
+    "Enable formatting" : "Aktivera formatering",
     "Upload attachment" : "Ladda upp bilaga",
     "Add attachment from Files" : "Lägg till bilaga från Filer",
     "Smart picker" : "Smart picker",
     "Send later" : "Skicka senare",
-    "Enable formatting" : "Aktivera formatering",
     "Request a read receipt" : "Begär läskvitto",
     "Encrypt message with Mailvelope" : " Kryptera meddelande med \"Mailvelope\"",
     "Send now" : "Skicka nu",
@@ -99,10 +109,10 @@ OC.L10N.register(
     "Monday morning" : "Måndag morgon",
     "Custom date and time" : "Anpassat datum och tid",
     "Enter a date" : "Ange datum",
-    "Send" : "Skicka",
     "Message {id} could not be found" : "Meddelandet {id} hittades inte",
     "Choose a file to add as attachment" : "Välj en fil att lägga som bilaga",
     "Choose a file to share as a link" : "Välj en fil att dela som länk",
+    "Choose" : "Välj",
     "_{count} attachment_::_{count} attachments_" : ["{count} bilaga","{count} bilagor"],
     "Confirm" : "Bekräfta",
     "Plain text" : "Oformaterad text",
@@ -149,6 +159,7 @@ OC.L10N.register(
     "_Delete {number} thread_::_Delete {number} threads_" : ["Ta bort {number} tråd","Ta bort {number} trådar"],
     "Report this bug" : "Rapportera detta fel",
     "All day" : "Hela dagen",
+    "Description" : "Beskrivning",
     "Create" : "Skapa",
     "Event created" : "Evenemang skapat",
     "Could not create event" : "Kunde inte skapa händelse",
@@ -160,7 +171,6 @@ OC.L10N.register(
     "Loading messages …" : "Läser in meddelanden …",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexera dina meddelanden. Det kan ta lite längre tid för större brevlådor.",
     "Choose target mailbox" : "Välj markerad inkorg",
-    "Choose" : "Välj",
     "Important info" : "Viktig info",
     "Other" : "Övrigt",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Meddelanden kommer automatiskt att markeras som viktiga baserat på vilka meddelanden du interagerade med eller har markerat som viktiga. I början kan du behöva ändra vikten manuellt, men det kommer att förbättras med tiden.",
@@ -220,7 +230,6 @@ OC.L10N.register(
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} av {total} oläst","{unread} av {total} oläst"],
     "Outbox" : "Utkorg",
     "New message" : "Nytt meddelande",
-    "Refresh" : "Uppdatera",
     "Error sending your message" : "Ett fel inträffade när ditt meddelande skulle skickas",
     "Retry" : "Försök igen",
     "Uploading attachments …" : "Laddar upp bilagor ...",
@@ -228,11 +237,11 @@ OC.L10N.register(
     "Send anyway" : "Skicka ändå",
     "Edit message" : "Redigera meddelande",
     "Draft" : "Utkast",
+    "Welcome to {cloudName} Mail" : "Välkommen till {cloudName} Mail",
     "First day" : "Första dagen",
     "Message" : "Meddelande",
     "Oh Snap!" : "Hoppsan!",
     "Could not open outbox" : "Kunde inte öppna utkorgen",
-    "Delete" : "Ta bort",
     "Contacts with this address" : "Kontakter med den här adressen",
     "Add to Contact" : "Lägg till i Kontakter",
     "New Contact" : "Ny kontakt",
@@ -248,7 +257,6 @@ OC.L10N.register(
     "Tags" : "Taggar",
     "Select tags" : "Välj taggar",
     "Clear" : "Rensa",
-    "Search" : "Sök",
     "Date" : "Datum",
     "Disabled" : "Inaktiverad",
     "Enabled" : "Aktiverad",
@@ -306,17 +314,9 @@ OC.L10N.register(
     "With the settings above, the app will create account settings in the following way:" : "Med inställningarna ovan skapar appen kontoinställningar på följande sätt:",
     "E-mail address" : "E-postadress",
     "Valid until" : "Giltigt till",
+    "Delete certificate" : "Ta bort certifikat",
     "Certificate" : "Certifikat",
     "Submit" : "Skicka",
-    "Keyboard shortcut" : "Tangentbordsgenvägar",
-    "Keyboard shortcuts" : "Tangentbordsgenvägar",
-    "Speed up your Mail experience with these quick shortcuts." : "Snabba upp din E-post-upplevelse med dessa genvägar.",
-    "Compose new message" : "Skapa nytt meddelande",
-    "Newer message" : "Nyare meddelande",
-    "Older message" : "Äldre meddelande",
-    "Toggle star" : "Växla stjärna",
-    "Toggle unread" : "Visa/dölj oläst",
-    "Archive" : "Arkivera",
     "Account connected" : "Konto anslutet",
     "Connect your mail account" : "Anslut ditt e-postkonto",
     "Tomorrow – {timeLocale}" : "Imorgon – {timeLocale}",
