@@ -19,8 +19,14 @@ OC.L10N.register(
     "Change name" : "เปลี่ยนชื่อ",
     "Email address" : "ที่อยู่อีเมล",
     "Cancel" : "ยกเลิก",
+    "Register" : "ลงทะเบียน",
+    "Archive" : "ที่เก็บถาวร",
+    "Delete" : "ลบ",
+    "Search" : "ค้นหา",
     "Send" : "ส่ง",
+    "Refresh" : "รีเฟรช",
     "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
+    "Choose" : "เลือก",
     "Confirm" : "ยืนยัน",
     "Favorite" : "รายการโปรด",
     "Read" : "อ่าน",
@@ -29,11 +35,11 @@ OC.L10N.register(
     "Edit tags" : "แก้ไขแท็ก",
     "Back" : "ย้อนกลับ",
     "Forward" : "ส่งต่อ",
+    "Description" : "คำอธิบาย",
     "Create" : "สร้าง",
     "Comment" : "ความคิดเห็น",
     "Accept" : "ยอมรับ",
     "Decline" : "ปฏิเสธ",
-    "Choose" : "เลือก",
     "Other" : "อื่น ๆ",
     "Reply" : "ตอบกลับ",
     "Unnamed" : "ไม่มีชื่อ",
@@ -45,15 +51,12 @@ OC.L10N.register(
     "Remove account" : "ลบบัญชี",
     "Mark all as read" : "เปลี่ยนทั้งหมดเป็นอ่านแล้ว",
     "Clear cache" : "ล้างแคช",
-    "Refresh" : "รีเฟรช",
     "Sending …" : "กำลังส่ง ...",
-    "Delete" : "ลบ",
     "Copy to clipboard" : "คัดลอกไปยังคลิปบอร์ด",
     "Add" : "เพิ่ม",
     "Close" : "ปิด",
     "Tags" : "แท็ก",
     "Clear" : "ล้าง",
-    "Search" : "ค้นหา",
     "Date" : "วันที่",
     "Disabled" : "ปิดใช้งาน",
     "Enabled" : "เปิดใช้งาน",
@@ -70,9 +73,6 @@ OC.L10N.register(
     "Valid until" : "ใช้ได้จนถึง",
     "Certificate" : "ใบรับรอง",
     "Submit" : "ส่ง",
-    "Keyboard shortcut" : "แป้นพิมพ์ลัด",
-    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
-    "Archive" : "ที่เก็บถาวร",
     "Account connected" : "เชื่อมต่อบัญชีแล้ว",
     "All" : "ทั้งหมด",
     "Drafts" : "ฉบับร่าง",
