@@ -42,7 +42,6 @@ OC.L10N.register(
     "Preferred writing mode for new messages and replies." : "Chế độ soạn thảo ưu tiên cho các tin nhắn và trả lời mới.",
     "Default folders" : "Thư mục mặc định",
     "Sieve filter rules" : "Quy tắc lọc Sieve",
-    "Trusted senders" : "Người gửi đáng tin cậy",
     "Mail server" : "Máy chủ thư",
     "Sieve filter server" : "Máy chủ lọc Sieve",
     "Go back" : "Quay lại",
@@ -50,17 +49,28 @@ OC.L10N.register(
     "Email address" : "Địa chỉ thư điện tử",
     "Add alias" : "Thêm bí danh",
     "Cancel" : "Hủy bỏ",
+    "List" : "Danh sách",
     "Add mail account" : "Thêm tài khoản mail",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Cho phép ứng dụng thu thập dữ liệu về các tương tác của bạn. Dựa trên dữ liệu này, ứng dụng sẽ điều chỉnh theo sở thích của bạn. Dữ liệu sẽ chỉ được lưu trữ trên máy của bạn.",
+    "Trusted senders" : "Người gửi đáng tin cậy",
     "Use Gravatar and favicon avatars" : "Sử dụng hình đại diện Gravatar và favicon",
     "Register as application for mail links" : "Đăng ký làm ứng dụng cho các liên kết gửi thư",
-    "Show keyboard shortcuts" : "Hiển thị phím tắt",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Cho phép ứng dụng thu thập dữ liệu về các tương tác của bạn. Dựa trên dữ liệu này, ứng dụng sẽ điều chỉnh theo sở thích của bạn. Dữ liệu sẽ chỉ được lưu trữ trên máy của bạn.",
+    "Register" : "Đăng ký",
+    "Compose new message" : "Soạn tin nhăn mơi",
+    "Newer message" : "Tin nhắn mới hơn",
+    "Older message" : "Tin nhắn cũ hơn",
+    "Toggle star" : "Chuyển đổi dấu sao",
+    "Toggle unread" : "Chuyển đổi chưa đọc",
+    "Archive" : "Lưu trữ",
+    "Delete" : "Xóa",
+    "Search" : "Tìm",
+    "Send" : "Gởi",
+    "Refresh" : "Làm mới",
     "Put my text to the bottom of a reply instead of on top of it." : "Đặt văn bản ở cuối thư trả lời thay vì ở đầu thư.",
     "From" : "Từ",
     "Select account" : "Chọn tài khoản",
     "To" : "Tới",
     "Contact or email address …" : "Địa chỉ liên hệ hoặc thư điện tử …",
-    "No contacts found." : "Không tìm thấy địa chỉ liên hệ.",
     "Subject" : "Chủ đề",
     "Subject …" : "Chủ đề …",
     "This message came from a noreply address so your reply will probably not be read." : "Thư này đến từ một địa chỉ không trả lời nên có thể sẽ không đọc được thư trả lời của bạn.",
@@ -68,17 +78,17 @@ OC.L10N.register(
     "Write message …" : "Viết tin nhắn …",
     "Saving draft …" : "Đang lưu bản nháp …",
     "Draft saved" : "Bản nháp đã được lưu",
+    "Enable formatting" : "Bật định dạng",
     "Upload attachment" : "Tải lên một đính kèm",
     "Add attachment from Files" : "Thêm tệp đính kèm từ Tệp",
-    "Enable formatting" : "Bật định dạng",
     "Request a read receipt" : "Yêu cầu xác nhận đã đọc",
     "Encrypt message with Mailvelope" : "Mã hóa thư bằng Mailvelope",
     "Enter a date" : "Nhập ngày",
     "Add share link from {productName} Files" : "Thêm liên kết chia sẻ từ Tệp {productName}",
-    "Send" : "Gởi",
     "Message {id} could not be found" : "Không tìm thấy tin nhắn {id}",
     "Choose a file to add as attachment" : "Chọn một tệp để thêm dưới dạng tệp đính kèm",
     "Choose a file to share as a link" : "Chọn một tệp để chia sẻ dưới dạng liên kết",
+    "Choose" : "Chọn",
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Các tệp đính kèm vượt quá kích thước được cho phép là {size}. Thay vào đó, hãy chia sẻ các tệp qua liên kết."],
     "Confirm" : "Xác nhận",
     "No messages in this mailbox" : "Không có thư nào trong hộp thư này",
@@ -108,6 +118,7 @@ OC.L10N.register(
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Chuyển tiếp {number} dưới dạng tệp đính kèm"],
     "Report this bug" : "Báo cáo lỗi này",
     "All day" : "Cả ngày",
+    "Description" : "Mô tả",
     "Create" : "‎Tạo‎",
     "Could not create event" : "Không thể tạo sự kiện",
     "Comment" : "Bình luận",
@@ -117,7 +128,6 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Lập chỉ mục tin nhắn của bạn. Quá trình này có thể lâu hơn một chút đối với các hộp thư lớn.",
     "Choose target mailbox" : "Chọn hộp thư mục tiêu",
     "No more submailboxes in here" : "Không còn hộp thư con nào ở đây",
-    "Choose" : "Chọn",
     "Important info" : "Thông tin quan trọng",
     "Other" : "Khác",
     "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Tin nhắn sẽ tự động được đánh dấu là quan trọng dựa trên những tin nhắn bạn đã tương tác hoặc được đánh dấu là quan trọng. Lúc đầu, bạn có thể phải thay đổi thủ công tầm quan trọng để dạy hệ thống, nhưng nó sẽ cải thiện theo thời gian.",
@@ -135,6 +145,7 @@ OC.L10N.register(
     "Save to Files" : "Lưu vào Tệp",
     "Unnamed" : "Vô danh",
     "Embedded message" : "Tin nhắn đã đính kém",
+    "Next week – {timeLocale}" : "Tuần sau - {timeLocale}",
     "Choose a folder to store the attachment in" : "Chọn một thư mục để lưu trữ tệp đính kèm trong",
     "Save all to Files" : "Lưu tất cả vào Tệp",
     "Download Zip" : "Tải xuống định dạng Zip",
@@ -179,13 +190,11 @@ OC.L10N.register(
     "_{total} message_::_{total} messages_" : ["{total} tin nhắn"],
     "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} thư chưa đọc trong tổng số {total} thư"],
     "New message" : "Tin nhắn mới",
-    "Refresh" : "Làm mới",
     "Error sending your message" : "Lỗi khi gửi tin nhắn",
     "Retry" : "Thử lại",
     "Uploading attachments …" : "Đang tải lên các tệp đính kèm …",
     "Sending …" : "Đang gửi …",
     "No sent mailbox configured. Please pick one in the account settings." : "Không có hộp thư đã gửi nào được định cấu hình. Vui lòng chọn một trong cài đặt tài khoản.",
-    "Delete" : "Xóa",
     "Contacts with this address" : "Liên hệ với địa chỉ này",
     "Add to Contact" : "Thêm liên hệ",
     "New Contact" : "ĐỊa chỉ liên hệ mới",
@@ -197,7 +206,6 @@ OC.L10N.register(
     "Tags" : "Nhãn",
     "Select tags" : "Chọn một thẻ",
     "Clear" : "Xóa",
-    "Search" : "Tìm",
     "Date" : "Date",
     "Disabled" : "Đã vô hiệu",
     "Enabled" : "Đá kích hoạt",
@@ -210,6 +218,7 @@ OC.L10N.register(
     "Sieve Password" : "Mật khẩu Sieve",
     "Save sieve settings" : "Lưu cài đặt sieve",
     "Save sieve script" : "Lưu sieve script",
+    "This weekend – {timeLocale}" : "Cuối tuần này - {timeLocale}",
     "Signature …" : "Chữ ký …",
     "Save signature" : "Lưu chữ ký",
     "Add tag" : "Thêm nhãn",
@@ -253,17 +262,10 @@ OC.L10N.register(
     "Valid until" : "Có hiệu lực đến",
     "Certificate" : "Chứng chỉ",
     "Submit" : "Gửi đi",
-    "Keyboard shortcut" : "Phím tắt",
-    "Keyboard shortcuts" : "Phím tắt",
-    "Speed up your Mail experience with these quick shortcuts." : "Tăng tốc trải nghiệm Thư của bạn với các phím tắt nhanh này.",
-    "Compose new message" : "Soạn tin nhăn mơi",
-    "Newer message" : "Tin nhắn mới hơn",
-    "Older message" : "Tin nhắn cũ hơn",
-    "Toggle star" : "Chuyển đổi dấu sao",
-    "Toggle unread" : "Chuyển đổi chưa đọc",
-    "Archive" : "Lưu trữ",
     "Account connected" : "Tài khoản đã được kết nối",
     "Connect your mail account" : "Kết nối tài khoản thư của bạn",
+    "Tomorrow – {timeLocale}" : "Ngày mai - {timeLocale}",
+    "Later today – {timeLocale}" : "Sau này - {timeLocale}",
     "Itinerary for {type} is not supported yet" : "Hành trình cho {type} chưa được hỗ trợ",
     "All" : "Tất cả",
     "Drafts" : "Bản nháp",
