@@ -134,10 +134,10 @@ class MessageMapper {
 		);
 		$perf->step('mailbox meta search');
 		$min = (int) $metaResults['min'];
-		$max = (int) $metaResults['max'];
 		$total = (int) $metaResults['count'];
 
 		if ($total === 0) {
+			$perf->step('No data in mailbox');
 			// Nothing to fetch for this mailbox
 			return [
 				'messages' => [],
@@ -146,6 +146,17 @@ class MessageMapper {
 			];
 		}
 
+		// This can happen for iCloud
+		if ($metaResults['max'] === null) {
+			$uidnext = $client->status(
+				$mailbox
+			);
+			$perf->step('mailbox meta search for UIDNEXT');
+			$max = (int) $uidnext['uidnext'] - 1; // We need to subtract one for the last used UID
+		} else {
+			$max = ((int) $metaResults['max']);
+		}
+
 		// The inclusive range of UIDs
 		$totalRange = $max - $min + 1;
 		// Here we assume somewhat equally distributed UIDs
@@ -351,7 +362,7 @@ class MessageMapper {
 		string $mailbox): void {
 		$client->store($mailbox, [
 			'add' => [
-				Horde_Imap_Client::FLAG_SEEN,
+				[Horde_Imap_Client::FLAG_SEEN],
 			],
 		]);
 	}
@@ -942,7 +953,7 @@ class MessageMapper {
 					$structure->setContents($htmlBody);
 					$htmlBody = $structure->getContents();
 				}
-				$html = new Html2Text($htmlBody, array('do_links' => 'none','alt_image' => 'hide'));
+				$html = new Html2Text($htmlBody, ['do_links' => 'none','alt_image' => 'hide']);
 				return new MessageStructureData(
 					$hasAttachments,
 					trim($html->getText()),
