@@ -36,6 +36,8 @@ use OCP\IConfig;
 use OCP\IInitialStateService;
 use OCP\LDAP\ILDAPProvider;
 use OCP\Settings\ISettings;
+use OCP\TextProcessing\FreePromptTaskType;
+use OCP\TextProcessing\SummaryTaskType;
 
 class AdminSettings implements ISettings {
 	/** @var IInitialStateService */
@@ -92,14 +94,20 @@ class AdminSettings implements ISettings {
 
 		$this->initialStateService->provideInitialState(
 			Application::APP_ID,
-			'enabled_thread_summary',
-			$this->config->getAppValue('mail', 'enabled_thread_summary', 'no') === 'yes'
+			'llm_processing',
+			$this->config->getAppValue('mail', 'llm_processing', 'no') === 'yes'
 		);
 
 		$this->initialStateService->provideInitialState(
 			Application::APP_ID,
-			'enabled_llm_backend',
-			$this->aiIntegrationsService->isLlmAvailable()
+			'enabled_llm_free_prompt_backend',
+			$this->aiIntegrationsService->isLlmAvailable(FreePromptTaskType::class)
+		);
+
+		$this->initialStateService->provideInitialState(
+			Application::APP_ID,
+			'enabled_llm_summary_backend',
+			$this->aiIntegrationsService->isLlmAvailable(SummaryTaskType::class)
 		);
 
 		$this->initialStateService->provideLazyInitialState(
